;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Routines : 
; 
;      - d_azav         : see_azav2, get_azav_mean2, see_mean_azav2
;      - d_mov_azav     : movie_azav2
;      - d_butterfly    : time_lat_azav2, time_lat_azav_mean2, time_rad_azav2
;      - d_magfieldprod : see_mag_prod
;      - d_alpha_omega  : Kyle's routines (quite complicated, see docs)
; 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

pro d_azav,GV,AZ,z

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Check if we have all variables needed
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  ans1 = 'plop'
   if not GV.haskey('rstar') then begin
     ans1 = ''
     print,'Enter stellar radius'
     read,ans1
     GV['rstar'] = double(ans1)
  endif
   if not GV.haskey('rbcz') then begin
     ans1 = ''
     print,'Enter proportion of the radiative core (between 0 and 1)'
     read,ans1
     GV['rbcz'] = double(ans1)
  endif
   if not GV.haskey('gr') then begin
     ans1 = ''
     print,'Enter stellar rotaiton rate (in solar units)'
     read,ans1
     GV['gr'] = double(ans1)
  endif
  if not AZ.haskey('quantities') then begin
     l = []
     print,'Choose a list of quantities'
     while ans1 ne '' do begin
        print,'Enter a new one (type nothing if list is complete)'
        read,ans1
        if ans1 ne '' then l = [l,long(ans1)]
     endwhile
     AZ['quantities'] = l
  endif
  if not AZ.haskey('sq') then begin
     l = []
     print,'Choose a list of statistical quantities'
     while ans1 ne '' do begin
        print,'Enter a new one (type nothing if list is complete)'
        read,ans1
        if ans1 ne '' then l = [l,long(ans1)]
     endwhile
     AZ['sq'] = l
  endif
  if not AZ.haskey('idmx') then begin
     print,'Enter idmx value'
     read,ans1
     AZ['idmx'] = long(ans1)
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Call to the see_eqsl routine
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  lq = AZ['quantities']
  sq = AZ['sq']

  nb_lq = size(lq) & nb_lq = nb_lq[1]
  nb_sq = size(sq) & nb_sq = nb_sq[1]

  for qq=0,nb_lq-1 do begin
     if qq ge nb_sq then sqq = sq[nb_sq-1] else sqq = sq[qq]
     if z eq 0 then see_azav2,GV['dir'],lq[qq],sqq,GV['iteration'],GV['recnum'],gr=GV['gr'],rbcz=GV['rbcz'],rstar=GV['rstar'],idmx=AZ['idmx'],$
               glob=GV['glob'],sc=GV['sc'],notquiet=GV['notquiet'],swap=GV['swap'],psf=GV['psf'],wnd=GV['wnd'],tv=1 else $
                  print,'plop : not implemented yet'
     GV['wnd'] = GV['wnd'] + 1
  endfor
end

pro d_butterfly,GV,BD
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   
; Check if we have all variables needed 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   

  ans1 = 'plop'
  if not BD.haskey('recperfile') then begin
     print,'Enter the number of record per file'
     read,ans1
     BD['recperfile'] = long(ans1)
  endif

  if not BD.haskey('radii') then begin
     l = []
     print,'Choose a list of radii'
     while ans1 ne '' do begin
        print,'Enter a new one (type nothing if list is complete)'
        read,ans1
        if ans1 ne '' then l = [l,long(ans1)]
     endwhile
     BD['radii'] = l
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
; Call to the see_eqsl routine                                                    
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  ir     = BD['radii']

  nb = long((GV['eend']-GV['start'])/GV['jump']+1)

  time_lat_azav14,GV['dir'],61,0,nb,GV['start'],GV['jump'],lr=ir,rstar=GV['rstar'],glob=GV['glob'],sc=GV['sc'],notquiet=GV['notquiet'],swap=GV['swap'],opl=GV['opl'],psf=GV['psf'],wnd=GV['wnd']
  GV['wnd']=GV['wnd']+1
end

pro d_magfieldprod,GV,MFP

  see_mag_prod,GV['iteration'],GV['recnum'],GV['dir'],swap=GV['swap'],sc=GV['sc'],glob=GV['glob'],psf=GV['psf'],tv=1,rbcz=GV['rbcz'],omr=GV['gr'],wnd=GV['wnd']
  GV['wnd'] = GV['wnd'] +1
end

pro d_alpha_omega,GV,AOE
end

pro d_mov_azav,GV,AZ
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Check if we have all variables needed               
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  ans1 = 'plop'
  if not AZ.haskey('quantities') then begin
     l = []
     print,'Choose a list of quantities'
     while ans1 ne '' do begin
        print,'Enter a new one (type nothing if list is complete)'
        read,ans1
        if ans1 ne '' then l = [l,long(ans1)]
     endwhile
     AZ['quantities'] = l
  endif

 if not AZ.haskey('to') then begin
     print,'Choose a time offset'
     read,ans1
     AZ['to'] = double(ans1)
  endif
  if not AZ.haskey('base') then begin
     print,'Choose an offset number of output file'
     read,ans1
     AZ['base'] = long(ans1)
  endif
  if not AZ.haskey('recperfile') then begin
     print,'Choose the number of record per file '
     read,ans1
     AZ['recperfile'] = long(ans1)
  endif
  if not AZ.haskey('idmx') then begin
     print,'Enter the idmx value'
     read,ans1
     AZ['idmx'] = long(ans1)
  endif
   
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Call to the eqsl movie routine                                                 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  lq     = AZ['quantities']
  sq     = AZ['sq']

  nb_lq = size(lq) & nb_lq = nb_lq[1]
  nb_sq = size(sq) & nb_sq = nb_sq[1]
  
  nbf = long((GV['eend']-GV['start'])/GV['jump']+1)

  for qq=0,nb_lq-1 do begin
     if qq ge nb_sq then sqq = sq[nb_sq-1] else sqq = sq[qq]
     movie_AZAV2,GV['dir'],lq[qq],sqq,AZ['recperfile'],nbf,GV['start'],GV['jump'],gr=GV['gr'],$
                 rbcz=GV['rbcz'],rstar=GV['rstar'],base=AZ['base'],to=AZ['to'],idmx=AZ['idmx'],$
                 glob=GV['glob'],sc=GV['sc'],notquiet=GV['notquiet'],swap=GV['swap'],psf=1,tv=1
     GV['wnd'] = GV['wnd']+1
  endfor

end
