;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Routines : 
; 
;     - colourbar  : horizontal one
;     - colourbar2 : vertival one
; 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; usage: colourbar,pos,notext=notext,mx=mx,mn=mn,zero=zero,textu=textu,
;           textmn=textmn,textmx=textmx,text_char_size=text_char_size,format=format,
;           text_color=text_color,text_thick=text_thick, pmvals=pmvals
; 
;        with pos     = 4-point array [x0,y0,x1,y1]
;             notext  = just plot colourbar
;             mx      = maximum
;             mn      = minimum
;             zero    = plot an intermediate tick (between min and max)
;                      in the colourbar, if not specified -> 0 if mn
;                      <0 and mean(mn,mx) either
;             textu   = name of unit
;             textmn  = specify text on minimum of the colourbar
;             textmx  = specify text on maximum of the colourbar
;             text_char_size = size of text
;             format         = string format for conversion number to
;                              string --> '(g9.3)' by default
;             text_color     = color of the text
;             text_thick     = thickness of the text
;             pmvals         = if set then symetrize the interval [mn,mx]
;             
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

pro colourbar,pos,notext=notext,mx=mx,mn=mn,zero=zero,textu=textu,$
              textmn=textmn,textmx=textmx, text_char_size=text_char_size, format=format, $
              text_color=text_color, text_thick=text_thick, pmvals=pmvals,space=space
              ;plttype=plttype,font=font,space=space

  if not keyword_set(format) then format='(g9.3)'
  if keyword_set(text_char_size) then begin
     text_char_size = text_char_size
  endif else begin
     text_char_size = 1.4
  endelse
  
;  if (not keyword_set(space)) then space=5
;  if n_elements(plttype) eq 0 then plttype = ' '

  xp = abs(pos(2)-pos(0))
  yp = abs(pos(3)-pos(1))
  
  xx0=convert_coord(pos(0),pos(1),/normal,/to_device)
  xx1=convert_coord(pos(2),pos(3),/normal,/to_device)
  ncols=255

  x0 = xx0(0)
  y0 = xx0(1)
  x1 = xx1(0)
  y1 = xx1(1)
  
  bar=(indgen(ncols)+1)#replicate(1,fix(abs(y1-y0)))
  
  bar=map(bar,abs(x1-x0)+2,abs(y1-y0))+2
  
  tv,bytscl(bar,top=ncols),pos(0),pos(1),xs=xp,ys=yp,/norm
  
  thick=2
  
  p0 = pos(0)*!d.x_size
  p1 = pos(1)*!d.y_size
  p2 = pos(2)*!d.x_size
  p3 = pos(3)*!d.y_size
  y_char = !D.Y_CH_SIZE*text_char_size
  x_char = !D.X_CH_SIZE*text_char_size
  

  plots,[p0+2,p2+1,p2+1,p0+2,p0+2],[p1,p1,p3-1,p3-1,p1], $
        thick=thick,/dev, color=text_color ;,color=2
  
  If (not keyword_set(notext)) Then Begin
     sf = 1.5 
     
     if (n_elements(textu) eq 0) then Begin
        textu=' '
     EndIf

     if (keyword_set(pmvals)) then begin
        val = max([abs(mx),abs(mn)])
        if (val eq abs(mx)) then begin
           valtxt = textmx
        endif else begin
           valtxt = strsplit(textmn,'-',/EXTRACT)      
        endelse
        txt = textmn+'!E !N/!E !N'+textmx+textu
        xyouts,0.5*(p2+p0),p1-1.25*y_char/sf,txt,/dev, charsize=text_char_size, color=text_color, align=0.5, charthick=text_thick
     endif else begin
        if (n_elements(textmx) ne 0) then begin
           xyouts,p2-1.5*x_char,0.5*(p1+p3)-1.5*y_char,textmx,/dev, charsize=text_char_size, color=text_color, align=0.0, charthick=text_thick
        endif else begin  
           if n_elements(mx) eq 0 then begin
              xyouts,p2,p1-1.25*y_char/sf,'!6max',/dev, charsize=text_char_size, color=text_color, align=0.5, charthick=2.0
           endif else begin
              xyouts,p2,p1-1.25*y_char/sf,strtrim(string(mx,form=format),2),/dev,$
                     charsize=text_char_size, color=text_color, align=0.5, charthick=2.0
           endelse
        endelse
        
        
        if (n_elements(textmn) ne 0) then begin
           xyouts,p0+1.5*x_char,0.5*(p1+p3)-1.5*y_char,textmn,/dev, charsize=text_char_size, color=text_color, align=1.0, charthick=text_thick
        endif else begin  
           if n_elements(mn) eq 0 then begin 
              xyouts,p0,p1-1.25*y_char/sf,'!6min',/dev, charsize=text_char_size, color=text_color, align=0.5, charthick=2.0
           endif else begin
              xyouts,p0,p1-1.25*y_char/sf,strtrim(string(mn,form=format),2),/dev, $
                     charsize=text_char_size, color=text_color, align=0.5, charthick=2.0
           endelse
        endelse
     endelse
     if not keyword_set(pmvals) then begin
        if keyword_set(mn) and keyword_set(mx) then begin
           if not keyword_set(zero) then begin
              if mn lt 0 then begin
                 zero=0.
              endif else begin
                 zero=(mx+mn)/2.
              endelse
           endif
           
           posc=(p2-p0)/(mx-mn)*zero+p0-(p2-p0)/(mx-mn)*mn
           
           plots,[posc,posc],[p1,p1-y_char/3d0],thick=thick,/dev, color=text_color ;,color=2
        endif
     endif
  EndIf
end

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; usage: colourbar,pos,notext=notext,mx=mx,mn=mn,zero=zero,textu=textu,
;           textmn=textmn,textmx=textmx,text_char_size=text_char_size,format=format,
;           text_color=text_color,text_thick=text_thick, pmvals=pmvals
; 
;        with pos     = 4-point array [x0,y0,x1,y1]
;             mx      = maximum
;             mn      = minimum
;             zero    = plot an intermediate tick (between min and max)
;                      in the colourbar, if not specified -> 0 if mn
;                      <0 and mean(mn,mx) either
;             plttype = text location dependant on the output type
;                       (screen or .eps)
;             textu   = name of unit
;             marks   = add more intermediate marks between mn and mx
;             nomarks = no intermediate marks between mn and mx even
;                       not zero           
;             textmn  = specify text on minimum of the colourbar
;             textmx  = specify text on maximum of the colourbar
;             text_char_size = size of text
;             format         = string format for conversion number to
;                              string --> '(g9.3)' by default
;             text_color     = color of the text
;             text_thick     = thickness of the text
;             space          = change the location of text
;             shiftmn        = idem
;             
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

pro colourbar2,pos,mx=mx,mn=mn,zero=zero,plttype=plttype,textu=textu,marks=marks,$
               nomarks=nomarks,textmn=textmn,textmx=textmx, text_char_size=text_char_size,$ 
               format=format,text_color=text_color,text_thick=text_thick,space=space,shiftmn=shiftmn
  
  If (not keyword_set(space)) Then space=5
  
  if not keyword_set(format) then format='(g9.3)'
  if keyword_set(text_char_size) then begin
     text_char_size = text_char_size
  endif else begin
     text_char_size = 1.4
  endelse
  
  if n_elements(plttype) eq 0 then plttype = ' '

  xp = abs(pos(2)-pos(0))
  yp = abs(pos(3)-pos(1))
  
  xx0=convert_coord(pos(0),pos(1),/normal,/to_device)
  xx1=convert_coord(pos(2),pos(3),/normal,/to_device)
  ncols=255
  
  x0 = xx0(0)
  y0 = xx0(1)
  x1 = xx1(0)
  y1 = xx1(1)

  bar=replicate(fix(abs(y1-y0)),1)#(indgen(ncols)+1)
  bar=map(bar,abs(x1-x0)+2,abs(y1-y0))+2
  
  tv,bytscl(bar,top=ncols),pos(0),pos(1),xs=xp,ys=yp,/norm
  
  thick=2
  p0 = pos(0)*!d.x_size
  p1 = pos(1)*!d.y_size
  p2 = pos(2)*!d.x_size
  p3 = pos(3)*!d.y_size
  y_char = !D.Y_CH_SIZE
  plots,[p0+2,p2+1,p2+1,p0+2,p0+2],[p1,p1,p3-1,p3-1,p1], $
        thick=thick,/dev,color=text_color

  if plttype eq 'ps' then sf = 1/16. else sf = 1.

  if n_elements(textu) eq 0 then textu=' '
  
  if (n_elements(textmx) ne 0) then begin
     xyouts, p0+(p2-p0)/2d0,p3+1.0*space/sf,textmx, /dev, charsize=text_char_size, align=0.5, charthick=text_thick,color=text_color
  endif else begin 
     if n_elements(mx) eq 0 then xyouts,p2,p3+5/sf,'!6max',/dev else $
        xyouts,p2,p3+y_char/sf/2., strtrim(string(mx,form=format),2), $
               /dev, charsize=text_char_size,charthick=1.4, align=1.0,color=text_color
     xyouts,p2,p3+y_char/sf/2., ' '+textu, $
            /dev, charsize=text_char_size,charthick=1.4, align=0.0,color=text_color
  endelse 
  
  if (n_elements(textmn) ne 0) then begin
     If (keyword_set(shiftmn)) Then Begin
        const = shiftmn
     Endif Else Begin
        const = 3.5d0
     EndElse
     xyouts, p0+(p2-p0)/2d0,p1-const*space/sf,textmn, /dev, charsize=text_char_size, align=0.5, charthick=text_thick,color=text_color
  endif else begin 
     if n_elements(mn) eq 0 then begin
        xyouts,p0+10/sf,p1-10/sf,'!6min',/dev 
     endif else begin
        xyouts,p2, p1-1.5*y_char/sf, strtrim(string(mn,form=format),2), $
               /dev, charsize=text_char_size,charthick=1.4, align=1.0,color=text_color
        xyouts,p2, p1-1.5*y_char/sf, ' '+textu, $
               /dev, charsize=text_char_size,charthick=1.4, align=0.0,color=text_color
     endelse
  endelse

  If (not keyword_set(nomarks)) Then Begin
     If (keyword_set(marks)) Then Begin
        nmrk = n_elements(marks)
        for ii=0,nmrk-1 do begin
           posc=(p3-p1)/(mx-mn)*marks[ii] + p1-(p3-p1)/(mx-mn)*mn
           plots,[p2,p2+5d0/sf],[posc,posc],thick=thick,/dev,color=text_color
        Endfor
     Endif Else Begin
        if keyword_set(mn) and keyword_set(mx) then begin
           if not keyword_set(zero) then begin
              if mn lt 0 then begin
                 zero=0.
              endif else begin
                 zero=(mx+mn)/2.
              endelse
           endif
           posc=(p3-p1)/(mx-mn)*zero+p1-(p3-p1)/(mx-mn)*mn
           plots,[p2,p2+5d0/sf],[posc,posc],thick=thick,/dev,color=text_color
        endif 
     Endelse
  EndIf
end







