@image_polar_css.pro
@legendre_derivative.pro

function int_tab3d_ind1, x, f, n2, n3

  TypeX = SIZE(X)
  TypeF = SIZE(F)

  Xsegments = TypeX[TypeX[0]+2] - 1L

  while (Xsegments MOD 4L) ne 0L do $
    Xsegments = Xsegments + 1L

  Xmin = MIN(X)
  Xmax = MAX(X)

 ;Uniform step size.
  h = (Xmax+0.0 - Xmin) / Xsegments
 ;Compute the interpolates at Xgrid.
  xnew = h*findgen(xsegments+1)+xmin
  h = 2.0*h/45.0
  y = fltarr(n2,Xsegments+1)
  tmp = fltarr(n2,n3)
  for  iz=0,n3-1 do begin
     for  iy=0,n2-1 do begin
        fx = reform(f[*,iy,iz])
 ;x values of interpolates >> Xgrid = h * FINDGEN(Xsegments + 1L) + Xmin
        z = SPL_INTERP(x, fx, SPL_INIT(x, fx), xnew)
        y[iy,*] = z
     endfor
 ;Compute the integral using the 5-point Newton-Cotes formula.
     ii = (LINDGEN((N_ELEMENTS(z) - 1L)/4L)+1) * 4L
     If (n_elements(ii) eq 1) Then Begin
        tmp[*,iz] = reform(h * (7.0 * (y[*,ii-4] + y[*,ii]) + 32.0 * (y[*,ii-3] + y[*,ii-1]) + 12.0 * y[*,ii-2]))
     Endif Else Begin
        tmp[*,iz] = total(h * (7.0 * (y[*,ii-4] + y[*,ii]) + 32.0 * (y[*,ii-3] + y[*,ii-1]) + 12.0 * y[*,ii-2]),2)
     EndElse
  endfor
  RETURN, tmp
  
end

pro build_aphi_only, is, ie, iskip, proc

    dir = '/dsm/stars2/f/cemeriau/EvolZR/20_eta_3d12/'

    ash_dir = dir+'/AZAV/azav_'
    nfs = long((ie-is)/iskip)+1L
    iter = is
    tmp = ash_dir + strcompress(iter,/r)
    files = tmp
    for ifile=1L,nfs-1L do begin
       iter = is+ifile*iskip
       tmp = ash_dir + strcompress(iter,/r)
       If (file_test(tmp)) Then Begin 
          files = [files,tmp]
       EndIf
    endfor

    nfs = n_elements(files)

    openr, file_unit, files[0], /get_lun ;open the file in read-only mode for big endian format 
    d = fltarr(3)
    readu, file_unit, d

    N_R = fix(d(0))
    N_Theta = fix(d(1))
    N_Q = fix(d(2))

    print, N_R, N_Theta, N_Q

    If (N_R eq 0) Then Begin
        close, file_unit
        free_lun, file_unit
        openr, file_unit, files[0], /SWAP_ENDIAN, /get_lun ;open the file in read-only mode for little endian format 
        d = fltarr(3)
        readu, file_unit, d

        N_R = fix(d(0))
        N_Theta = fix(d(1))
        N_Q = fix(d(2))
        swap = 1b
     Endif Else Begin
        swap = 0b
     EndElse
    
 ; now begin data read in 
    az_avgs = assoc(file_unit, fltarr(N_Theta,N_R,N_Q+1))
    
 ; read in radius information 
    radius = dblarr(N_R)
    radius[N_R-1] = az_avgs[7,0,0,0,0]
    radius[0] = az_avgs[9,0,0,0,0]
    radius[1:N_R-2] = az_avgs[10,0:N_R-3,0,0,0]
    rmax = max(radius)
    rrev = reverse(radius)/rmax

 ; and latitudes  
    costheta = reform(az_avgs[*,N_R-2,0,0,0])
    quantities = LONG(az_avgs[11,0:N_q-1,0,0,0])

;Get eta.
  ref_state = dblarr(N_r,22)
  openr, fu, dir+'/Checkpoint/01074000/reference', /get_lun, /f77_unformatted
  readu, fu, ref_state
  close, fu
  free_lun, fu

  eta = 4d0*!dpi*reform(ref_state[0:N_r-1,20])/2.99792458d10

  eta2d = (0d0*costheta+1d0)#eta
  eta2d = float(eta2d)
  record = 0
  while not(eof(file_unit)) do begin
     temp = az_avgs[0,0,1:N_Q,record]
     record = record+1
  endwhile
  
  if (record eq 0) then begin
     num_records = 1
  endif else begin
     num_records = record
  endelse
  
  rdqs = [161]
  nrqs = n_elements(rdqs)
  arqs = indgen(nrqs)
  for iq=0,nrqs-1 do begin
     arqs[iq] = where(quantities eq rdqs[iq])+1
  endfor

  close, file_unit
  free_lun, file_unit
  
 ; now begin data read in 
  print, 'qs = ', arqs

  theta = float(acos(costheta))
  sintheta = sin(acos(costheta))
  sintheta = float(sintheta)

  myf1 = long(proc[0])*long(nfs/proc[1])
  myf2 = (1L+long(proc[0]))*long(nfs/proc[1])-1L
  If ((proc[0] eq (proc[1]-1)) and (myf2 ne nfs-1L)) Then Begin
     myf2 = nfs-1L
  EndIf

  ntot = long(num_records)*long(myf2-myf1+1L)
  times = dblarr(ntot)
  azvals = fltarr(N_Theta,N_R,ntot)

  print, myf1, myf2, ntot

  pts = legendre_collocation_pts(n_theta)
  weights = pts[n_theta:*]
  ft = build_ftransform(costheta,weights)
  dt = build_dmatrix(costheta)
  bt = build_btransform(costheta)

  lmax = (2*n_theta-1)/3
  eep1r2 = dblarr(lmax,N_R)
  ell = dindgen(lmax+1)
  ell = -1d0/(ell*(ell+1d0))
  ell[0] = 0d0
  eep1r2 = ell#(radius)
  csct = 1d0/sin(acos(costheta))
  deltat = 0d0

  for ifile=myf1,myf2 do begin
     tstart = systime(1)

     openr, file_unit, files[ifile], /get_lun, swap_endian=swap
 ; now begin data read in
     az_avgs = assoc(file_unit, fltarr(N_Theta,N_R,N_Q+1))
     for inr=0L,num_records-1L do begin
        k = (ifile-myf1)*num_records + inr
        times[k] = az_avgs[5,0,0,inr]
        br = double(reform(az_avgs[*,*,arqs[0],inr]))

        for ir=0L,N_R-1L do begin
           azvals[*,ir,k] = float(csct*(bt#reform(dt##(eep1r2[*,ir]*(ft##reform(br[*,ir]))))))
        endfor
     endfor
     close, file_unit
     free_lun, file_unit

     tstop = systime(1)
     If (ifile eq myf1) Then Begin
        deltat = (tstop-tstart)/60d0
     Endif Else Begin
        deltat = 0.5d0*(deltat + (tstop-tstart)/60d0)
     EndElse
     print, 'file ' + strcompress(ifile+1L,/r) + ' of ' + strcompress(nfs,/r) + ' read.'
     print, 'Remaining time (minutes):', double(myf2-ifile-1L)*deltat
  endfor
  
  tmp = transpose(azvals,[2,0,1])

  print,'Size tmp : ',size(tmp)
  
  times = [ntot,times]
  openw, lun, ash_dir + 'Aphi_times_'+strcompress(proc[0],/r)+'.dat', /get_lun
  writeu, lun, times
  close, lun
  free_lun, lun
  
  openw, lun, ash_dir + 'Aphi_'+strcompress(proc[0],/r)+'.dat', /get_lun
  writeu, lun, tmp
  close, lun
  free_lun, lun
  
  tmp = 0
end

pro pack_files_aphi,nt,n_theta,n_r

  qs=["Aphi"]
  qt = qs+'_times'
  ash_dir = '/dsm/stars2/f/cemeriau/EvolZR/20_eta_3d12/AZAV/azav_'

  n_nt = size(nt) & n_nt = n_nt[1]
  n_times = 0
  for i_nt = 0,n_nt-1 do begin
     n_times = n_times + nt[i_nt]
  endfor

  arr = fltarr(n_times,n_theta,n_r)
  times = dblarr(n_times+1)
  times[0] = n_times

  k = 0L
  iq = 0
  for ii=0,n_nt-1 do begin
     tt = dblarr(nt[ii]+1L)
     openr, lun, ash_dir + qt[iq] +'_'+ strcompress(ii,/r)+'.dat', /get_lun
     readu, lun, tt
     close, lun
     free_lun, lun
     
     openr, lun, ash_dir + qs[iq] +'_'+ strcompress(ii,/r)+'.dat', /get_lun
     a = assoc(lun, fltarr(nt[ii],n_theta,n_r))
     tmp = a[0]
     close, lun
     free_lun, lun
     arr[k:k+nt[ii]-1L,*,*] = tmp
     times[k+1L:k+nt[ii]] = tt[1:*]
     k = k+nt[ii]
  endfor

  openw, lun, ash_dir + qt[iq]+'.dat'
  writeu, lun, times
  close, lun
  free_lun, lun
  
  openw, lun, ash_dir + qs[iq]+'.dat'
  a = assoc(lun, fltarr(n_times,n_theta,n_r))
  a[0] = arr
  close, lun
  free_lun, lun
end

pro build_aphi_comp, is, ie, iskip, proc

    dir = '/electra3/augustso/gs10_2013/d3_sld'

    ash_dir = dir+'/AZ_Avgs/'
    nfs = long((ie-is)/iskip)+1L
    iter = is
    tmp = ash_dir + strcompress(iter,/r)
    files = tmp
    for ifile=1L,nfs-1L do begin
       iter = is+ifile*iskip
       tmp = ash_dir + strcompress(iter,/r)
       If (file_test(tmp)) Then Begin 
          files = [files,tmp]
       EndIf
    endfor

    nfs = n_elements(files)

    openr, file_unit, files[0], /get_lun ;open the file in read-only mode for big endian format 
    d = fltarr(3)
    readu, file_unit, d

    N_R = fix(d(0))
    N_Theta = fix(d(1))
    N_Q = fix(d(2))

    print, N_R, N_Theta, N_Q

    If (N_R eq 0) Then Begin
        close, file_unit
        free_lun, file_unit
        openr, file_unit, files[0], /SWAP_ENDIAN, /get_lun ;open the file in read-only mode for little endian format 
        d = fltarr(3)
        readu, file_unit, d

        N_R = fix(d(0))
        N_Theta = fix(d(1))
        N_Q = fix(d(2))
        swap = 1b
     Endif Else Begin
        swap = 0b
     EndElse
    
 ; now begin data read in 
    az_avgs = assoc(file_unit, fltarr(N_Theta,N_R,N_Q+1))
    
 ; read in radius information 
    radius = dblarr(N_R)
    radius[N_R-1] = az_avgs[7,0,0,0,0]
    radius[0] = az_avgs[9,0,0,0,0]
    radius[1:N_R-2] = az_avgs[10,0:N_R-3,0,0,0]
    rmax = max(radius)
    rrev = reverse(radius)/rmax

 ; and latitudes  
    costheta = reform(az_avgs[*,N_R-2,0,0,0])
    quantities = LONG(az_avgs[11,0:N_q-1,0,0,0])

;Get eta.
  ref_state = dblarr(N_r,22)
  openr, fu, dir+'/Checkpoint/08000000/reference', /get_lun, /f77_unformatted
  readu, fu, ref_state
  close, fu
  free_lun, fu

  eta = 4d0*!dpi*reform(ref_state[0:N_r-1,20])/2.99792458d10

  eta2d = (0d0*costheta+1d0)#eta
  eta2d = float(eta2d)
  record = 0
  while not(eof(file_unit)) do begin
     temp = az_avgs[0,0,1:N_Q,record]
     record = record+1
  endwhile
  
  if (record eq 0) then begin
     num_records = 1
  endif else begin
     num_records = record
  endelse
  
  rdqs = [1,2,161,162,166,185]
  nrqs = n_elements(rdqs)
  arqs = indgen(nrqs)
  for iq=0,nrqs-1 do begin
     arqs[iq] = where(quantities eq rdqs[iq])+1
  endfor

  close, file_unit
  free_lun, file_unit
  
 ; now begin data read in 
  print, 'qs = ', arqs

  theta = float(acos(costheta))
  sintheta = sin(acos(costheta))
  sintheta = float(sintheta)

  myf1 = long(proc[0])*long(nfs/proc[1])
  myf2 = (1L+long(proc[0]))*long(nfs/proc[1])-1L
  If ((proc[0] eq (proc[1]-1)) and (myf2 ne nfs-1L)) Then Begin
     myf2 = nfs-1L
  EndIf

  ntot = long(num_records)*long(myf2-myf1+1L)
  times = dblarr(ntot)
  azvals = fltarr(N_Theta,N_R,4,ntot)

  print, myf1, myf2, ntot

  pts = legendre_collocation_pts(n_theta)
  weights = pts[n_theta:*]
  ft = build_ftransform(costheta,weights)
  dt = build_dmatrix(costheta)
  bt = build_btransform(costheta)

  lmax = (2*n_theta-1)/3
  eep1r2 = dblarr(lmax,N_R)
  ell = dindgen(lmax+1)
  ell = -1d0/(ell*(ell+1d0))
  ell[0] = 0d0
  eep1r2 = ell#(radius)
  csct = 1d0/sin(acos(costheta))
  deltat = 0d0
  for ifile=myf1,myf2 do begin
     tstart = systime(1)

     openr, file_unit, files[ifile], /get_lun, swap_endian=swap
 ; now begin data read in
     az_avgs = assoc(file_unit, fltarr(N_Theta,N_R,N_Q+1))
     for inr=0L,num_records-1L do begin
        k = (ifile-myf1)*num_records + inr
        times[k] = az_avgs[5,0,0,inr]

        tmp = reform(az_avgs[*,*,arqs[0],inr])
        vt = reform(az_avgs[*,*,arqs[1],inr])
        br = double(reform(az_avgs[*,*,arqs[2],inr]))
        tmp = tmp*reform(az_avgs[*,*,arqs[3],inr])

        azvals[*,*,0,k] = tmp - vt*br

        tmp = reform(az_avgs[*,*,arqs[4],inr])
        azvals[*,*,1,k] = reform(az_avgs[*,*,arqs[5],inr])
        azvals[*,*,2,k] = eta2d*tmp

        for ir=0L,N_R-1L do begin
           azvals[*,ir,3,k] = float(csct*(bt#reform(dt##(eep1r2[*,ir]*(ft##reform(br[*,ir]))))))
        endfor
     endfor
     close, file_unit
     free_lun, file_unit

     tstop = systime(1)
     If (ifile eq myf1) Then Begin
        deltat = (tstop-tstart)/60d0
     Endif Else Begin
        deltat = 0.5d0*(deltat + (tstop-tstart)/60d0)
     EndElse
     print, 'file ' + strcompress(ifile+1L,/r) + ' of ' + strcompress(nfs,/r) + ' read.'
     print, 'Remaining time (minutes):', double(myf2-ifile-1L)*deltat
  endfor
  
  azvals[*,*,1,*] = azvals[*,*,1,*] - azvals[*,*,0,*]

  tmp = transpose(reform(azvals[*,*,0,*]),[2,0,1])
  
  times = [ntot,times]
  openw, lun, ash_dir + 'MEMFphi_times_'+strcompress(proc[0],r)+'.dat', /get_lun
  writeu, lun, times
  close, lun
  free_lun, lun
  
  openw, lun, ash_dir + 'MEMFphi_'+strcompress(proc[0],/r)+'.dat', /get_lun
  writeu, lun, tmp
  close, lun
  free_lun, lun
  
  tmp = transpose(reform(azvals[*,*,1,*]),[2,0,1])
  
  times = [ntot,times]
  openw, lun, ash_dir + 'FEMFphi_times_'+strcompress(proc[0],/r)+'.dat', /get_lun
  writeu, lun, times
  close, lun
  free_lun, lun
  
  openw, lun, ash_dir + 'FEMFphi_'+strcompress(proc[0],/r)+'.dat', /get_lun
  writeu, lun, tmp
  close, lun
  free_lun, lun
  
  tmp = transpose(reform(azvals[*,*,2,*]),[2,0,1])
  
  times = [ntot,times]
  openw, lun, ash_dir + 'RDphi_times_'+strcompress(proc[0],/r)+'.dat', /get_lun
  writeu, lun, times
  close, lun
  free_lun, lun
  
  openw, lun, ash_dir + 'RDphi_'+strcompress(proc[0],/r)+'.dat', /get_lun
  writeu, lun, tmp
  close, lun
  free_lun, lun

  tmp = transpose(reform(azvals[*,*,3,*]),[2,0,1])
  
  times = [ntot,times]
  openw, lun, ash_dir + 'Aphi_times_'+strcompress(proc[0],/r)+'.dat', /get_lun
  writeu, lun, times
  close, lun
  free_lun, lun
  
  openw, lun, ash_dir + 'Aphi_'+strcompress(proc[0],/r)+'.dat', /get_lun
  writeu, lun, tmp
  close, lun
  free_lun, lun
  
  tmp = 0
end

pro pack_files_all

  qs=["Aphi", "FEMFphi", "MEMFphi", "RDphi"]
  qt = qs+'_times'
  ash_dir = '/electra3/augustso/gs10_2013/d3_sld/AZ_Avgs/'
  nt = [4400,4400,4400,4420]

  for iq=0,3 do begin
     arr = fltarr(17620,256,200)
     times = dblarr(17621)
     times[0] = 17620d0

     k = 0L
     for ii=0,3 do begin
        tt = dblarr(nt[ii]+1L)
        openr, lun, ash_dir + qt[iq] +'_'+ strcompress(ii,/r)+'.dat', /get_lun
        readu, lun, tt
        close, lun
        free_lun, lun

        openr, lun, ash_dir + qs[iq] +'_'+ strcompress(ii,/r)+'.dat', /get_lun
        a = assoc(lun, fltarr(nt[ii],256,200))
        tmp = a[0]
        close, lun
        free_lun, lun
        arr[k:k+nt[ii]-1L,*,*] = tmp
        times[k+1L:k+nt[ii]] = tt[1:*]
        k = k+nt[ii]
     endfor

     openw, lun, ash_dir + qt[iq]+'.dat'
     writeu, lun, times
     close, lun
     free_lun, lun

     openw, lun, ash_dir + qs[iq]+'.dat'
     a = assoc(lun, fltarr(17620,256,200))
     a[0] = arr
     close, lun
     free_lun, lun
  endfor
end

pro compute_time_integrals

    dir = '/dsm/stars2/f/cemeriau/EvolZR/20_eta_3d12/'
    path = dir+'/AZAV/azav_'

    openr, lun, path + 'Aphi_times.dat', /get_lun
    tmp = 0d0
    readu, lun, tmp
    nt = long(tmp)
    close, lun
    free_lun, lun
  
    times = dblarr(nt+1)
    openr, lun, path + 'Aphi_times.dat', /get_lun
    readu, lun, times
    close, lun
    free_lun, lun

    dt = float(max(times)-min(times))/float(nt-1)
    time = dt*findgen(nt)

    nr = 500
    nth = 768 ; HARDCODE

    aphi = dblarr(nt,nth,nr)
    openr, lun, path + 'Aphi.interp', /get_lun
    a = assoc(lun,fltarr(nt,nth,nr))
    aphi = a[0]    
    close, lun
    free_lun, lun

    i1 = 1030L
    i2 = i1 + 650L

    ap1 = reform(aphi[i1,*,*]) ;total(aphi[i1-50:i1+50,*,*],1,/double)/101d0
    ap2 = reform(aphi[i2,*,*]) ;total(aphi[i2-50:i2+50,*,*],1,/double)/101d0
    dap = ap2-ap1
    apm = total(aphi[100:*,*,*],1,/double)/17520d00
    ;^stop
    aphi=0

    openr, lun, path + 'FEMFphi.interp', /get_lun
    a = assoc(lun,fltarr(nt,nth,nr))
    tmp = a[0]    
    close, lun
    free_lun, lun

    femf1 = int_tab3d_ind1(time[100:i1],tmp[100:i1,*,*],nth,nr)
    femf2 = int_tab3d_ind1(time[100:i2],tmp[100:i2,*,*],nth,nr)
    femf = femf2-femf1

    openr, lun, path + 'MEMFphi.interp', /get_lun
    a = assoc(lun,fltarr(nt,nth,nr))
    tmp = a[0]    
    close, lun
    free_lun, lun

    memf1 = int_tab3d_ind1(time[100:i1],tmp[100:i1,*,*],nth,nr)
    memf2 = int_tab3d_ind1(time[100:i2],tmp[100:i2,*,*],nth,nr)
    memf = memf2-memf1

    openr, lun, path + 'RDphi.interp', /get_lun
    a = assoc(lun,fltarr(nt,nth,nr))
    tmp = a[0]    
    close, lun
    free_lun, lun

    rdp1 = int_tab3d_ind1(time[100:i1],tmp[100:i1,*,*],nth,nr)
    rdp2 = int_tab3d_ind1(time[100:i2],tmp[100:i2,*,*],nth,nr)
    rdp = rdp2-rdp1

    dth = !dpi/double(nth)
    theta = dth*(dindgen(nth)+0.5d0)
    dr = (0.97d0-0.71d0)/double(nr-1)
    radius = dr*dindgen(nr) + 0.71

    save, filename='deltaAphi.sav', radius, theta, memf, femf, rdp, ap1, ap2, dap
    stop
end

pro load_fields
  common blk, radius, theta, memf, femf, rdp, ap1, ap2, dap
  restore, 'deltaAphi.sav'
end

pro d3_sld_deltaAphi, filename
  common blk, radius, theta, memf, femf, rdp, ap1, ap2, dap

    nth = n_elements(theta)
    nr = n_elements(radius)

    costheta = cos(theta)
    print, nth, nr
    rstar = 6.96d10

    rmin = min(radius)
    rmax = max(radius)
        
    aztmp = fltarr(nth,nr,7)
    aztmp[*,*,0] = ap1
    aztmp[*,*,1] = ap2
    aztmp[*,*,2] = dap
    aztmp[*,*,3] = femf+memf-rdp
    aztmp[*,*,4] = femf
    aztmp[*,*,5] = memf
    aztmp[*,*,6] = -rdp

    xsize = 7.1d0
    ysize = 2.0286d0

    chrsz1=1.0
    chrsz2=0.85
   
    Set_Plot, "PS"
    !P.FONT=1
    Device, filename=filename, /ENCAPSULATED, BITS_PER_PIXEL=8, /COLOR, XSIZE=xsize, YSIZE=ysize, /TT_FONT, SET_FONT='Helvetica', /CMYK, /INCHES
    !P.FONT=1

    !P.MULTI=0
    !P.NOERASE=1
    !P.THICK=4    
    !P.CHARSIZE=chrsz1
    docolor
    choose_color, /special, /quiet

    space = 0.01d0
    dx = (1.0-7.0*3.85d0*space)/7d0

    min_value = 0.1d0*min(aztmp)
    max_value = 0.1d0*max(aztmp)
    max_value = max([-min_value,max_value])
    min_value = -max_value

    print, 'minmax=', min_value, max_value

    yc = 0.5d0
    dy = dx 
    y1 = 1d0-space
    y0 = space
    ytxt = yc-1.5d0*space

    iq = 0
    labels=['(a)','(b)','(c)','(d)','(e)','(f)','(g)']

    langle = '!9'+string("341b) + '!X' ;"
    rangle = '!9'+string("361b) + '!X' ;"
    vp = textoidl('\varphi')

    qnames=[langle+'A!E !N'+vp+', '+rangle, langle+'A!E !N'+vp+', !E !N'+rangle, textoidl('\Delta')+langle+'A!E !N'+vp+rangle, 'RHS', "{   '"+vp+'}', '[   '+vp+']', textoidl('-\eta')+'{J'+vp+'}']

    rrev = reverse(radius)
    for ix=0,6 do begin
       x0 = 4d0*space + ix*(dx+3.5d0*space)
       x1 = x0 + dx
       pos = [x0,y0,x1,y1]
       !P.POSITION=pos
       azgen = reform(aztmp[*,*,ix])
       image_polar_css, transpose(azgen[39:216,*]), rrev, costheta[39:216], min=min_value, max=max_value, $
             spacing=2d0*(max(radius)-min(radius))/n_elements(radius), /nocontour, position= pos

       ;xyouts,/NORMAL,x0+1d0*space,ytxt, 'T', color=0, wid=wid
       xyouts,/NORMAL,x0+1d0*space,ytxt-0.5d0*space, qnames[ix],color=0, charsize=chrsz2
       xyouts,/NORMAL,x0-3d0*space, y1-4d0*space, labels[ix], color=0

       If (ix eq 1) Then Begin
           plots, /normal, 0.2425d0+[0d0,0d0], [0.14d0,0.86d0], linestyle=3, thick=2, color=0
           xyouts, /normal, 0.2525d0, 0.92d0, 'T.C.'
           arrow_internal, /normal, /solid, 0.2625d0, 0.91d0, 0.2425d0, 0.86d0, hsize=120, thick=2.5
       EndIf
    endfor

    xyouts,/NORMAL, 0.075, ytxt-space, '1', charsize=0.65
    xyouts,/NORMAL, 0.1115+dx, ytxt-space, '2', charsize=0.65
    xyouts,/NORMAL, 0.615, ytxt-space, "!13E!X'", font=-1, charsize=0.85
    xyouts,/NORMAL, 0.7525, ytxt-space, "!13E!X", font=-1, charsize=0.85

    ;Mark lats

     ticknames = ['-60','-30','0','+30','+60']+textoidl('\circ')
     theta_tick=[-60,-30,0,30,60]*!dpi/180d0
     costh = cos(theta_tick) ;For y
     sinth = sin(theta_tick) ;For x
     x0s = 0d0*space+0.73d0*dx*costh/abs(costh[0])
     y0s = 0.4875d0+0.49d0*sinth/abs(sinth[0])
     x0s[3] = x0s[3]-0.5d0*space
     x0s[4] = x0s[4]-0.5d0*space
     y0s[0] = y0s[0]+1.35d0*space
     y0s[1] = y0s[1]
     y0s[3] = y0s[3]+0.5d0*space
     y0s[4] = y0s[4]-1.55d0*space

     for ii=0,4 do begin
        xyouts, x0s[ii], y0s[ii], ticknames[ii], color=0, /normal, charsize=chrsz2
     endfor

    x0 = 2d0*space
    yc = 0.5d0
    
    colourbar2,[x0,yc-0.12,x0+1.5d0*space,yc+0.12],mn=mint,mx=maxt,$
      textmx='+', textmn='_', text_char_size=0.9, plttype='ps',charthick=1,shiftmn=2d0

    DEVICE, /close
    print, 'Image ready.'
    SPAWN, 'evince '+ filename + ' &'
    close, /all

    stop
end
