;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Routines : 
; 
;      - ud6  : uniforme derivative
;      - nud6 : non uniform derivatives
; 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

function ud6, dr, arr

    sz = size(arr)
    np = sz[2]
    a0 = max([max(arr),1])
    array = arr/a0
    darr = fltarr(sz[1],sz[2])

;Sixth order accurate first derivatives at the ends
    left = (-147.0*array[*,0]+360.0*array[*,1]-450.0*array[*,2]+400.0*array[*,3]-225.0*array[*,4]+72.0*array[*,5]-10.0*array[*,6])/60.0
    left1 = (-10.0*array[*,0]-77.0*array[*,1]+150.0*array[*,2]-100.0*array[*,3]+50.0*array[*,4]-15.0*array[*,5]+2.0*array[*,6])/60.0
    left2 = (2.0*array[*,0]-24.0*array[*,1]-35.0*array[*,2]+80.0*array[*,3]-30.0*array[*,4]+8.0*array[*,5]-1.0*array[*,6])/60.0
        
    darr[*,0]=left
    darr[*,1]=left1
    darr[*,2]=left2
  
;Sixth order accurate first derivatives in the interior
    
    for i=3,np-4 do begin
        darr[*,i] = 1.0*array[*,i+3]-9.0*array[*,i+2]+45.0*array[*,i+1]-45.0*array[*,i-1]+9.0*array[*,i-2]-1.0*array[*,i-3]
        darr[*,i] = darr[*,i]/60.0
    endfor

    right2 = (1.0*array[*,np-7]-8.0*array[*,np-6]+30.0*array[*,np-5]-80.0*array[*,np-4]+35.0*array[*,np-3]+24.0*array[*,np-2]-2.0*array[*,np-1])/60.0
    right1 = (-2.0*array[*,np-7]+15.0*array[*,np-6]-50.0*array[*,np-5]+100.0*array[*,np-4]-150.0*array[*,np-3]+77.0*array[*,np-2]+10.0*array[*,np-1])/60.0
    right = (10.0*array[*,np-7]-72.0*array[*,np-6]+225.0*array[*,np-5]-400.0*array[*,np-4]+450.0*array[*,np-3]-360.0*array[*,np-2]+147.0*array[*,np-1])/60.0

    darr[*,np-3]=right2
    darr[*,np-2]=right1
    darr[*,np-1]=right

    darr = darr*a0/dr

return, darr

end

function nud6, rad, arr

   np = n_elements(rad)
   if (n_elements(arr) ne np) then begin
      return, -1
   endif

   r0 = max(rad)
   arr0 = max([max(arr),1.0])
   r = rad(*)/r0   
   array = arr(*)/arr0

   der = fltarr(np)
   der(*) = 0.0

   ;Lower boundary
   d3  = r(6)-r(0)
   d2  = r(5)-r(0)
   d1  = r(4)-r(0)
   dm1 = r(3)-r(0)
   dm2 = r(2)-r(0)
   dm3 = r(1)-r(0)

   a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
   a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
   a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
   am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
   am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
   am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

   a0  = a3+a2+a1+am1+am2+am3
   a0  = -a0
   der(0) = a3*array(6)+a2*array(5)+a1*array(4)+a0*array(0)+am1*array(3)+am2*array(2)+am3*array(1)
   
   d3  = r(6)-r(1)
   d2  = r(5)-r(1)
   d1  = r(4)-r(1)
   dm1 = r(3)-r(1)
   dm2 = r(2)-r(1)
   dm3 = r(0)-r(1)

   a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
   a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
   a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
   am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
   am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
   am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

   a0  = a3+a2+a1+am1+am2+am3
   a0  = -a0
   der(1) = a3*array(6)+a2*array(5)+a1*array(4)+a0*array(1)+am1*array(3)+am2*array(2)+am3*array(0)

   d3  = r(6)-r(2)
   d2  = r(5)-r(2)
   d1  = r(4)-r(2)
   dm1 = r(3)-r(2)
   dm2 = r(1)-r(2)
   dm3 = r(0)-r(2)

   a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
   a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
   a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
   am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
   am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
   am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

   a0  = a3+a2+a1+am1+am2+am3
   a0  = -a0
   der(2) = a3*array(6)+a2*array(5)+a1*array(4)+a0*array(2)+am1*array(3)+am2*array(1)+am3*array(0)
   
   ;Interior
   for i=3L,np-4L do begin
       d3  = r(i+3)-r(i)
       d2  = r(i+2)-r(i)
       d1  = r(i+1)-r(i)
       dm1 = r(i-1)-r(i)
       dm2 = r(i-2)-r(i)
       dm3 = r(i-3)-r(i)

       a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
       a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
       a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
       am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
       am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
       am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

       a0  = a3+a2+a1+am1+am2+am3
       a0  = -a0
       ;c1  = -d3*d2*d1*dm1*dm2*dm3

       der(i) = a3*array(i+3)+a2*array(i+2)+a1*array(i+1)+a0*array(i)+am1*array(i-1)+am2*array(i-2)+am3*array(i-3)
   endfor

   ;Upper boundary
   d3  = r(np-7L)-r(np-3L)
   d2  = r(np-6L)-r(np-3L)
   d1  = r(np-5L)-r(np-3L)
   dm1 = r(np-4L)-r(np-3L)
   dm2 = r(np-2L)-r(np-3L)
   dm3 = r(np-1L)-r(np-3L)

   a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
   a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
   a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
   am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
   am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
   am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

   a0  = a3+a2+a1+am1+am2+am3
   a0  = -a0
   der(np-3L) = a3*array(np-7L)+a2*array(np-6L)+a1*array(np-5L)+a0*array(np-3L)+am1*array(np-4L)+am2*array(np-2L)+am3*array(np-1L)

   d3  = r(np-7L)-r(np-2L)
   d2  = r(np-6L)-r(np-2L)
   d1  = r(np-5L)-r(np-2L)
   dm1 = r(np-4L)-r(np-2L)
   dm2 = r(np-3L)-r(np-2L)
   dm3 = r(np-1L)-r(np-2L)

   a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
   a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
   a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
   am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
   am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
   am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

   a0  = a3+a2+a1+am1+am2+am3
   a0  = -a0
   der(np-2L) = a3*array(np-7L)+a2*array(np-6L)+a1*array(np-5L)+a0*array(np-2L)+am1*array(np-4L)+am2*array(np-3L)+am3*array(np-1L)

   d3  = r(np-7L)-r(np-1L)
   d2  = r(np-6L)-r(np-1L)
   d1  = r(np-5L)-r(np-1L)
   dm1 = r(np-4L)-r(np-1L)
   dm2 = r(np-3L)-r(np-1L)
   dm3 = r(np-2L)-r(np-1L)

   a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
   a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
   a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
   am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
   am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
   am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

   a0  = a3+a2+a1+am1+am2+am3
   a0  = -a0
   der(np-1L) = a3*array(np-7L)+a2*array(np-6L)+a1*array(np-5L)+a0*array(np-1L)+am1*array(np-4L)+am2*array(np-3L)+am3*array(np-2L)

   der = arr0*der/r0

   return, der
end

function nud6_2d, rad, arr

   np = n_elements(rad)
   if (n_elements(arr[0,*]) ne np) then begin
      return, -1
   endif

   nz = n_elements(arr[*,0])

   r0 = max(rad)
   arr0 = max([max(arr),1.0])
   r = rad/r0   
   array = arr/arr0

   der = fltarr(nz,np)
   der[*,*] = 0.0

   ;Lower boundary
   d3  = r[6]-r[0]
   d2  = r[5]-r[0]
   d1  = r[4]-r[0]
   dm1 = r[3]-r[0]
   dm2 = r[2]-r[0]
   dm3 = r[1]-r[0]

   a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
   a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
   a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
   am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
   am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
   am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

   a0  = a3+a2+a1+am1+am2+am3
   a0  = -a0
   der[*,0] = a0*array[*,0] + am3*array[*,1] + am2*array[*,2] + am1*array[*,3] + a1*array[*,4] + a2*array[*,5] + a3*array[*,6]
   
   d3  = r[6]-r[1]
   d2  = r[5]-r[1]
   d1  = r[4]-r[1]
   dm1 = r[3]-r[1]
   dm2 = r[2]-r[1]
   dm3 = r[0]-r[1]

   a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
   a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
   a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
   am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
   am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
   am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

   a0  = a3+a2+a1+am1+am2+am3
   a0  = -a0
   der[*,1] = am3*array[*,0] + a0*array[*,1] + am2*array[*,2] + am1*array[*,3] + a1*array[*,4] + a2*array[*,5] + a3*array[*,6]

   d3  = r[6]-r[2]
   d2  = r[5]-r[2]
   d1  = r[4]-r[2]
   dm1 = r[3]-r[2]
   dm2 = r[1]-r[2]
   dm3 = r[0]-r[2]

   a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
   a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
   a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
   am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
   am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
   am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

   a0  = a3+a2+a1+am1+am2+am3
   a0  = -a0
   der[*,2] = am3*array[*,0] + am2*array[*,1] + a0*array[*,2] + am1*array[*,3] + a1*array[*,4] + a2*array[*,5] + a3*array[*,6]

   ;Interior
   for i=3L,np-4L do begin
       d3  = r[i+3]-r[i]
       d2  = r[i+2]-r[i]
       d1  = r[i+1]-r[i]
       dm1 = r[i-1]-r[i]
       dm2 = r[i-2]-r[i]
       dm3 = r[i-3]-r[i]

       a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
       a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
       a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
       am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
       am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
       am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

       a0  = a3+a2+a1+am1+am2+am3
       a0  = -a0
       ;c1  = -d3*d2*d1*dm1*dm2*dm3

       der[*,i] = am3*array[*,i-3] + am2*array[*,i-2] + am1*array[*,i-1] + a0*array[*,i] + a1*array[*,i+1] + a2*array[*,i+2] + a3*array[*,i+3]
   endfor

   ;Upper boundary
   d3  = r[np-7L]-r[np-3L]
   d2  = r[np-6L]-r[np-3L]
   d1  = r[np-5L]-r[np-3L]
   dm1 = r[np-4L]-r[np-3L]
   dm2 = r[np-2L]-r[np-3L]
   dm3 = r[np-1L]-r[np-3L]

   a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
   a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
   a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
   am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
   am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
   am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

   a0  = a3+a2+a1+am1+am2+am3
   a0  = -a0
   der[*,np-3L] = a3*array[*,np-7L]+a2*array[*,np-6L]+a1*array[*,np-5L]+am1*array[*,np-4L]+a0*array[*,np-3L]+am2*array[*,np-2L]+am3*array[*,np-1L]

   d3  = r[np-7L]-r[np-2L]
   d2  = r[np-6L]-r[np-2L]
   d1  = r[np-5L]-r[np-2L]
   dm1 = r[np-4L]-r[np-2L]
   dm2 = r[np-3L]-r[np-2L]
   dm3 = r[np-1L]-r[np-2L]

   a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
   a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
   a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
   am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
   am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
   am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

   a0  = a3+a2+a1+am1+am2+am3
   a0  = -a0
   der[*,np-2L] = a3*array[*,np-7L]+a2*array[*,np-6L]+a1*array[*,np-5L]+am1*array[*,np-4L]+am2*array[*,np-3L]+a0*array[*,np-2L]+am3*array[*,np-1L]

   d3  = r[np-7L]-r[np-1L]
   d2  = r[np-6L]-r[np-1L]
   d1  = r[np-5L]-r[np-1L]
   dm1 = r[np-4L]-r[np-1L]
   dm2 = r[np-3L]-r[np-1L]
   dm3 = r[np-2L]-r[np-1L]

   a3  = -d2*d1*dm1*dm2*dm3/(d3*(d1-d3)*(d2-d3)*(d3-dm1)*(d3-dm2)*(d3-dm3))
   a2  = -d3*d1*dm1*dm2*dm3/(d2*(d2-d3)*(d2-d1)*(d2-dm1)*(d2-dm2)*(d2-dm3))
   a1  = -d3*d2*dm1*dm2*dm3/(d1*(d1-d3)*(d1-d2)*(d1-dm1)*(d1-dm2)*(d1-dm3))
   am1 = -d3*d2*d1*dm2*dm3/(dm1*(dm1-d3)*(dm1-d2)*(dm1-d1)*(dm1-dm2)*(dm1-dm3))
   am2 = -d3*d2*d1*dm1*dm3/(dm2*(dm2-d3)*(dm2-d2)*(dm2-d1)*(dm2-dm1)*(dm2-dm3))
   am3 = -d3*d2*d1*dm1*dm2/(dm3*(dm3-d3)*(dm3-d2)*(dm3-d1)*(dm3-dm1)*(dm3-dm2))

   a0  = a3+a2+a1+am1+am2+am3
   a0  = -a0
   der[*,np-1L] = a3*array[*,np-7L]+a2*array[*,np-6L]+a1*array[*,np-5L]+am1*array[*,np-4L]+am2*array[*,np-3L]+am3*array[*,np-2L]+a0*array[*,np-1L]

   der = arr0*der/r0


   return, der
end
