;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Step function
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

function stepfct_nu,r,rad,stiff

  return,0.5*(tanh(1e-10*(r-rad)/stiff)+1.0d0)

end  

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Nu function (expression based on ASH code)
; 
;   usage: nu,r,secondary_input,density=density
;     with r               = radius array
;          secondary_input = relevant secondary_input
;          density         = 1D density array (only dependant on r) 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

function nu,r,secondary_input,density

  openr,lun,secondary_input,/get_lun

  val=dictionary()

  line = ' '
  while not eof(lun) do begin
     readf,lun,line
     len=strlen(line)
     line = str_replace(line,'%','')
     i=strpos(line,'=')
     if i ge 0 then begin
        keyword= strtrim(strmid(line,0,i),2)
        keyword=STRCOMPRESS(keyword,/REMOVE_ALL)
        value= strmid(line,i+1,len-i-1)
        value = str_replace(value,'d','e')
        value =str_replace(value,'D','e')
        val[keyword] = long(strcompress(value,/remove_all))
     endif
  endwhile

  if val['nu_type'] eq 0 then val['nu_type'] = 1

  sn = stepfct_nu(r,val['nu_radius'],val['nu_stiffness'])

  plot,r/1e10,sn
  stop
  
  print,val['nu_type']
  stop

  case val['nu_type'] of
     1: return,val['nu_top'] * (density/density[0])^val['nu_exponent']

     2: return,val['nu_exponent']*val['nu_top'] + val['nu_top'] * (1.0D0-val['nu_exponent'])*sn
        
     3: return,val['nu_exponent']*val['nu_top'] + val['nu_top'] * (1.0D0-val['nu_exponent'])*sn * (density/density[0])^(val['nu_density_dep']) 
  end
end

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Kappa function (expression based on ASH code)
; 
;   usage: kappa,r,secondary_input,density=density
;     with r               = radius array
;          secondary_input = relevant secondary_input
;          density         = 1D density array (only dependant on r) 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

function kappa,r,secondary_input,density

  openr,lun,secondary_input,/get_lun

  val=dictionary()

  line = ' '
  while not eof(lun) do begin
     readf,lun,line
     len=strlen(line)
     line = str_replace(line,'%','')
     i=strpos(line,'=')
     if i ge 0 then begin
        keyword= strtrim(strmid(line,0,i),2)
        keyword=STRCOMPRESS(keyword,/REMOVE_ALL)
        value= strmid(line,i+1,len-i-1)
        value = str_replace(value,'d','e')
        value =str_replace(value,'D','e')
        val[keyword] = long(strcompress(value,/remove_all))
        print,keyword,val[keyword]
     endif
  endwhile

  if val['nu_type'] eq 0 then val['nu_type'] = 1

  sn = stepfct_nu(r,val['kappa_radius'],val['kappa_stiffness'])

  case val['nu_type'] of
     1: return,val['kappa_top'] * (density/density[0])**val['kappa_exponent']

     2: return,val['kappa_exponent']*val['kappa_top'] + val['kappa_top'] * (1.0D0-val['kappa_exponent'])*sn
        
     3: return,val['kappa_exponent']*val['kappa_top'] + val['kappa_top'] * (1.0D0-val['kappa_exponent'])*sn * (density/density[0])**(val['kappa_density_dep'])
  end
end

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Eta function (expression based on ASH code)
; 
;   usage: eta,r,secondary_input,density=density
;     with r               = radius array
;          secondary_input = relevant secondary_input
;          density         = 1D density array (only dependant on r) 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

function eta,r,secondary_input,density

  openr,lun,secondary_input,/get_lun

  val=dictionary()

  line = ' '
  while not eof(lun) do begin
     readf,lun,line
     len=strlen(line)
     line = str_replace(line,'%','')
     i=strpos(line,'=')
     if i ge 0 then begin
        keyword= strtrim(strmid(line,0,i),2)
        keyword=STRCOMPRESS(keyword,/REMOVE_ALL)
        value= strmid(line,i+1,len-i-1)
        value = str_replace(value,'d','e')
        value =str_replace(value,'D','e')
        val[keyword] = long(strcompress(value,/remove_all))
        print,keyword,val[keyword]
     endif
  endwhile

  if val['nu_type'] eq 0 then val['nu_type'] = 1

  sn = stepfct_nu(r,val['eta_radius'],val['eta_stiffness'])

  case val['nu_type'] of
     1: return,val['eta_top'] * (density/density[0])**val['eta_exponent']

     2: return,val['eta_exponent']*val['eta_top'] + val['eta_top'] * (1.0D0-val['eta_exponent'])*sn
        
     3: return,val['eta_exponent']*val['eta_top'] + val['eta_top'] * (1.0D0-val['eta_exponent'])*sn * (density/density[0])**(val['eta_density_dep'])
  end
end
