;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  get_lmean.pro  -  Plot spectra from files cominf from get_spectra2
;   
;  usage : spectra2,file=file,icutmax=icutmax,rho=rho,mag=mag,ross=ross,$
;                   notquiet=notquiet,namepsf=namepsf,savef=savef,$
;                   psf=psf,q=q,rbcz=rbcz,fshsl=file_shsl,rstar=rstar,$
;                   swap=swap
;          where file     = output of get_spectra2
;                icutmax  = number of shells
;                rho      = density to calculate KE
;                mag      = also plot magnetic spectra
;                ross     = spectra on velocity components
;                notquiet = verbose if smaller than 2
;                namepsf  = name of output .ps file
;                savef    = save values as .idl files
;                psf      = type of output (screen or .eps)
;                q        = if greater than 1 plot spectra of q
;                rbcz     = percentage of radiative zone
;                fhsl     = path of the shsl file (to get radii of
;                shells)
;                rstar    = stellar radius
;                swap     = dependant of the endianess of files
;                licut    = list icut
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

pro get_lmean2,file,icutmax,rho=rho,mag=mag,psf=psf,notquiet=notquiet,$
             namepsf=namepsf,savef=savef,ross=ross,q=q,rbcz=rbcz,fshsl=fshsl,$
             rstar=rstar,swap=swap,glob=glob,yy=yy,licut=licut,nokolmo=nokolmo,$
             wnd=wnd

  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  if n_params() lt 2 then begin
     print,'spectra2,file,icutmax,rho=rho,mag=mag,psf=psf,'+$
           'notquiet=notquiet,namepsf=namepsf,savef=savef,'+$
           'ross=ross,q=q,rbcz=rbcz,fshsl=fshsl,rstar=rstar,'+$
           'swap=swap'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(name1)    then namepsf  = 'spectra.ps'
  if not keyword_set(rbcz)     then rbcz     = 0
  if not keyword_set(rho)      then rho      = ''
  if not keyword_set(savef)    then savef    = 0
  if not keyword_set(mag)      then mag      = 0
  if not keyword_set(ross)     then ross     = 0
  if not keyword_set(q)        then q        = 0
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(yy)       then begin
     yra  = [1.d0,1.d8]
     yrb  = [1.d0,2.d9]
     yrm  = [1.d1,2.d9]
     yrm0 = [1.d2,2.d8]
  endif else begin
     yra  = yy
     yrb  = yy
     yrm  = yy
     yrm0 = yy
  endelse
  if not keyword_set(licut)    then licut    = lindgen(icutmax+1) 
  if not keyword_set(nokolmo)  then nokolmo  = 0

  if glob eq 0 then fileshsl='/dsm/stars2/f/cemeriau/EvolZR/'+fshsl else fileshsl=fshsl

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Graphics device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  !p.font=1
  device,set_font='Helvetica Italic',/tt_font
  
  device,decomposed=0
  r=[0,255,255,225,195,165,0,0,0,0,0,0]
  g=[0,255,0,0,0,0,0,0,0,0,255,225]
  b=[0,255,0,0,0,0,255,225,195,165,0,0]
  tvlct,r,g,b  
  dec=1
  
  if (psf eq 1) then begin
     set_plot,'ps'
     device,filename=name1,/color,/landscape
  endif

  if (psf eq 0) then  window,wnd,xsize=1600,ysize=800
  !x.style=1
  
  !p.thick=5 & !x.thick=6 & !y.thick=6 & !p.charsize=2.5
  !p.charthick=1.4
  
  if psf eq 1 then !p.charsize=1.5
  
  !p.multi = 0

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Time parameters
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  dt = 1.d0/(3600.d0*24.d0)
  P = dt * ((2.*!pi) / 2.6d-6)
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; File reading
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  dims=fltarr(2)

  if not keyword_set(fshsl) then begin
     print,"File SHSL : "
     read,fshsl
  endif
  close,1 & openr,1,fshsl,swap_endian=swap
  readu,1,d & N_Phi = fix(d)
  readu,1,d & N_Theta = fix(d)
  readu,1,d & N_Shells = fix(d)
  readu,1,d & N_quantities = fix(d)
  close,1 & openr,1,fshsl,swap_endian=swap
  shell_slices = assoc(1,fltarr(N_Theta,N_Phi+1,N_Shells,N_quantities))
  rad=reform(shell_slices(8,0,0:icutmax,0,0))
  
  icutmax1=icutmax
  icutmax2=icutmax

  close,2 & openr,2,file
  readu,2,dims
  l_max1 = long(dims(0)) & nt1 = long(dims(1))
  if (l_max1 eq 0 && nt1 eq 0) then begin
     close,2
     restore,file=file,/ver
     l_max1=long(dims(0)) 
     nt1 = long(dims(1))
     KE1=out
  endif else begin
     iter1 = fltarr(nt1) & time1 = fltarr(nt1)
     KE1 = fltarr(l_max1+1,l_max1+1,icutmax1+1)
     readu,2,iter1,time1
     readu,2,KE1
  endelse

  l_max2=l_max1
  
  if (mag gt 0) then begin
     lasti = STRPOS(file, '/', /REVERSE_SEARCH)
     print,'mag file :: ',strmid(file,0,lasti+1)+'mag_'+strmid(file,lasti+1)
     close,2 & openr,2,strmid(file,0,lasti+1)+'mag_'+strmid(file,lasti+1)
  endif else if (ross gt 0 ) then begin
     close,2 & openr,2,'pol_'+file
  endif
  
  magross = mag + ross
  
  if (magross gt 0) then begin
     readu,2,dims
     l_max2 = long(dims(0)) & nt2 = long(dims(1))
     iter2 = fltarr(nt2) & time2 = fltarr(nt2)
     KE2 = fltarr(l_max2+1,l_max2+1,icutmax2+1)
     readu,2,iter2,time2
     readu,2,KE2
     iter2=long(iter2)
     close,2
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculation on kinetic data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  Km1 = fltarr(l_max1+1,icutmax1+1)*0.d0 & Km1nol0=Km1
  Kl1 = fltarr(l_max1+1,icutmax1+1)*0.d0 & Kl1nom0=Kl1
  
  for i=0,l_max1 do for j=0,icutmax1 do Km1(i,j)=total(KE1(0:l_max1,i,j),/double)
  for i=0,l_max1 do for j=0,icutmax1 do Km1nol0(i,j)=total(KE1(1:l_max1,i,j),/double)
  for i=0,l_max1 do for j=0,icutmax1 do Kl1(i,j)=total(KE1(i,0:l_max1,j),/double)
  for i=0,l_max1 do for j=0,icutmax1 do Kl1nom0(i,j)=total(KE1(i,1:l_max1,j),/double)
  
  E_kolmo1 = fltarr(l_max1+1) & E_k1 = E_kolmo1 & E_k1a = E_kolmo1 & E_k1b = E_k1a
  ll1 = findgen(l_max1+1)
  cte1=3e8
  for i=0,l_max1 do E_kolmo1(i)=cte1*i^(-5./3.)
  for i=0,l_max1 do E_k1(i)=cte1*i^(-2.)
  for i=0,l_max1 do E_k1a(i)=cte1*i^(-3.)
  for i=0,l_max1 do E_k1b(i)=cte1*i^(-4.)
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculation on magnetic or poloidal data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if (magross gt 0) then begin
     Km2 = fltarr(l_max2+1,icutmax2+1)*0.d0 & Km2nol0=Km2
     Kl2 = fltarr(l_max2+1,icutmax2+1)*0.d0 & Kl2nom0=Kl2
     
     for i=0,l_max2 do for j=0,icutmax2 do Km2nol0(i,j) = total(KE2(1:l_max2,i,j),/double)
     for i=0,l_max2 do for j=0,icutmax2 do Km2(i,j) = total(KE2(0:l_max2,i,j),/double)
     for i=0,l_max2 do for j=0,icutmax2 do Kl2nom0(i,j) = total(KE2(i,1:l_max2,j),/double)
     for i=0,l_max2 do for j=0,icutmax2 do Kl2(i,j) = total(KE2(i,0:l_max2,j),/double)
     
     E_kolmo2 = fltarr(l_max2+1)
     ll2 = findgen(l_max2+1) & E_k2 = E_kolmo2 & E_k2a = E_kolmo2
     cte2=3e8
     for i=0,l_max2 do E_kolmo2(i)=cte2*i^(-5./3.)
     for i=0,l_max2 do E_k2(i)=cte2*i^(-2.)
     for i=0,l_max2 do E_k2a(i)=cte2*i^(-3.)
  endif
  
  if (savef eq 1) then begin
     print,"Name of save file"
     sf=''
     read,sf
     if (magross gt 0) then begin
        save,file=sf,l_max1,l_max2,Km1,Kl1,Km1nol0,Kl1nom0,Km2,Kl2,Km2nol0,Kl2nom0,rad
     endif else begin
        save,file=sf,l_max1,Km1,Kl1,Km1nol0,Kl1nom0,rad
     endelse
  endif

  xra=[1,l_max1] & xra1=[0,l_max1]
  xrb=[1,l_max2] & xrb1=[0,l_max2]
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Transformation into energies
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if (not (strcmp(rho,''))) then begin
     restore,file=rho,/ver
                                ;dens1=dens
     coef=1.d0/8.d0/!dpi
     print,'density used',dens
  endif else begin
     print,'Constant definition'
     dens=dblarr(icutmax+1)
     dens(*) = 2
     coef  = 1
  endelse
  
  nomlz=0                  ; kinetic energy without m=0 or l=0 (depending of what is the variable)
  no_m= 1    ; kinetic energy as a function of m
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculate lmean
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  global_KE    = dblarr(icutmax1+1)*0.d0
  ponderate_KE = dblarr(icutmax1+1)*0.d0
  lmean        = dblarr(icutmax1+1)*0.d0


  for ir = 0,icutmax1 do begin
     for ll = 0,l_max1 do begin
        global_KE[ir]    = global_KE[ir]    + Kl1[ll,ir]
        ponderate_KE[ir] = ponderate_KE[ir] + Kl1[ll,ir]*ll
     endfor
     lmean[ir] = ponderate_KE[ir]/global_KE[ir]
  endfor

  plot,rad,lmean

  if psf eq 1 then begin
     device,/close
     set_plot,'x'
     !p.multi=0
  endif

end
  




