;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  image_eq_comp - Plot routine in r theta map
;  
;     usage :   image_eq_comp,a1,a2,r,spacing=spacing,amap=amap,title=title,
;                             interface=interface,phi=phi,pad=pad,flip=flip,
;                             pm_scale=pm_scale,eq_thick=eq_thick,rbcz=rbcz,
;                              mini=mini,maxi=maxi,levels=levels,date=date,
;                             c_labels=c_labels,c_thick=c_thick,psf=psf
;               where a1        = 1st set of values to compare 
;                     a2        = 2nd set of values to compare
;                     r         = radius array
;                     spacing   = keyword of polar_surface  
;                     title     = Title in image contour 
;                     interface = Ticks and addons to the 2Dplot  
;                     phi       = phi array
;                     pad       = Link to image contour 
;                     flip      = Reverse input values (regarding phi)
;                     pm_scale  = Link to image_contour 
;                     rbcz      = Base of the convective zone (in
;                     stellar radius)
;                     mini      = minimum of the plot
;                     maxi      = maximum of the plot
;                     levels    = Link to image contour
;                     c_labels  = Link to image contour
;                     c_thick   = Link to image contour
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

pro image_eq_comp,a1,a2,r,spacing=spacing,title=title,interface=interface,phi=phi,$
    pad=pad, flip = flip,pm_scale=pm_scale,rbcz=rbcz,mini=mini,maxi=maxi, $
    levels=levels,c_labels=c_labels,c_thick=c_thick,date=date,psf=psf

  ; optionally flip the image
  if keyword_set(flip) then begin
  if (flip eq 1) then begin
     sz = size(a1) & N_Phi = sz(2)
     b = a1     
     for i=0,N_Phi-1 do a1(*,i) = b(*,N_Phi-1-i)
     sz = size(a2) & N_Phi = sz(2)
     b = a2
     for i=0,N_Phi-1 do a2(*,i) = b(*,N_Phi-1-i)
  endif
  endif

  If keyword_set(phi) Then begin
      phi1 = phi / !radeg
  Endif Else begin
      sz = size(a1) 
      phi = !pi * findgen(sz(2))/sz(2)+ !pi/2
      phi2 = !pi +phi
   Endelse

  if not keyword_set(rbcz) then rbcz=0 

  rmax = max(r) & rmin = min(r)

  if not keyword_set(spacing) then spacing = .01*rmax
  if not keyword_set(title) then title = ' '

  if keyword_set(mini) then begin
    min1 = min(a1)
    min2 = min(a2)
    max1 = max(a1)
    max2 = max(a2)
    print,min(min1,min2),max(max1,max2),mini,maxi
;   amin=0
    amin=min(a1)                 ;mini
  endif else begin
   amin = min(a1)
  endelse

  amap2 = polar_surface(a2,r,phi2,/grid,missing=amin, $
                        bound=[0,-rmax,rmax,rmax],spacing=spacing*[0.1,0.1])
  amap = polar_surface(a1,r,phi,/grid,missing=amin, $
                       bound=[-rmax,-rmax,0,rmax],spacing=spacing*[0.1,0.1])
  amap=[amap,amap2]

  sz=size(amap) & nx=sz(1) & ny=sz(2)
  x=amap & y=x
  for i=0,ny-1 do x(*,i) = 2.*rmax*findgen(nx)/(nx-1) - rmax
  for i=0,nx-1 do y(i,*) = 2.*rmax*findgen(ny)/(ny-1) - rmax
  rad = sqrt(x^2+y^2)
  ind=where(rad lt rmin)
  amap(ind) = amin

  if keyword_set(pad) then begin
      mx = nx+2*pad & my = ny+2*pad
      aa=fltarr(mx,my) + amap(0,0)
      aa(pad:pad+nx-1,pad:pad+ny-1) = amap
      xx=findgen(mx) & yy=findgen(my)
      image_contour,xx=xx,yy=yy,aa,title=title,aspect=1,levels=min(amap),/noaxis
  endif else begin
      pad = 0
      xx=findgen(nx) & yy=findgen(ny)
      xx2=findgen(nx/2) & yy2=findgen(ny/2)
      if keyword_set(pm_scale) then begin          
          aa=bytscl0(amap)
          image_contour,xx=xx,yy=yy,aa,title=title,aspect=1,levels=min(amap),/noaxis
       ;   image_contour,xx=xx,yy=yy,aa,title=title,aspect=1,levels=bytsc10(levels),/noaxis
      endif else begin
          if keyword_set(mini) then begin
          if keyword_set(c_labels) then begin
           image_contour,xx=xx,yy=yy,amap,title=title,/noaxis, $
           mini=mini,maxi=maxi,aspect=1,levels=levels,c_labels=c_labels,c_thick=c_thick ; here
          endif else begin
           image_contour,xx=xx,yy=yy,amap,title=title,levels=min(amap),/noaxis, $
           mini=mini,maxi=maxi,aspect=1 ; here
          endelse
          endif else begin
           image_contour,xx=xx,yy=yy,amap,title=title,aspect=1,levels=min(amap),/noaxis 
          endelse ; mini
      endelse
      mx=nx & my=ny
  endelse

  if keyword_set(interface) then begin
     xx=findgen(101)/50.-1.     ; full circle
                                ; xx=findgen(101)/50.
     rt=rmin/rmax
     nn=200*5                   ;100
;     print,rt
     if (rbcz ne 0) then begin
        oplot,nn*(1+rbcz*xx),nn*(1+rbcz*(1-xx^2)^0.5),thick=3,line=2
        oplot,nn*(1+rbcz*xx),nn*(1-rbcz*(1-xx^2)^0.5),thick=3,line=2
     endif
     oplot,nn*(1+xx),nn*(1+(1-xx^2)^0.5),thick=3
     oplot,nn*(1+xx),nn*(1-(1-xx^2)^0.5),thick=3
     oplot,nn*(1+rt*xx),nn*(1+rt*(1-xx^2)^0.5),thick=3
     oplot,nn*(1+rt*xx),nn*(1-rt*(1-xx^2)^0.5),thick=3
     
; plot the small ticks every 15 degree
     nx=1001                    ;201 ;101
     plots,nx-1+(nx-1)*[1,1.025],[nx-1,nx-1],thick=3
     theta_tick=[15,30,45,60,75,90]*2*!pi/360.
     plots,nx-1-(nx-1)*[1,1.025],[nx-1,nx-1],thick=3
     for ii=0,5 do begin
        plots,nx-1+(nx-1)*[1,1.025]*cos(theta_tick(ii)),(nx-1)+(nx-1)*[1,1.025]*sin(theta_tick(ii)),thick=3
     plots,nx-1+(nx-1)*[1,1.025]*cos(theta_tick(ii)),(nx-1)+(nx-1)*[1,1.025]*sin(-1*theta_tick(ii)),thick=3
     plots,nx-1-(nx-1)*[1,1.025]*cos(theta_tick(ii)),(nx-1)+(nx-1)*[1,1.025]*sin(theta_tick(ii)),thick=3
     plots,nx-1-(nx-1)*[1,1.025]*cos(theta_tick(ii)),(nx-1)+(nx-1)*[1,1.025]*sin(-1*theta_tick(ii)),thick=3
  endfor     

    ; plot a line where corresponding polar slices is being shown
;     plots,nx-1-(nx-1)*[-1,1],[nx-1,nx-1],line=1,thick=3
;     plots,nx-1-(nx-1)*[-1,-0.07],[nx-1,nx-1],line=2,thick=3 ; phi=0

  endif

end








