function legendre_collocation_pts, ntheta
    meps=2d0^((machar(/double)).machep)
    points = dblarr(ntheta)
    weights = dblarr(ntheta)
    for n=0L,ntheta/2-1L do begin
        guess = cos(!dpi*(n+0.75d0)/(double(ntheta)+0.5d0))
        old_guess = -2d0
        while (abs(guess-old_guess) gt meps) do begin
            pn_m1 = 1d0
            pn = guess
            for il=1L,ntheta-1L do begin
                dil = double(il)+1d0
                pn_p1=((2d0*dil-1d0)*guess*pn-(dil-1d0)*pn_m1)/dil
                pn_m1=pn
                pn=pn_p1
            end
            pderiv=ntheta*(guess*pn-pn_m1)/(guess^2-1d0)
            old_guess = guess
            guess = guess-pn/pderiv
        endwhile
        pderiv=ntheta*(guess*pn-pn_m1)/(guess^2-1d0)
        points[n] = guess
        points[ntheta-n-1L] = -guess
        w = 2d0/((1d0-guess^2)*pderiv^2)
        weights[n] = w
        weights[ntheta-n-1L] = w
    endfor

    arr = [points,weights]

    return, arr
end

function build_ftransform, costheta, weights
    nth = n_elements(costheta)
    lmax = (2L*nth-1L)/3L

    ftrans = dblarr(nth,lmax+1)

    P_lm2=1d0/sqrt(4d0*!dpi)
    P_lm1=P_lm2*costheta*sqrt(3d0)
    ftrans[*,0] = weights*P_lm2
    ftrans[*,1] = weights*P_lm1
    for il=2L,lmax do begin
       lr=double(il)
       c1=sqrt(4d0-1/lr^2)
       c2=-(1-1/lr)*sqrt((2*lr+1)/(2*lr-3))
       P_l=c1*costheta*P_lm1+c2*P_lm2
       
       ftrans[*,il] = weights*P_l
       P_lm2=P_lm1
       P_lm1=P_l
    endfor

    return, ftrans
end

function legendre_forward_transform, arr, costheta, weights
    nth = n_elements(costheta)
    lmax = (2L*nth-1L)/3L
    Plm1 = 1d0+0d0*costheta
    Pl = costheta

    coefs = dblarr(lmax+1)

    P_lm2=1d0/sqrt(4d0*!dpi)
    P_lm1=P_lm2*costheta*sqrt(3d0)
    coefs[0]=total(arr*P_lm2*weights,/double) ;  set l=0 m=0 term
    
    coefs[1]=total(arr*P_lm1*weights,/double) ;  set l=1 m=0 term

    for l=2L,lmax do begin
        lr=double(l)
        c1=sqrt(4d0-1/lr^2)
        c2=-(1-1/lr)*sqrt((2*lr+1)/(2*lr-3))
        P_l=c1*costheta*P_lm1+c2*P_lm2
        coefs[l]=total(arr*P_l*weights,/double) ;  set m=0 term for all other l's
        P_lm2=P_lm1
        P_lm1=P_l
    endfor

    return, coefs
end

function build_btransform, costheta
    nth = n_elements(costheta)
    lmax = (2L*nth-1L)/3L
    Plm1 = 1d0+0d0*costheta
    Pl = costheta

    btrans = dblarr(nth,lmax+1)

    P_lm2=1d0/sqrt(4d0*!dpi)
    P_lm1=P_lm2*costheta*sqrt(3d0)
    btrans[*,0] = P_lm2
    btrans[*,1] = P_lm1
    for il=2L,lmax do begin
       lr=double(il)
       c1=sqrt(4d0-1/lr^2)
       c2=-(1-1/lr)*sqrt((2*lr+1)/(2*lr-3))
       P_l=c1*costheta*P_lm1+c2*P_lm2
       
       btrans[*,il] = P_l
       P_lm2=P_lm1
       P_lm1=P_l
    endfor
    btrans = 2d0*!dpi*btrans
    return, btrans
end

function build_dmatrix, costheta
    ntheta = n_elements(costheta)
    csctheta = 1d0/sqrt(1d0-costheta^2)
    lmax = (2*ntheta-1)/3
    Dl = dblarr(lmax+1)
    for il=1,lmax do begin
       dil = double(il)
       Dl[il] = dil/sqrt((2d0*dil-1d0)*(2d0*dil+1d0))
    endfor

    al = 0d0*Dl
    bl = 0d0*Dl
    for il=0L,lmax-1L do begin
       dil = double(il)
       al[il] = -(dil+1d0)*Dl[il]
       bl[il] = dil*Dl[il+1L]
    endfor
    al[lmax] = -(double(lmax)+1d0)*Dl[lmax]

    ;Legendre Derivative
    deriv = dblarr(lmax+1,lmax+1)
    deriv[1,0] = al[1]
    for il=1L,lmax-1L do begin
       deriv[il-1L,il] = bl[il-1L]
       deriv[il+1L,il] = al[il+1L]
    endfor
    il=lmax
    deriv[il-1L,il] = bl[il-1L]

    return, deriv
end

pro test_legendre, ntheta

  pts = legendre_collocation_pts(ntheta)
  ct = pts[0:ntheta-1]
  st = sqrt(1d0-ct^2)
  wt = pts[ntheta:*]

  ;arr = 0.25d0*sqrt(7d0/!dpi)*(5d0*ct^2-3d0)*ct
  ;ans = -0.75d0*sqrt(7d0/!dpi)*(5d0*ct^2-1d0)*st

  ;arr = arr + 0.25d0*sqrt(5d0/!dpi)*(3d0*ct^2-1d0)
  ;ans = ans - 1.5d0*sqrt(5d0/!dpi)*ct*st

  ;arr = arr + 0.5d0*sqrt(3d0/!dpi)*ct
  ;ans = ans - 0.5d0*sqrt(3d0/!dpi)*st
  arr = ct
  ans = -st

  ft = build_ftransform(ct,wt)
  dt = build_dmatrix(ct)
  bt = build_btransform(ct)

  darr = bt#reform(dt##(ft##reform(arr)))
  darr = darr/st

  lmax = (2*ntheta-1)/3

  ell = dindgen(lmax+1)
  eep1 = -1d0/(ell*(ell+1d0))
  eep1[0] = 0d0
  aphi = (bt#reform(dt##(eep1*(ft##arr))))/st
  
  aphiex = -0.5d0*ans

  stop

end
