;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;     movie_azav2.pro  - Make movie with azav
; 
;     usage:  movie_eqsl2,dir,qq,sq,recperfile,nbf,start,jump,glob=glob,
;                          sc=sc,notquiet=notquiet,swap=swap,psf=psf,
;                          namepsf=namepsf,wnd,legendd=legendd,tv=tv,
;                          rbcz=rbcz,vmin=vmin,vmax=vmax,base=base,to=to
;            where dir        = data directory
;                  qq         = quantity index 
;                  sq         = statistical quantity ([0,1,2,3]= 
;                               [0,vrms,mean,log]) 
;                  recperfile = number of record per file
;                  nbf        = number of files to read
;                  start      = first iteration
;                  jump       = number of iterations between two files 
;                  rbcz       = dashed line for the base of convective
;                  zone
;                  to         = offset time
;                  base       = not to begin output filename at 0
;                  glob       = prefix of data directory
;                  sc         = prefix of filenames
;                  notquiet   = verbose if smaller then 2
;                  swap       = dependant on the endianess of files
;                  psf        = type of output (screen or .eps)
;                  namepsf    = name of the .eps output file  
;                  wnd        = number of the window for screen output
;                  legendd    = legend is set if 0 and is hidden either
;                  tv         = set if image rather than contour plot
;                               is desired  
; 
;  C.Emeriau-Viard - 22 Sept 2016 - Version 2.0
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

pro movie_azav2,dir,qq,sq,recperfile,nbf,start,jump,rbcz=rbcz,base=base,to=to,$
                glob=glob,sc=sc,notquiet=notquiet,swap=swap,psf=psf,namepsf=namepsf,$
                wnd=wnd,legendd=legendd,tv=tv
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;   Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 7 then begin
     print,'movie_azav2,dir,qq,sq,recperfile,nbf,start,jump,rbcz=rbcz,'+$
           'base=base,to=to,glob=glob,sc=sc,notquiet=notquiet,swap=swap,'+$
           'psf=psf,namepsf=namepsf,wnd=wnd,legendd=legendd,tv=tv,rbcz=rbcz,base=base'
     return
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set default values
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  movie_azav2.pro:  parameter dir must be set'
     return
  endif

  if n_elements(qq) eq 0 then begin
     print,'  movie_azav2.pro:  parameter qq must be set'
     return
  endif

  if n_elements(sq) eq 0 then begin
     print,'  movie_azav2.pro:  parameter sq must be set'
     return
  endif

  if n_elements(recperfile) eq 0 then begin
     print,'  movie_azav2.pro:  parameter recperfile must be set'
     return
  endif

  if n_elements(nbf) eq 0 then begin
     print,'  movie_azav2.pro:  parameter nbf must be set'
     return
  endif
  
  if n_elements(start) eq 0 then begin
     print,'  movie_azav2.pro:  parameter start must be set'
     return
  endif

  if n_elements(jump) eq 0 then begin
     print,'  movie_azav2.pro:  parameter jump must be set'
     return
  endif

  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 0
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(namepsf)  then namepsf  = ''
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(legendd)  then legendd  = 0
  if not keyword_set(tv)       then tv       = 1
  if not keyword_set(rbcz)     then rbcz     = 0
  if not keyword_set(base)     then base     = 0

  if glob eq 0 then begin
     dir = '/dsm/stars2/f/cemeriau/EvolZR/'+dir
  endif

  print,'NBF : ',nbf
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if psf eq 0 then  device,decomposed=0
  device,set_font='Helvetica',/tt_font
  loadct_mld,41

  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Creation of the file list
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  dend  = start + nbf*jump
  i     = start
  filel = list()
  while (i lt dend) do begin
     filel.Add,string(i,format='(I6)')
     i=i+jump
  endwhile
  
  i=long(0)
  k=long(base)
  while i lt nbf do begin
     print,'Loop 1 : ',i
     close,/all
     j = long(0)
     while j lt recperfile do begin 
        it = long(start+i*jump)
        namepsf = 'AZAV_'
        if k lt 10 then begin
           namepsf=namepsf+'000'+strcompress(k,/r)
        endif else begin
           if k lt 100 then begin
              namepsf=namepsf+'00'+strcompress(k,/r)
           endif else begin
              if k lt 1000 then begin
                 namepsf=namepsf+'0'+strcompress(k,/r)
              endif else begin
                 namepsf=namepsf+strcompress(k,/r)
              endelse
           endelse
        endelse
        see_azav2,dir,qq,sq,it,j,tv=1,rbcz=rbcz,swap1=swap,notquiet=2,namepsf=namepsf,psf=psf,to=to,wnd=wnd,glob=1,radial_plot=1,sc=sc
        j=j+1
        k=k+1
     endwhile
     i = i + 1
  endwhile                      ; it 
  
  !p.multi = 0
  
end







