;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;     movie_eqsl2.pro  - Make movie with eqsl
; 
;     usage: movie_eqsl2,dir,qq,sq,recperfile,nbf,start,jump,depth=depth,
;                         base=base,to=to,glob=glob,sc=sc,notquiet=notquiet,
;                         swap=swap,psf=psf,namepsf=namepsf,wnd=wnd,
;                         legendd=legendd,tv=tv,vmin=vmin,vmax=vmax
;            where dir        = data directory
;                  qq         = quantity index 
;                  sq         = statistical quantity ([0,1,2,3]= 
;                               [0,vrms,mean,log]) 
;                  recperfile = number of record per file
;                  nbf        = number of files to read
;                  start      = first iteration
;                  jump       = number of iterations between two files 
;                  rstar      = stellar radius
;                  depth      = radius of the shell if negative use 
;                               shsl instead of shsl_envision with
;                               icutmax = -depth
;                  base       = not to begin output filename at 0
;                  to         = 0-time
;                  glob       = prefix of data directory
;                  sc         = prefix of filenames
;                  notquiet   = verbose if smaller then 2
;                  swap       = dependant on the endianess of files
;                  psf        = type of output (screen or .eps)
;                  namepsf    = name of output file
;                  wnd        = number of the window for screen output
;                  legendd    = legend is set if 0 and is hidden either
;                  tv         = set if image rather than contour plot
;                               is desired  
;                  ortho      = type of projection of the sphere (0/1/2)
; 
;  C.Emeriau-Viard - 06 June 2016 - Version 2.0
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names

pro movie_shsl2,dir,qq,sq,recperfile,nbf,start,jump,rstar=rstar,depth=depth,$
                 base=base,to=to,glob=glob,sc=sc,notquiet=notquiet,swap=swap,$
                 namepsf=namepsf,wnd=wnd,legendd=legendd,tv=tv,ortho=ortho
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;   Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 7 then begin
     print,' movie_shsl2,dir,qq,sq,recperfile,nbf,start,jump,rstar=rstar,'+$
           'depth=depth,base=base,to=to,glob=glob,sc=sc,notquiet=notquiet,'+$
           'swap=swap,psf=psf,namepsf=namepsf,wnd=wnd,legendd=legendd,tv=tv,ortho=ortho'
     return
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set default values
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  movie_shsl2.pro:  parameter dir must be set'
     return
  endif

  if n_elements(qq) eq 0 then begin
     print,'  movie_shsl2.pro:  parameter qq must be set'
     return
  endif

  if n_elements(sq) eq 0 then begin
     print,'  movie_shsl2.pro:  parameter sq must be set'
     return
  endif

  if n_elements(recperfile) eq 0 then begin
     print,'  movie_shsl2.pro:  parameter recperfile must be set'
     return
  endif

  if n_elements(nbf) eq 0 then begin
     print,'  movie_shsl2.pro:  parameter nbf must be set'
     return
  endif
  
  if n_elements(start) eq 0 then begin
     print,'  movie_shsl2.pro:  parameter start must be set'
     return
  endif

  if n_elements(jump) eq 0 then begin
     print,'  movie_shsl2.pro:  parameter jump must be set'
     return
  endif

  if not keyword_set(rstar)    then rstar    = 1
  if not keyword_set(depth)    then depth    = 0
  if not keyword_set(base)     then base     = 0
  if not keyword_set(to)       then to       = 0
  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 0
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  psf = 1
  if not keyword_set(namepsf) then begin
     if depth ge 0 then namepsf  = 'SHSL_envision_' else namepsf = 'SHSL_'
  endif else if namepsf eq '' then begin
     if depth ge 0 then namepsf  = 'SHSL_envision_' else namepsf = 'SHSL_'
  endif
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(legendd)  then legendd  = 0
  if not keyword_set(tv)       then tv       = 1
  if not keyword_set(ortho)    then ortho    = 0

  if glob eq 0 then begin
     dir = '/dsm/stars2/f/cemeriau/'+dir
  endif

  print,'NBF : ',nbf
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Creation of the file list
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  dend  = start + nbf*jump
  i     = start
  filel = list()
  while (i lt dend) do begin
     filel.Add,string(i,format='(I6)')
     i=i+jump
  endwhile

  i=long(0)
  k=long(base)
  while i lt nbf do begin
     close,/all
     j = long(0)
     while j lt recperfile do begin 
        it = long(start+i*jump)
        if k lt 10 then begin
           namepsf1=namepsf+'000'+strcompress(k,/r)
        endif else begin
           if k lt 100 then begin
              namepsf1=namepsf+'00'+strcompress(k,/r)
           endif else begin
              if k lt 1000 then begin
                 namepsf1=namepsf+'0'+strcompress(k,/r)
              endif else begin
                 namepsf1=namepsf+strcompress(k,/r)
              endelse
           endelse
        endelse
        qqq=qq
        if depth ge 0 then see_envision_shsl2,dir,qqq,sq,it,j,depth=depth,rstar=rstar,to=to,glob=1,sc=sc,notquiet=2,swap=swap,psf=psf,namepsf=namepsf1,tv=tv,ortho=ortho $
        else see_shsl2,dir,qqq,sq,it,j,icutmax=-depth,lc=lc,rstar=rstar,to=to,glob=1,sc=sc,notquiet=2,swap=swap,psf=psf,namepsf=namepsf1,tv=tv,ortho=ortho
        j=j+1
        k=k+1
     endwhile
     i = i + 1
  endwhile                      ; it 
  
  !p.multi = 0
  
end







