;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names
@get_units
@colourbar

pro movie_strl_mag_bp2,dir,recper,nfiles,start,skip,fill=fill,swap=swap,psf=psf,$
                      extrapol=extrapol,notquiet=notquiet,wnd=wnd,name=name,base=base
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Usage message 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 2 then begin
     print,''
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  movie_strl_mag_bp.pro:  parameter dir must be set'
     return
  endif

  if nfiles eq 0 or skip eq 0 then begin
     if files(0) eq -1 then files=findfile(dir)
     firstchar=byte(strmid(files,0,1))
     wh=where((firstchar ge 48b) and (firstchar le 57))
     if wh lt 0 then begin
        print,'  movie_strl_mag_bp.pro:  directory does not contain any valid files'
        return
     endif
     files=long(files(wh))
     nfiles=n_elements(files)
  endif else begin
     files  = lindgen(nfiles)*skip+start
     nfiles = size(files) & nfiles = nfiles(1)
  endelse

  if not keyword_set(glob)      then glob     = 0
  if not keyword_set(sc)        then sc       = 1
        
  if not keyword_set(fill)      then fill     = 0
  if not keyword_set(swap)      then swap     = 0
  if not keyword_set(psf)       then psf      = 0
  if not keyword_set(extrapol)  then extrapol = 0 ;check imagepolar rmax to get correct sizing between contour plot a nd lines
  if not keyword_set(rbcz)      then rbcz     = 0
  if not keyword_set(notquiet)  then notquiet = 0
  if not keyword_set(swap)      then swap     = 0
  if not keyword_set(wnd)       then wnd      = 0
  if not keyword_set(name)      then name     = 'Bp_Test'
  if not keyword_set(base)      then base     = 0

  if glob eq 0 then begin
     dir='/dsm/stars2/f/cemeriau/EvolZR/'+dir
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^       
; Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^       
  
  close,/all
  interface1 = 0

  window,wnd,xs=800,ys=640

  daysflag=1
  device,decomposed=0

  levs=[-250.0,-100,-50.0,-25.0,-10.0,-5.0,-2.5,-1.0,-0.5,-0.1,-0.01,-0.001,0.001,0.01,0.1,0.5,1.0,2.5,5.0,10.0,25.0,50.0,100.0,250.0]
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Set up filename array, etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  textnum = strcompress(files,/r)
  
  case sc of 
     1: file=dir+'AZAV/azav_0'+textnum
     2: file=dir+'0'+textnum
     else: file=dir+textnum
  end

  nt=intarr(nfiles)
  nt(*) = recper
  nframes = total(nt) & print,'nb of frames',nframes

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  associate data file
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  qq1 = 61 & qq2 = 62 & qq3 = 63

  read_azav2,qq1,file(0),0,time=to,rad=radius,theta=theta,notquiet=notquiet

  n_r1 = size(radius)    & n_r1 = n_r1(1)
  n_theta1 = size(theta) & n_theta1 = n_theta1(1)

  costheta = cos(theta)
  sintheta = sin(theta)
  lat      = 90.-acos(costheta)*!radeg

  if (daysflag eq 1) then to=to/(3600.*24d0)
  print,'initial time',to

;  q1 = where(quantities eq qq1)+1 & q2 = where(quantities eq qq2)+1
  title1 = get_name2(61) & title2 = get_name2(62)
  if notquiet le 1 then print,title1,', ',title2
  
  r1  = radius       & ct1 = costheta
  r1b = dblarr(N_R1) & r1c = dblarr(2*N_R1) & aa=1.5d0
  r1b = r1(0)*(1.0+aa*findgen(N_R1)/(N_R1-1))
  
  for i=N_R1,2*N_R1-1 do r1c(i)=r1b(i-N_R1)
  for i=0,N_R1-1 do r1c(N_R1-1-i)=r1(i)
  r1d    = r1c/r1(0)
  theta1 = acos(ct1)
  
  factt=1e0                     ; multiplying factor
  single=0
  if single eq 1 then begin
     r1x=r1/r1(0)
     read_azav2,qq1,file(0),0,time=to,rad=radius,theta=theta,time=to,f=Vr1,notquiet=notquiet
     read_azav2,qq2,file(0),0,time=to,rad=radius,theta=theta,time=to,f=Vtheta1,notquiet=notquiet
     
     Mr1x = fltarr(N_Theta1,N_R1) & Mtheta1x=Mr1x
     for i=0,N_R1-1 do begin
        Mr1x(*,i)     = factt*Vr1(*,i,2)
        Mtheta1x(*,i) = factt*Vtheta1(*,i,2) ;???
     endfor

     psi1x=streamfunction(Mr1x,Mtheta1x,r1x,ct1)
     
     xs=4.0 & ys=3.8
     !p.multi=[0,2,1]
     
     !p.thick=2.0
     !p.charthick=1.0
     xyouts,0,0,'!17'
     
     y1 = .02 & y2 = .98
     x1 = .02 & x4 = .98
     
     dy = y2-y1
     dx = 0.5*dy * (ys/xs)
     x2 = x1+dx & x3 = x4-dx
     
     !p.position=[x1,y1,x2,y2]
     
     con_pol_spiffy_mag,psi1x(*,0:N_R1-1),r1x(0:N_R1-1),ct1,inter=interface1,fill=fill,r_extra=1 ;,levels=levs
     stop
  endif                         ; single

  ind = 0 & idn=0 & idx=N_theta1-1
  
;  q3     = where(quantities eq qq3)+1
  title3 = get_name2(qq3) & if notquiet le 1 then print,title3
  
  for ifile=0,nfiles-1 do begin
     for it = 0,nt(ifile)-1 do begin

        read_azav2,qq1,file(ifile),it,f=Vr1,rad=rad,theta=theta,name=title1,$
                   time=time,deltat=deltat,iteration=iteration,notquiet=notquiet,swap=swap
        read_azav2,qq2,file(ifile),it,f=Vtheta1,name=title2,notquiet=notquiet
        read_azav2,qq3,file(ifile),it,f=Vphi,name=title3,notquiet=notquiet

        if (daysflag eq 1) then time=time/(3600.*24d0)
        print,'  iteration = ',strtrim(iteration,2),$
              ', time = '   ,strtrim(time-to ,2),$
              ', delta t = ',strtrim(deltat   ,2)
        
        print,'frame number: ',ind
               
        if notquiet le 1 then print,title1,', ',title2

        if extrapol eq 0 then begin
           Mr1 = fltarr(N_Theta1,N_R1) & Mtheta1=Mr1
           Mr1=factt*Vr1 & Mtheta1=factt*Vtheta1 & r1d=r1/r1(0)
        endif else begin
           Mr1 = fltarr(N_Theta1,2*N_R1) & Mtheta1=Mr1
           Vr1_in=factt*Vr1(*,*) & Vtheta1_in=factt*Vtheta1(*,*)
           Vr1=Mr1 & Vtheta1=Mr1
        endelse
        
        if extrapol eq 1 then begin ; be careful index for 0,N_R1-1 -> Rsurf,Rbot so we need to reverse it
           for i=0,N_R1-1 do begin
              Vr1(*,i)=Vr1_in(*,N_R1-1-i)
              Vtheta1(*,i)=Vtheta1_in(*,N_R1-1-i)
           endfor
           
           Brtop1=double(Vr1(*,N_R1-1)) 
           
           M = 20 ; ???
           coeff = SVDFIT(ct1,Brtop1,M,chisq=chi1b,/double,/legendre,y=ytest) ; func='flegendre')
           print,'chi: ',chi1b

           Vr1(*,N_R1:2*N_R1-1)=0.0 & Vtheta1(*,N_R1:2*N_R1-1)=0.0
           
           for l=1,M-2 do begin
              ell=double(l)     ;& print,ell
              Rl=ell/sqrt(4.d0*ell^2.d0-1.d0) & Rlp1=double(l+1.d0)/sqrt(4.d0*double(l+1.d0)^2.d0-1.d0)
              plend=legendre(ct1,l) ;der_p=deriv(theta1,plend)
              
              rtp1=r1d(N_R1-1)^(ell-1.d0) & rtp2=r1d(N_R1-1)^(-(ell+2.d0)) & rss1=r1d(2*N_R1-1)^(-(2.d0*ell+1.d0))
              rtpm1=r1d(N_R1-1)^(ell-2.d0) & rtpm2=r1d(N_R1-1)^(-(ell+1.d0)) & rssm1=r1d(2*N_R1-1)^(-(2.d0*ell-1.d0))
              rtpp1=r1d(N_R1-1)^ell & rtpp2=r1d(N_R1-1)^(-(ell+3.d0)) & rssp1=r1d(2*N_R1-1)^(-(2.d0*ell+3.d0))
              
              Blm=coeff(l)/(ell*rss1*rtp1+(ell+1.d0)*rtp2)
              Alm=-Blm*rss1
              Blmp1=coeff(l+1)/((ell+1.d0)*rssp1*rtpp1+(ell+2.d0)*rtpp2)
              Almp1=-Blmp1*rssp1
              Blmm1=coeff(l-1)/((ell-1.d0)*rssm1*rtpm1+ell*rtpm2)
              Almm1=-Blmm1*rssm1
              
                                ; if source term at rs=rtop from surf, plotting pb!, 2.5 rtop ok
              Alm=0.d0 & Almm1=0.d0 & Almp1=0.d0 ; no source term when Alm's=0 
              
              for i=0,N_theta1-1 do begin
                 for j=N_R1,2*N_R1-1 do begin                       
                    Vr1(i,j)     = Vr1(i,j)-(Alm*ell*r1d(j)^(ell-1.d0)-Blm*(ell+1.d0)/r1d(j)^(ell+2.d0))*plend(i) 
                    Vtheta1(i,j) = Vtheta1(i,j)+Rl*(ell-1.d0)*(Almm1*r1d(j)^(ell-1.d0)+Blmm1/r1d(j)^ell)
                    Vtheta1(i,j) = Vtheta1(i,j)-Rlp1*(ell+2.d0)*(Almp1*r1d(j)^(ell+1.d0)+Blmp1/r1d(j)^(ell+2.d0))
                    Vtheta1(i,j) = -Vtheta1(i,j)*plend(i)/r1d(j)/sin(theta1(i))
                 endfor
              endfor 
           endfor
           
           for i=0,2*N_R1-1 do begin
              Mr1(*,i)     = Vr1(*,i)
              Mtheta1(*,i) = Vtheta1(*,i)
           endfor
           
        endif                   ; extrapol
        
        psi1=streamfunction(Mr1,Mtheta1,r1d,ct1)
        
        print,min(psi1),max(psi1)

        xs=4.0 & ys=3.8
        !p.multi=[0,2,1]
        
        if psf eq 1 then set_plot,'ps'

        ind2 = ind + base

        if ((fill eq 1) and (psf ne 1)) then begin

           if (nframes le 99) then begin
              if (ind2 lt 10) then name1=name+'0'+strcompress(ind2,/r)+'.bmp' $
              else name1=name+strcompress(ind2,/r)+'.bmp'
           endif else if (nframes le 999) Then begin
              if (ind2 lt 10) then begin
                 name1=name+'00'+strcompress(ind2,/r)+'.bmp' 
              endif else if (ind2 lt 100) then begin 
                 name1=name+'0'+strcompress(ind2,/r)+'.bmp'
              endif else begin
                 name1=name+strcompress(ind2,/r)+'.bmp'
              endelse
           endif else begin
              if (ind2 lt 10) then begin
                 name1=name+'000'+strcompress(ind2,/r)+'.bmp'  
              endif else if (ind2 lt 100) then begin 
                 name1=name+'00'+strcompress(ind2,/r)+'.bmp'
              endif else if (ind2 lt 1000) then begin 
                 name1=name+'0'+strcompress(ind2,/r)+'.bmp'
              endif else begin
                 name1=name+strcompress(ind2,/r)+'.bmp'
              endelse
           endelse
           
        endif else if psf eq 1 then begin
           
           if (nframes le 99) then begin
              if (ind2 lt 10) then name1=name+'0'+strcompress(ind2,/r)+'.ps' $
              else name1=name+strcompress(ind2,/r)+'.ps'
           endif else if (nframes le 999) Then begin
              if (ind2 lt 10) then begin
                 name1=name+'00'+strcompress(ind2,/r)+'.ps' 
              endif else if (ind2 lt 100) then begin 
                 name1=name+'0'+strcompress(ind2,/r)+'.ps'
              endif else begin
                 name1=name+strcompress(ind2,/r)+'.ps'
              endelse
           endif else begin
              if (ind2 lt 10) then begin
                 name1=name+'000'+strcompress(ind2,/r)+'.ps'  
              endif else if (ind2 lt 100) then begin 
                 name1=name+'00'+strcompress(ind2,/r)+'.ps'
              endif else if (ind2 lt 1000) then begin 
                 name1=name+'0'+strcompress(ind2,/r)+'.ps'
              endif else begin
                 name1=name+strcompress(ind2,/r)+'.ps'
              endelse
           endelse
           
           device,filename=name1,/color,bits=8,xs=17.5,ys=18,yoffset=1
           
        endif
        
        !p.thick=2.0
        !p.charthick=1.0
        xyouts,0,0,'!17'
        
        y1 = .02 & y2 = .98
        x1 = .02 & x4 = .98
        
        dy = y2-y1
        dx = 0.5*dy
        x2 = x1+dx & x3 = x4-dx
        
        !p.position=[x1,y1,x2,dy]
        
        omega = 1 ;???
        Global_rate=2.6d-6*omega
        if qq3 eq 3 then begin
           for i=0,N_R1-1 do begin
              Vphi(*,i)=Vphi(*,i)/radius(i)/sin(acos(costheta(*)))+Global_rate
           endfor
           vphi=vphi/2./!pi*1e9 ; s^-1 -> nHz
        endif
        
        if ind eq 0 then begin
           minil=min(vphi) & maxil=max(vphi)
           print,'mini, maxi',minil,maxil
           ans1=0
           print,' '
           print,'Do you want to keep these min and max values (0/1)?',minil,maxil
           read,ans1
           if (ans1 eq 1) then begin
              print,'enter new values, min first'
              read,minil,maxil
           endif
           
           if qq3 eq 3 then begin
              levels=350+findgen(30)*5 ; 300 with 17 index implies index 14
              levels(13)=fix(Global_rate/2./!pi*1e9)
              c_labels1 = levels*0.0 
              c_labels1(13)=1 
              c_labels1(16)=1
              c_labels1(19)=1
              c_labels1(22)=1
              c_labels1(10)=1
              c_labels1(7)=1
              c_labels1(4)=1
                                ;c_thick=[1,1]
                                ; print,levels
           endif else begin
              levels=[-5000,-2500,-1000,-500,-250,-100,100,250,500,1000,2500,5000]
              c_labels1=levels*0.0
           endelse
        endif                   ; ind
        
        loadct_mld,41
        
        if extrapol eq 1 then begin
           print,max(r1c),max(radius)/max(r1c)
           factt=max(radius)/max(r1c)
           image_polar_b,vphi(idn:idx,*),radius,costheta(idn:idx),sp=sp,mini=minil,maxi=maxil,rbcz=rbcz,r_extra=2.5,levels=levels,c_thick=c_thick,c_labels=c_labels1
        endif else begin
           image_polar_b,vphi(idn:idx,*),radius,costheta(idn:idx),sp=sp,mini=minil,maxi=maxil,rbcz=rbcz,levels=levels,c_thick=c_thick,c_labels=c_labels1 ;,/noborder
        endelse
;endelse
        
        if fill eq 1 then begin
           !p.position=[x1,y1,x2*0.8,dy]
        endif else if psf eq 1 then begin
           !p.position=[x1,y1,x2,dy*0.99]
        endif else begin
           !p.position=[x1,y1,x2*0.8,dy]
        endelse
        
        if extrapol eq 1 then begin
           con_pol_spiffy_mag,psi1(*,0:2*N_R1-2),r1d(0:2*N_R1-2),ct1,inter=interface1,fill=0,levels=levs,/noborder ;,title='Poloidal Field B'
        endif else begin
           con_pol_spiffy_mag,psi1(*,0:N_R1-2),r1d(0:N_R1-2),ct1,inter=interface1,fill=0,r_extra=1.0,levels=levs,/noborder ;,clabels=clabels;,title='Poloidal Field B'
        endelse
        
        if fill eq 1 then begin
           xyouts,(x4-x1)/4.,0.02,'Rad Dynamo Case, t= '+strtrim(string(time-to,format='(g10.4)'),2)+' days',/normal,align=0.5
        endif else if psf eq 1 then begin
           to=0.0 & print,'attention mis to a 0'
           xyouts,(x4-x1)/3.,0.01,'Antoine s Tacho Case, t= '+strtrim(string(time-to,format='(g10.4)'),2)+' d',/normal,align=0.5
        endif
        
        ind = ind + 1
        
        if ((fill eq 1) and (psf ne 1)) then begin
           tvlct,r,g,b,/get
           image_azav=tvrd()
           write_bmp,name1,image_azav,r,g,b ;bytscl(image_azav,max=255)
        endif else if psf eq 1 then begin
           device,/close
        endif
        
     endfor                     ; it
  endfor                        ; ifiles
  
  if psf eq 1 then begin
     set_plot,'x'
  endif
  
  !p.multi=0
  !p.position=0
  
  stop
  
end









