;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  read_scalar2.pro - Reads scalar files
;
;      usage : read_scalar2,qq,file,recnum,sq,f=f,
;              time=time,deltat=deltat,name=name,
;              notquiet=notquiet,swap=swap
; 
;              where qq       = output quantity
;                    file     = filename
;                    recnum   = record number
;                    sq       = statistical quantity ([1,2,3] = [mean,min,max])
;                    f        = output quantity (scalar in that routine)
;                    time     = output time
;                    dt       = time-step
;                    name     = quantity name
;                    notquiet = verbose if smaller than 2
;                    swap     = dependant of the endianess of the file        
; 
;  M.DeRosa - 25 Aug 1998 - modified from Mark's version
;  C.Emeriau-Viard - 13 May 2016 - Version 2.0
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

pro read_scalar2,qq,file,recnum,sq,f=f,time=time,deltat=deltat,name=name,$
                notquiet=notquiet,swap=swap
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 4 then begin
     print,'read_scalar2,qq,file,recnum,sq,f=f,time=time,deltat=deltat,'+$
           'name=name,notquiet=notquiet,swap=swap'
     return
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
;  Check parameters, set defaults          
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  close,/all

  if n_elements(qq) eq 0 then begin
     print,'  read_scalar2.pro:  parameter qq is not set'
     return
  endif
  if n_elements(file) eq 0 then begin
     print,'  read_scalar2.pro:  parameter file is not set'
     return
  endif
  if n_elements(recnum) eq 0 then begin
     print,'  read_scalar2.pro:  parameter recnum is not set'
     return
  endif
  if n_elements(sq) eq 0 then begin
     print,'  read_scalar2.pro:  parameter sq is not set'   
     return
  endif

  if qq lt 1 then begin
     print,'  read_scalar2.pro:  q must be greater than 0'
     return
  endif

  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0

; ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Associate data file
; ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  temp=0.0
  openr,lun,file,/g,swap_endian=swap
  readu,lun,temp
  n_totals = fix(temp)          ;  total number of output quantities
  scalar = assoc(lun,fltarr(4,n_totals+1,/nozero))



; ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Read code quantities
; ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  quantities = scalar(3,*,0)     ;  code number of output quantity of interest
  
  q = where(quantities eq qq)+1
  while (q eq 0) do begin
     print,"This quantity does not exist : ",qq
     print,quantities
     print,"Please, enter a new one :"
     read,qq
     q=where(quantities eq qq)+1
  endwhile
  name = get_scalar_name2(qq)

; ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Read in scalar data
; ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  time = scalar(1,0,recnum)      ; time index in seconds
  dt   = scalar(2,0,recnum)      ; time-step

  f    = scalar(sq-1,q,recnum)   ; quantity of interest

  free_lun,lun
  if (notquiet lt 1) then begin 
     print,name 
     stop
  endif

end
