;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
;   see_amom_avgs12b - Plot amom balance
; 
;       usage: see_amom_avgs12b,dir,recper,nfiles,start,jump,gr=gr,mag=mag,
;              rstar=rstar,rbcz=rbcz,zoomm=zoomm,glob=glob,sc=sc,
;              notquiet=notquiet,swap=swap,opl=opl,psf=psf,namepsf=namepsf,
;              wnd=wnd,legendd=legendd,tv=tv
; 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
@get_names

pro see_amom_avgs12b,dir,recper,nfiles,start,jump,mag=mag,gr=gr,rstar=rstar,$
                     rbcz=rbcz,zoomm=zoomm,glob=glob,sc=sc,notquiet=notquiet,$
                     swap=swap,opl=opl,psf=psf,namepsf=namepsf,wnd=wnd,$
                     legendd=legendd,tv=tv
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 5 then begin
     print,'see_amom_avgs12b,dir,recper,nfiles,start,jump,mag=mag,gr=gr,'+$
           'rstar=rstar,rbcz=rbcz,zoomm=zoomm,glob=glob,sc=sc,notquiet=notquiet,'+$
           'swap=swap,opl=opl,psf=psf,namepsf=namepsf,wnd=wnd,legendd=legendd,tv=tv'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  see_scalar2.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  if n_elements(recper) eq 0 then begin
     print,'  see_scalar2.pro:  parameter recper must be set'
     return
  endif else recordsperfile=recper

  if nfiles eq 0 or jump eq 0 then begin
     if files(0) eq -1 then files=findfile(dir)
     firstchar=byte(strmid(files,0,1))
     wh=where((firstchar ge 48b) and (firstchar le 57))
     if wh lt 0 then begin
        print,'  see_scalar2.pro:  directory does not contain any valid files'
        return
     endif
     files=long(files(wh))
     nfiles=n_elements(files)  
  endif else begin
     files=lindgen(nfiles)*jump+start
  endelse

  if not keyword_set(mag)      then mag      = 0
  if not keyword_set(gr)       then gr       = 1
  if not keyword_set(rstar)    then rstar    = 1
  if not keyword_set(rbcz)     then rbcz     = 0
  if not keyword_set(zoomm)    then zoomm    = 0
  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 1
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(opl)      then opl      = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(namepsf)  then namepsf  = "AMOM"
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(legendd)  then legendd  = 0
  if not keyword_set(daysflag) then daysflag = 1
  if not keyword_set(xmin)     then xmin     = -1000
  if not keyword_set(xmax)     then xmax     = -1000
  if not keyword_set(ymin)     then ymin     = -1000
  if not keyword_set(ymax)     then ymax     = -1000
  
  if glob eq 0 then begin
     dir='/dsm/stars2/f/cemeriau/'+dir
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  close,/all
  
  r=[0b,255b,130b,255b,255b,0b  ,0b  ,0b  ,255b,255b]
  g=[0b,255b,130b,0b  ,0b  ,0b  ,255b,255b,255b,170b]
  b=[0b,255b,130b,0b  ,255b,255b,255b,0b  ,0b  ,0b  ]
  tvlct,r,g,b
  
  device,set_font='Helvetica',/tt_font
  
  !p.font         = 1
  !x.style        = 1
  !x.thick        = 4
  !y.thick        = 4
  !p.thick        = 4
  !p.charthick    = 1.8
  !p.charsize     = 1.8
  !x.charsize     = 1
  !y.charsize     = 1
  !p.multi        = 0
  th              = 5

  if (psf eq 0) then begin
     set_plot,'x'
     window,wnd,xsize=1200,ysize=800
     device,decomposed=0
  endif else begin 
     if (psf eq 1) then begin
        set_plot,'ps'
        namepsf1=namepsf+'_radial'+'_0'+strcompress(files(0),/r)+'_to_0'+strcompress(files(nfiles-1),/r)+'.eps'
        device,/encapsulated,/landscape,/color,bits=8,filename=namepsf1
     endif
  endelse


; define radius of star + cst for normalizing flux
  r_sun=6.9599e10 
  normf=1e15                    ; 1e16
  
  
  print,'zr : ',rbcz 


;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   
;  Titles generation
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   

  title = get_amom_name2(mag=mag)
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Set up filename array, etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  textnum=strcompress(files,/r)
  if (sc eq 1) then begin
     file=dir+'AMOM/amom_0'+textnum
  endif else if (sc eq 2) then begin
      file=dir+'0'+textnum
   endif else begin
      file=dir+textnum
   endelse


   nfiles=n_elements(file) & nt=intarr(nfiles) & qt=intarr(nfiles)

   temp=0.0
   
   nt(*)=recper                 ; number of record per files
   ntt = long(total(nt))

   snap_iter = ntt-1
   P1_iter   = [0,3]
   P10_iter  = [0,ntt-1]    
   
   d=0.0
   dt = 1.d0/(3600.d0*24.d0)
   Global_rate=2.6d-6*gr
   if (Global_rate ne 2.6d-6) then print,'Not computing with solar rotation rate'
   P = dt * ((2.*!pi) / Global_rate) ; lam3 rot =2 * rot_sol

; read in preliminaries - assume N_r, N_Theta remain the same
   close,2 & openr,2,file(0),swap_endian=swap
   readu,2,d & N_R=fix(d)
   dd=fltarr(N_R) & readu,2,dd
   readu,2,d & N_R_1 = fix(d) & readu,2,dd
   readu,2,d & N_Theta = fix(d)
   print,'N_R and N_theta',N_R,N_Theta
   close,2 & openr,2,file(0),swap_endian=swap

   if mag eq 1 then begin
      N_q=13
   endif else begin
      N_q=9
   endelse
   Amom_balance = assoc(2,fltarr(N_R+1,N_theta,N_q)) 
   
   costheta=fltarr(N_Theta) & theta_weights=costheta
   if (N_R le N_Theta) then begin
      radius=fltarr(N_R) & r_weights = radius
      radius(*) = Amom_balance(0,0:N_R-1,3,0)
      r_weights(*) = Amom_balance(0,0:N_R-1,4,0)
   endif else if (N_R le 2*N_theta) then begin
      print,'oops'
      radius=fltarr(N_R) & r_weights = radius
      radius(0:N_theta-1) = amom_balance(0,0:N_theta-1,3,0)
      radius(N_theta:N_r-1) = amom_balance(0,0:N_R-N_theta-1,4,0)
      r_weights(0:N_theta-1) = amom_balance(0,0:N_theta-1,5,0)
      r_weights(N_theta:N_r-1) = amom_balance(0,0:N_R-N_theta-1,6,0)
   endif else if (N_R le 3*N_theta) then begin
      print,'oops2'
      radius=fltarr(N_R) & r_weights = radius
      radius(0:N_theta-1) = amom_balance(0,0:N_theta-1,3,0)
      radius(N_theta:2*N_theta-1) = amom_balance(0,0:N_theta-1,4,0)
      radius(2*N_theta:N_r-1) = amom_balance(0,0:N_R-2*N_theta-1,5,0)
      r_weights(0:N_theta-1) = amom_balance(0,0:N_theta-1,6,0)
      r_weights(N_theta:2*N_theta-1) = amom_balance(0,0:N_theta-1,7,0)
      r_weights(2*N_theta:N_r-1) = amom_balance(0,0:N_R-2*N_theta-1,8,0)
      save,file='radius_weight_AstarsFS4.idl',radius,r_weights
   endif else begin
      print,'up to 05/15/2010, if Nr > 3*Ntheta, get crap, need to save radius first'
      restore,file='radius_weight_pensd2reala.idl',/ver
      print,'Attention Nr > 3 Ntheta'
      wait,1
      radius=r
   endelse
   costheta(*)=Amom_balance(0,*,1,0)
   sintheta=sin(acos(costheta))
   theta_weights(*)=Amom_balance(0,*,2,0)
   if not keyword_set(rstar) then rstar =radius(0)
   
   t_o = amom_balance(0,3,0,0)
   t_1 = amom_balance(0,3,0,1)
   print,t_o,t_1
   deltat=(t_1-t_o)*dt & print,'delta t',deltat
   iter_1=fix(P/deltat)
   if (iter_1+0.5 lt P/deltat) then iter_1=iter_1+1
   print,'iter1,ntt-1',iter_1,ntt-1
   if (iter_1 gt ntt-1) then iter_1=ntt-1
   P1_iter   = [0,iter_1]
   
; double precision accumulation
                                ; different output with origin version
   print,N_q
   f = dblarr(N_Theta,N_R,N_q,3)
   !p.multi=[0,2,2]
   if mag eq 1 then !p.multi=[0,3,4]
   if psf eq 0 then window,wnd,xsize=750,ysize=750
   
   ff = fltarr(N_Theta,N_R)
   tt = fltarr(ntt)
   
   itt=0
   a = fltarr(2)
   for ifile=0,nfiles-1 do begin 
      
      close,2 & openr,2,file(ifile),swap_endian=swap
      
      Nq=N_q
      Amom_balance = assoc(2,fltarr(N_R+1,N_theta,Nq))
      
      for it=0,nt(ifile)-1 do begin ; avg loop
         
         for q=1,Nq do begin    ; quantities loop
            ff(*,*) = transpose(Amom_balance(1:N_R,*,q-1,it))
            
            if itt eq snap_iter then begin
               f(*,*,q-1,0) = ff
            endif
            if (itt ge P1_iter(0)) and (itt le P1_iter(1)) then begin
               f(*,*,q-1,1) = f(*,*,q-1,1) + ff
            endif
            if (itt ge P10_iter(0)) and (itt le P10_iter(1)) then begin
               f(*,*,q-1,2) = f(*,*,q-1,2) + ff
            endif
            
            
         endfor                 ; quantities
         
         iteration = long(amom_balance(0,5,0,it))
         time      = amom_balance(0,3,0,it)
         DeltaT    = amom_balance(0,4,0,it)
         
         print,'iteration = ',strtrim(iteration,2),$
               ', time = '   ,strtrim(time     ,2),$
               ', delta t = ',strtrim(deltat   ,2)
         
         if itt eq snap_iter   then begin 
            snap_time = (time - t_o) * dt
            snap_iter1 = iteration
         endif
         if itt eq P1_iter(0)  then begin_P1  = (time - t_o) * dt
         if itt eq P1_iter(1)  then end_P1    = (time - t_o) * dt
         if itt eq P10_iter(0) then begin_P10 = (time - t_o) * dt
         if itt eq P10_iter(1) then end_P10   = (time - t_o) * dt
         
         tt(itt) = time
         
         itt=itt+1
         
      endfor                    ; avg
      
   endfor                       ; files
   
; turn sum to temporal average
   norm = 1.d0/float(P1_iter(1)-P1_iter(0)+1)
   f(*,*,*,1) = f(*,*,*,1) * norm
   
   norm = 1.d0/float(P10_iter(1)-P10_iter(0)+1)
   f(*,*,*,2) = f(*,*,*,2) * norm
   
;------------------------------------------------------------
   print,' '
   print,'Global Rotation',P,' days' 
   print,' '
   
   dur_P1  = (end_P1-begin_P1)/P
   dur_P10 = (end_P10-begin_P10)/P
   
   print,'-------------------------------------------'
   print,'snapshot time        : '+strtrim(string(snap_time,format='(f10.2)'),2)+' days'
   print,'1 period time range  : '+strtrim(string(begin_P1,format='(f10.2)'),2)+$
         '--'+strtrim(string(end_P1,format='(f10.2)'),2)+' days'
   print,'          duration/P : '+strtrim(string(dur_P1,format='(f10.2)'),2)
   print,'Max period time range : '+strtrim(string(begin_P10,format='(f10.2)'),2)+$
         '--'+strtrim(string(end_P10,format='(f10.2)'),2)+' days'
   print,'          duration/P : '+strtrim(string(dur_P10,format='(f10.2)'),2)
   
   nit1  = P1_iter(1)-P1_iter(0) + 1
   nit10 = P10_iter(1)-P10_iter(0) + 1
   
   
   print,' '
   print,'Number of iterations: '+strtrim(string(ntt  ,format='(i6)'),2)
   print,'          1  period : '+strtrim(string(nit1 ,format='(i6)'),2)
   print,'        Max periods : '+strtrim(string(nit10,format='(i6)'),2)
   
;------------------------------------------------------------
   
   !p.thick=2
   print,' '
   print,'Now Displays Averages'
   print,' '
   
;; New approach discussed with JPZ (03/05/01)
; first radial mean so use r_weights

;have to redefine r_integration weights for surfaces integral r-phi

   r_int_weights=dblarr(N_r) & r_int_weights(*)=0.d0 & r_int_weights2=r_int_weights & r_int_weightss=r_int_weights
   
   tmp2 = 3.d0*5.d-1*!dpi * (radius(0)-radius(N_r-1)) / ( (radius(0)^3 - radius(N_r-1)^3) * N_r )
   tmp = 2.d0*5.d-1*!dpi * (radius(0)-radius(N_r-1)) / ( (radius(0)^2 - radius(N_r-1)^2) * N_r )
   for ii=0,N_R-1 do begin
      x = (2.d0*radius(ii)-radius(N_r-1)-radius(0))/(radius(0)-radius(N_r-1))
      if (x gt 1.d0) then x=1.0d0
      if (x lt -1.d0) then x=-1.0d0
      r_int_weights2(ii) = radius(ii)^2 * tmp2 * sqrt(1.d0-x*x)
      r_int_weights(ii) = radius(ii) * tmp * sqrt(1.d0-x*x)
   Endfor
   
   
   i_rbcz=where(radius le rbcz*rstar)
   i_rbcz=i_rbcz(0)

   print,'NQ : ',n_q,'i_rbcz :',i_rbcz,'Ntheta : ',n_theta 
   ffqr=dblarr(N_q,N_r) & ffqr(*,*)=0. & ffql=dblarr(N_q,N_theta) & ffql(*,*)=0.
   
   if (mag eq 1) then begin
      
      for q=1,N_q do begin      ; here we don't exclude the thermal wind
         fq=reform(f(*,*,q-1,2)) ; only for max time average
         for i=0,N_r-1 do begin
            for k=0,N_theta-1 do begin
               if (q le 9) then begin
                  ffqr(q-1,i)=ffqr(q-1,i)+radius(i)^2*theta_weights(k)*fq(k,i) ; good
               endif else begin
                  ffqr(q-1,i)=ffqr(q-1,i)+radius(i)^2*theta_weights(k)*(-1.0d0*fq(k,i)) ; good
               endelse
            endfor
         endfor
         
; then the latitudinal
         for k=0,N_theta-1 do begin
            for i=0,i_rbcz do begin
               if (q le 9) then begin
                  ffql(q-1,k)=ffql(q-1,k)+r_int_weights(i)*sintheta(k)*fq(k,i)
               endif else begin
                  ffql(q-1,k)=ffql(q-1,k)+r_int_weights(i)*sintheta(k)*(-1.0d0*fq(k,i))
               endelse
            endfor
         endfor
      endfor
      
   endif else begin             ; magnetic
      
      for q=1,N_q-1 do begin    ; exclude thermal wind
         fq=reform(f(*,*,q-1,2)) ; only for max time average
         for i=0,N_r-1 do begin
            for k=0,N_theta-1 do begin
               ffqr(q-1,i)=ffqr(q-1,i)+radius(i)^2*theta_weights(k)*fq(k,i) ; good
            endfor
         endfor
         
; then the latitudinal
         for k=0,N_theta-1 do begin
            for i=0,i_rbcz do begin
               ffql(q-1,k)=ffql(q-1,k)+r_int_weights(i)*sintheta(k)*fq(k,i)
            endfor
         endfor
      endfor
   endelse                      ; magnetic
   
   ffqr=ffqr/radius(0)^2        ; pseudo normalization of I_r
   
   titt = get_amom_name2(mag=mag,short=1)

   lat=acos(costheta(*))*!radeg-90 ; latitude
   
   ffql=reverse(ffql,2)         ;  put field in order of increasing latitudes (not theta)
   
   r_bot=radius(N_r-1) & r_top=radius(0)
   if not keyword_set(rstar) then rstar = r_top
      
   !p.position=0
   for q=1,8,2 do begin
      plot,lat,ffql(q,*),xrange=[-90,90],xs=1,ystyle=1,title=titt(q),xtitle='!17 Latitude (deg)'
   endfor
   
   if (mag eq 1) then begin
      for q=10,12,2 do begin
         plot,lat,ffql(q,*),xrange=[-90,90],xs=1,ystyle=1,title=titt(q),xtitle='!17 Latitude (deg)'
      endfor
   endif
   
   !x.style=1
   for q=0,7,2 do begin
      plot,radius/r_top,ffqr(q,*),title=titt(q),xtitle='!17 r/R!D!9n!N!17'
   endfor
   if (mag eq 1) then begin
      for q=9,11,2 do begin
         plot,radius/r_top,ffqr(q,*),title=titt(q),xtitle='!17 r/R!D!9n!N!17'
      endfor
   endif
   
; useful to tune x and y ranges and for location of ytitle
   
   maxll=max(ffql(1,*))
   if (maxll lt max(ffql(3,*))) then maxll=max(ffql(3,*))
   if (maxll lt max(ffql(5,*))) then maxll=max(ffql(5,*))
   if (maxll lt max(ffql(7,*))) then maxll=max(ffql(7,*))
   minll=min(ffql(1,*))
   if (minll gt min(ffql(3,*))) then minll=min(ffql(3,*))
   if (minll gt min(ffql(5,*))) then minll=min(ffql(5,*))
   if (minll gt min(ffql(7,*))) then minll=min(ffql(7,*))
   maxrr=max(ffqr(0,*))
   if (maxrr lt max(ffqr(2,*))) then maxrr=max(ffqr(2,*))
   if (maxrr lt max(ffqr(4,*))) then maxrr=max(ffqr(4,*))
   if (maxrr lt max(ffqr(6,*))) then maxrr=max(ffqr(6,*))
   minrr=min(ffqr(0,*))
   if (minrr gt min(ffqr(2,*))) then minrr=min(ffqr(2,*))
   if (minrr gt min(ffqr(4,*))) then minrr=min(ffqr(4,*))
   if (minrr gt min(ffqr(6,*))) then minrr=min(ffqr(6,*))
   
; overwrite values
   minrr=-10e15 & maxrr=6e15 & midr=(maxrr+minrr)/2./normf
   minll=-20e15 & maxll=20e15 & midl=(maxll+minll)/2./normf 
   
   print,'min max r:',minrr,maxrr,midr
   print,'min max l:',minll,maxll,midl
   print,'normf',normf
   
   print,'Do you want to keep the extrema ? (0/1)'
   read,ans1
   if ans1 ne 0 then begin
      print,'Write the new radial values : '
      read,minrr,maxrr
      print,'Write the new lat values : '
      read,minll,maxll
   endif
   
   if (psf eq 1) then begin
      device,/close
      mv_var='mv '+namepsf1+' '+dir+'/figs/'+namepsf1
      if notquiet lt 1 then print,mv_var
      spawn,mv_var
      namepsf2=namepsf+'_0'+strcompress(files(0),/r)+'_to_0'+strcompress(files(nfiles-1),/r)+'.eps'
      device,/encapsulated,/color,bits=8,filename=namepsf2
   endif


   !p.thick=4 & !x.thick=4 & !y.thick=4
   if psf eq 0 then window,wnd+1,xsize=750,ysize=500
   
   !x.style=4
   !p.multi=[0,2,1]
   if (mag eq 1) then begin
      plot,radius/rstar,(ffqr(0,*)+ffqr(2,*)+ffqr(4,*)+ffqr(6,*)+ffqr(9,*)+ffqr(11,*))/normf,ystyle=1,yrange=[minrr,maxrr]/normf,charsize=1.4,pos=[0.12,0.1,0.47,0.925],xs=1,xr=[r_bot,rstar]/rstar,xtitle='!17 r/R!D!9n!17!N'
   endif else begin
      plot,radius/rstar,(ffqr(0,*)+ffqr(2,*)+ffqr(4,*)+ffqr(6,*))/normf,ystyle=1,yrange=[minrr,maxrr]/normf,charsize=1.4,pos=[0.12,0.1,0.47,0.925],xs=1,xr=[r_bot,rstar]/rstar,xtitle='!17 r/R!D!9n!17!N';,ytitle='!9F!17!Dr!N/10!U15!N'  
   endelse
   xyouts,r_bot/rstar-0.05,midr,'!9F!17!Dr!N/10!U15!N',orientation=90,charsize=1.4,align=0.5  
   oplot,radius/rstar,ffqr(0,*)/normf,linestyle=3             ;1
   oplot,radius/rstar,(ffqr(2,*)+ffqr(4,*))/normf,linestyle=2 ; total meridional circulation
;oplot,radius/rstar,ffqr(4,*)/normf,linestyle=3
   oplot,radius/rstar,ffqr(6,*)/normf,linestyle=4
   if (mag eq 1) then begin
      oplot,radius/rstar,ffqr(9,*)/normf,linestyle=5
      oplot,radius/rstar,ffqr(11,*)/normf,linestyle=1
   endif
   
   if (mag eq 1) then begin
      plot,lat,(ffql(1,*)+ffql(3,*)+ffql(5,*)+ffql(7,*)+ffql(10,*)+ffql(12,*))/normf,xrange=[-90,90],xs=1,ystyle=1,xtitle='!17 Latitude (deg)',yrange=[minll,maxll]/normf,charsize=1.4,pos=[0.61,0.1,0.96,0.925];,ytitle='!9 F!D!7h!17!N/10!U15!N'
   endif else begin
      plot,lat,(ffql(1,*)+ffql(3,*)+ffql(5,*)+ffql(7,*))/normf,xrange=[-90,90],xs=1,ystyle=1,xtitle='!17 Latitude (deg)',yrange=[minll,maxll]/normf,charsize=1.4,pos=[0.61,0.1,0.96,0.925]
   endelse
   xyouts,-110,midl,'!9 F!D!7h!17!N/10!U15!N',orientation=90,charsize=1.4,align=0.5
   oplot,lat,ffql(1,*)/normf,linestyle=3             ;1 
   oplot,lat,(ffql(3,*)+ffql(5,*))/normf,linestyle=2 ; total meridional circulation
   oplot,lat,ffql(7,*)/normf,linestyle=4

   line=[0,3,2,4]
   name_rad = ['Total',title[0],title[2],'Meridional circulation']
   name_lat = ['Total',title[1],title[7],'Meridional circulation']
   thick = [4,4,4,4]

   if (mag eq 1) then begin
      oplot,lat,ffql(10,*)/normf,linestyle=5
      oplot,lat,ffql(12,*)/normf,linestyle=1
      line=[line,5,1]
      name_rad=[name_rad,title[9],title[11]]
      name_lat=[name_lat,title[10],title[12]]
      thick=[thick,4,4]
   endif
   
   if (psf eq 1) then begin
        set_plot,'ps'
        !p.multi=0
        namepsf1=namepsf+'_legend_rad'+'.eps'
        device,/encapsulated,/color,bits=8,filename=namepsf1
        plot,lat,lat,color=1
        legend,name_rad,linestyle=line,location=-1
        device,/close
        namepsf1=namepsf+'_legend_lat'+'.eps'
        device,/encapsulated,/color,bits=8,filename=namepsf1
        legend,name_lat,linestyle=line,location=-1
        device,/close
     endif      
   
   if psf eq 1 then begin
      Device,/close
      mv_var='mv '+namepsf2+' '+dir+'/figs/'+namepsf2
      if notquiet lt 1 then print,mv_var
      spawn,mv_var
      set_plot,'x'
   endif
   
end
