;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  see_azav2.pro  -  Plot azimuthal averages
;
;       usage:  see_azav2,dir,q,sq,iter,recnum,rbcz=rbcz,rstar=rstar,to=to,
;               idmx=idmx,glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,
;               psf=psf,namepsf=namepsf,wnd=wnd,legendd=legendd,tv=tv
; 
;               where dir      = data directory
;                     q        = output quantity index (starting at 1)
;                     sq       = 
;                     iter     = iteration of output file
;                     recnum   = record number
;                     gr       = rotation rate (in solar units)
;                     rbcz     = percentage of the radiative zone
;                     rstar    = stellar radius
;                     to       = time offset (default=0.0)
;                     idmx     = amplitude of theta
;                     glob     = prefix of data directory    
;                     sc       = prefix of filenames 
;                     notquiet = verbose if smaller than 2
;                     swap     = change endianess of the file 
;                     opl      = set if overplot command should be
;                     used 
;                     psf      = output screen or psf    
;                     namepsf  = name of the .eps output file           
;                     wnd      = number of the window for screen
;                     output  
;                     legendd  = set to plot legend to the graph 
;                     daysflag = set if time units are days (rather than sec)
;                     tv       = set if image rather than contour plot
;                     is desired
;                     flip     = reverse latitudes
; 
;  M.DeRosa - 27 Aug 1998 - modified from Mark's routine
;  A.S. Brun - many modif - adapted to ASH 1.2
;  A.S. Brun - 2009 - ASH 1.4 version
;  C.Emeriau-Viard - June 2016 - Version 2.0 
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_units
@get_names
@colourbar

pro see_azav2,dir,dir2=dir2,q,q2=q2,sq,sq2=sq2,iter,iter2=iter2,recnum,$
              recnum2=recum2,gr=gr,rbcz=rbcz,rstar=rstar,to=to,idmx=idmx,$
              glob=glob,sc=sc,notquiet=notquiet,swap1=swap1,opl=opl,psf=psf,$
              namepsf=namepsf,wnd=wnd,legendd=legendd,tv=tv,flip=flip,swap2=swap2,$
              radial_plot=radial_plot

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 4 then begin
     print,'see_azav2,dir,q,sq,iter,recnum,gr=gr,rbcz=rbcz,rstar=rstar,to=to,'+$
           'idmx=idmx,glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,'+$
           'psf=psf,namepsf=namepsf,wnd=wnd,legendd=legendd,tv=tv,flip=flip'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Input settings
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  see_azav2.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  if n_elements(q) eq 0 then begin
     print,'  see_azav2.pro:  parameter q must be set'
     return
  endif

  if n_elements(sq) eq 0 then begin
     print,'  see_azav2.pro:  parameter sq must be set'
     return
  endif

  if n_elements(iter) eq 0 then begin
     print,'  see_azav2.pro:  parameter iter must be set'
     return
  endif
  if n_elements(recnum) eq 0 then begin
     print,'  see_azav2.pro:  parameter recnum must be set'
     return
  endif

  if keyword_set(dir2) or keyword_set(qq2) or keyword_set(sq2) or $
     keyword_set(iter2) or keyword_set(recnum2) then comp = 1 $
  else comp = 0
  if not keyword_set(dir2)        then dir2        = dir
  if not keyword_set(q2)          then q2          = q
  if not keyword_set(sq2)         then sq2         = sq
  if not keyword_set(iter2)       then iter2       = iter
  if not keyword_set(recnum2)     then recnum2     = recnum
  if not keyword_set(rbcz)        then rbcz        = 0
  if not keyword_set(rstar)       then rstar       = 1
  if not keyword_set(to)          then to          = 0
  if not keyword_set(gr)          then gr          = 0
  if not keyword_set(gr2)         then gr2         = gr
  if not keyword_set(idmx)        then idmx        = 0
  if not keyword_set(glob)        then glob        = 0
  if not keyword_set(sc)          then sc          = 0
  if not keyword_set(notquiet)    then notquiet    = 0
  if not keyword_set(swap1)       then swap1       = 0
  if not keyword_set(swap2)       then swap2       = 0
  if not keyword_set(opl)         then opl         = 0
  if not keyword_set(psf)         then psf         = 0
  if not keyword_set(namepsf)     then namepsf     = 'AZAV'
  if not keyword_set(wnd)         then wnd         = 0
  if not keyword_set(legendd)     then legendd     = 0
  if not keyword_set(daysflag)    then daysflag    = 0
  if not keyword_set(tv)          then tv          = 0
  if not keyword_set(flip)        then flip        = 0
  if not keyword_set(radial_plot) then radial_plot = 0

  tv = 1 
  if gr gt 0 then begin
     Global_rate  = 2.6d-6*gr  
     Global_rate2 = 2.6d-6*gr2  
  endif

  if glob eq 0 then begin
     dir  = '/dsm/stars2/f/cemeriau/'+dir
     dir2 = '/dsm/stars2/f/cemeriau/'+dir2
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if notquiet eq 0 then print,'SEE_AZAV'

  loadct_mld,41
  device,set_font='Helvetica',/tt_font

  if (psf eq 0) then begin
     set_plot,'x'
     if radial_plot eq 0 then window,wnd,xsize=860,ysize=540 else window,wnd,xs=700,ys=900
     device,decomposed=0
  endif else begin
     set_plot,'ps'
     title=get_name2(q) & if notquiet lt 1 then print,title
     namepsf=namepsf+'_'+STRCOMPRESS(title,/REMOVE_ALL)+'_0'+strcompress(iter,/r)+".eps"
     device,/landscape,/color,bits=8,filename=namepsf;,xsize=8,ysize=8
  endelse

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Set up filename
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  textnum=strcompress(iter,/r)
  case sc of 
     1: file = dir+'/AZAV/azav_0'+textnum 
     2: file = dir+'/AZAV/azav_0'+textnum+'_special'
     else: file = dir +textnum
  end

  if comp eq 1 then begin
     textnum2=strcompress(iter2,/r) 
     case sc of 
        1: file2 = dir2+'/AZAV/azav_0'+textnum2
        2: file2 = dir2+'/AZAV/azav_0'+textnum2+'_special' 
        else: file2 = dir2 +textnum2   
     end
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Associate data file
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  read_azav2,q,file,recnum,f=v,rad=rad,theta=theta,time=time,name=title,$
             notquiet=notquiet,swap=swap1,omega=Global_rate,sq=sq

  if comp eq 1 then read_azav2,q2,file2,recnum2,f=v2,rad=rad2,theta=theta2,$
                               time=time2,name=title2,notquiet=notquiet,swap=swap2,$
                               omega=Global_rate2,sq=sq

  n_theta = size(theta) & n_theta = n_theta[1]
  n_r     = size(rad)   & n_r     = n_r[1] 
  if comp eq 1 then begin
     n_r2     = size(rad2)   & n_r2     = n_r2[1]
  endif

  textu    = get_unit2(title)
  costheta = cos(theta)

  v_tmp=v
  if comp eq 1 then v_tmp2 = v2
  if (flip eq 1) then begin
     print,' '
     print,'use flip=1!'
     print,' '
     for i=0,N_theta-1 do begin
        v(i,*)  = v_tmp(N_theta-i-1,*)
        v2(i,*) = v_tmp2(N_theta-i-1,*)
     endfor
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plot : minimum and maximum
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  !p.multi=[0,2,1]

  sp=max(rad)/200.
  lat=90.-acos(costheta)*!radeg
  lattg=[75.0,60.0,45.0,30.0,15.0,-15.0,-30.0,-45.0,-60.0,-75.0]
  n_theta1 = size(theta) & n_theta1 = n_theta1[1] 

  ilat1=intarr(12) & ilat1(5)=(N_theta/2)-1 & ilat1(6)=N_theta/2
  for jj=0,4 do begin
     indlt1=where(lat lt lattg(jj))
     ilat1(jj)=indlt1(0)
  endfor
  for jj=5,9 do begin
     indlt1=where(lat gt lattg(jj))
     ilat1(jj+2)=max(indlt1)
  endfor
  print,'selected lat cuts:',lat(ilat1)

  if (idmx eq 1) then begin
     idn=ilat1(0) & idx=ilat1(11) ;
  endif else begin
     idn=0 & idx=N_theta1-1
  endelse

  n_theta2 = size(theta2) & N_theta2=n_theta2[1]
  if comp eq 1 then begin
     lat2=90-theta2(*)*!radeg ; latitude
     ilat2=intarr(12) & ilat2(5)=(N_theta2/2)-1 & ilat2(6)=N_theta2/2
     for jj=0,4 do begin
        indlt2=where(lat2 lt lattg(jj))
        ilat2(jj)=indlt2(0)
     endfor
     for jj=5,9 do begin
        indlt2=where(lat2 gt lattg(jj))
        ilat2(jj+2)=max(indlt2)
     endfor
     print,'selected lat cuts:',lat2(ilat2)
  endif
  
  if q eq 3 then begin
     th = 3
     omega_eq = (v[ilat1[5],th] + v[ilat1[6],th])/2
     omega_60 = (v[ilat1[1],th] + v[ilat1[10],th])/2
     ir = 0
     while rad[ir] gt rbcz*rstar do begin
        ir = ir +1
     endwhile
     omega_bcz = (v[ilat1[5],ir-1]+v[ilat1[6],ir-1])/2
     print,' '
     print,omega_eq
     print,omega_60
     print,omega_bcz
     print,' '
     print,'Latitudinal contrast : ',omega_eq - omega_60
     print,'Radial contrast : ',omega_eq - omega_bcz
     print,'Relative shear : ',(omega_eq - omega_60)/omega_eq
     print,' '
  endif
  
  maxi  = max(v(idn:idx,*))
  mini  = min(v(idn:idx,*))
  maxi2 = maxi
  mini2 = mini

  if comp eq 1 then begin
     maxi2=max(v2(idn:idx,*))
     mini2=min(v2(idn:idx,*))
  endif
     
  mini=min(mini,mini2)
  maxi=max(maxi,maxi2)
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; See if we want to modify the proposed values
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if notquiet lt 2 then begin
     print,' '
     print,'Do you want to keep these min and max values (0/1)?',mini,maxi
     read,ans1
     yaa = mini
     ybb = maxi
     if (ans1 eq 1) then begin
        print,'enter new values, min first'
        read,mini,maxi
        print,'enter new values for the radial cut, min first'
        read,yaa,ybb
     endif
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; See if we want to modify the proposed values
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if (gr gt 0) then begin
     levels=100+findgen(21)*20
     c_labels=[0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,0]
     c_thick=c_labels+1.8
  endif else begin
     levels=mini+(maxi-mini)/10*findgen(11)
     c_labels=[0,0]
  endelse

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; 2D plot
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  ansmm1 = 1 
  
  while ansmm1 eq 1 do begin
     if comp eq 0 then begin
        image_polar,v(idn:idx,*),rad,costheta(idn:idx),mini=mini,maxi=maxi,flip=flip,levels=levels,$
                    c_labels=c_labels,c_thick=c_thick,rbcz=rbcz ;vmin=mini
     endif else begin
        if n_r eq n_r2 then begin
           image_polar_rot,v(idn:idx,*),v2(idn:idx,*),rad,costheta(idn:idx),mini=mini,maxi=maxi,flip=flip,levels=levels,$
                           c_labels=c_labels,c_thick=c_thick,rbcz=rbcz ;vmin=mini
        endif else begin
           print,rad,rad
        endelse
     endelse

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plots of radial cuts
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
     xminl = 0.4
     yminl = 0.2
     xmaxl = 0.45
     ymaxl = 0.7
     xt    = 0.6
     yt = 0.06
     if comp eq 1 then begin
        xminl = 0.12
        yminl = 0.85
        xmaxl = 0.42
        ymaxl = 0.9
        xt    = 0.27
        yt    = 0.92
     endif
     
     print,'Legend '
     if (psf eq 0) then begin
        if tv then xyouts,xt,yt,title,/normal,charsize=1.5
        if tv then begin
           if comp eq 1 then colourbar,[xminl,yminl,xmaxl,ymaxl],mn=mini,mx=maxi,textu=textu,zero=Global_rate/2./!pi*1e9 $
           else colourbar2,[xminl,yminl,xmaxl,ymaxl],mn=mini,mx=maxi,textu=textu,zero=Global_rate/2./!pi*1e9
        endif
     endif else begin
        print,psf
        if tv then xyouts,xt,yt,title,/normal,charsize=1.5
        if tv then begin
           if comp eq 1 then colourbar,[xminl,yminl,xmaxl,ymaxl],mn=mini,mx=maxi,textu=textu,zero=Global_rate/2./!pi*1e9 ;$
                                ;else colourbar2,[xminl,yminl,xmaxl,ymaxl],mn=mini,mx=maxi,textu=textu,zero=Global_rate/2./!pi*1e9
        endif
     endelse
     
     
     rmin=0
     rmax = 1                   ;???
     
     if radial_plot eq 0 then begin ; plot the radial cuts for Omega and Fen 
        !p.thick=4 & !y.thick=4 & !x.thick=4   
        diffr1=(max(rad)-min(rad))/max(rad)
        diffr2=diffr1
        if comp eq 1 then diffr2=(max(rad)-min(rad))/max(rad)
        xxtt=0.05
        if min(diffr1,diffr2) lt 0.2 then xxtt=0.02 
        if max(diffr1,diffr2) gt 0.4 then xxtt=0.1
        if rstar lt 1.9e11 then begin
           if (q eq 3) then begin 
              yytitle="!9 W/2p !3(nHz)"
           endif
           xxtt=0.1  
           print,"y range plot",yaa,ybb,rmin,rmax
           plot,rad/rstar,(v(ilat1(5),*)+v(ilat1(6),*))/2.,ytitle=yytitle,ystyle=1,yrange=[yaa,ybb],xstyle=1,xr=[rmin,rmax],xtickinterval=xxtt,charsize=1.4,charthick=1.4,pos=[0.6,0.1,0.95,0.925],xtitle='!3 r/R'
           if comp eq 1 then oplot,rad2/rstar,(v2(ilat2(5),*)+v2(ilat2(6),*))/2.,color=190
        endif else if rstar lt 3e11 then begin                                                             
           plot,rad/rstar,(v(ilat1(5),*)+v(ilat1(6),*))/2.,ytitle="!9 W/2p !3(nHz)",ystyle=1,yrange=[250,450],xstyle=1,xr=[0.0,0.3],xtickinterval=0.1,charsize=1.4,charthick=1.4,pos=[0.6,0.1,0.95,0.925],xtitle='!3 r/R!D*!3!N'
           if comp eq 1 then oplot,rad2/rstar,(v2(ilat2(5),*)+v2(ilat2(6),*))/2.,color=190
           plots,0.3*[rbcz,rbcz],[250,450]
        endif else begin
           plot,alog10(rad/rstar),alog10((v(ilat1(5),*)+v(ilat1(6),*))/2.),ytitle="log!D10!N(!9 W/2p !3) [nHz]",ystyle=1,yrange=[1,3],xstyle=1,xr=[-1.5,-0.1],charsize=1.4,charthick=1.4,pos=[0.6,0.1,0.95,0.925],xtitle='log!D10!N!3(r/R!D*!3!N)'
           if comp eq 1 then oplot,alog10(rad2/rstar),alog10((v2(ilat2(5),*)+v2(ilat2(6),*))/2.)
        endelse
        if rstar gt 3e11 then begin
           oplot,alog10(rad/rstar),alog10((v(ilat1(4),*)+v(ilat1(7),*))/2.),linestyle=1,thick=6
           oplot,alog10(rad/rstar),alog10((v(ilat1(3),*)+v(ilat1(8),*))/2.),linestyle=2,thick=6
           oplot,alog10(rad/rstar),alog10((v(ilat1(2),*)+v(ilat1(9),*))/2.),linestyle=3,thick=6
           oplot,alog10(rad/rstar),alog10((v(ilat1(1),*)+v(ilat1(10),*))/2.),linestyle=4,thick=6
           oplot,alog10(rad/rstar),alog10((v(ilat1(0),*)+v(ilat1(11),*))/2.),linestyle=5,thick=6
           if comp eq 1 then begin
              oplot,alog10(rad2/rstar),alog10((v2(ilat2(4),*)+v2(ilat2(7),*))/2.),linestyle=1,thick=6,color=190
              oplot,alog10(rad2/rstar),alog10((v2(ilat2(3),*)+v2(ilat2(8),*))/2.),linestyle=2,thick=6,color=190
              oplot,alog10(rad2/rstar),alog10((v2(ilat2(2),*)+v2(ilat2(9),*))/2.),linestyle=3,thick=6,color=190
              oplot,alog10(rad2/rstar),alog10((v2(ilat2(1),*)+v2(ilat2(10),*))/2.),linestyle=4,thick=6,color=190
              oplot,alog10(rad2/rstar),alog10((v2(ilat2(0),*)+v2(ilat2(11),*))/2.),linestyle=5,thick=6 ,color=190
           endif
        endif else begin
           oplot,rad/rstar,(v(ilat1(4),*)+v(ilat1(7),*))/2.,linestyle=1,thick=6
           oplot,rad/rstar,(v(ilat1(3),*)+v(ilat1(8),*))/2.,linestyle=2,thick=6
           oplot,rad/rstar,(v(ilat1(2),*)+v(ilat1(9),*))/2.,linestyle=3,thick=6
           oplot,rad/rstar,(v(ilat1(1),*)+v(ilat1(10),*))/2.,linestyle=4,thick=6
           oplot,rad/rstar,(v(ilat1(0),*)+v(ilat1(11),*))/2.,linestyle=5,thick=6
           if comp eq 1 then begin
              oplot,rad2/rstar,(v2(ilat2(4),*)+v2(ilat2(7),*))/2.,linestyle=1,thick=6,color=190
              oplot,rad2/rstar,(v2(ilat2(3),*)+v2(ilat2(8),*))/2.,linestyle=2,thick=6,color=190
              oplot,rad2/rstar,(v2(ilat2(2),*)+v2(ilat2(9),*))/2.,linestyle=3,thick=6,color=190
              oplot,rad2/rstar,(v2(ilat2(1),*)+v2(ilat2(10),*))/2.,linestyle=4,thick=6,color=190
              oplot,rad2/rstar,(v2(ilat2(0),*)+v2(ilat2(11),*))/2.,linestyle=5,thick=6,color=190
           endif
           plots,[rbcz,rbcz],[yaa,ybb],line=2,thick=4                                    
        endelse
        
        if legendd ne 0 then legend, ['0','15','30','45','60','75'], linesty=[0,1,2,3,4,5], thick=5,location=legendd,charsize=1.5
     endif

     if notquiet lt 2 then begin
        print,' '
        print,'Do you want to keep these min and max values (0/1)?',mini,maxi
        read,ansmm1
        yaa = mini
        ybb = maxi
        if (ansmm1 eq 1) then begin
           print,'enter new values, min first'
           read,mini,maxi
           print,'enter new values for the radial cut, min first'
           read,yaa,ybb
        endif
     endif else begin
        ansmm1 = 0
     endelse
  endwhile
  
  if psf eq 1 then begin
     device,/close
     mv_var= 'mv '+namepsf+' '+dir+'/figs/'+namepsf
     print,mv_var
     spawn,mv_var
     set_plot,'x'  
  endif
  
end








