;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 ;  see_envision_shsl2.pro  -  Reads in shell_slice and plots
;
;       usage:  see_envision_shsl2,dir,q,iter,recnum,glob=glob,sc=sc,
;                                  notquiet=notquiet,swap=swap,opl=opl,
;                                  psf=psf,namepsf=namepsf,wnd=wnd,
;                                  daysflag=daysflag,tv=tv,ortho=ortho
;               where dir      = data directory
;                     q        = output quantity index (starting at 1)
;                     sq       = statistical quantity ([0,1,2,3] =
;                                [normal,mean,diffrot,vorticity])             
;                     iter     = iteration of output file
;                     recnum   = record number
;                     depth    = number of the shell
;                     rstar    = stellar radius
;                     glob     = prefix of data directory
;                     sc       = prefix of filename 
;                     notquiet = verbose if smaller than 2
;                     swap     = dependant of the endianess of the file 
;                     opl      = set if overplot command should be used
;                     psf      = type of output (screen or .eps)    
;                     namepsf  = name of the .eps output file   
;                     wnd      = number of the output screen window 
;                     daysflag = set if time units are days (rather than sec)
;                     tv       = set if image rather than contour plot is desired
;                     ortho    = set to [lcent,bcent] if orthographic
;                             projection is desired, where lcent and
;                             bcent are the longitude and latitude
;                             (respectively) of the tangent point of
;                             the projection, default=[0,35]
;		      fill = set if color
;                     flip = 
;
;       notes:  -tv keyword doesn't do anything at this point
;
;  M.DeRosa -  2 Sep 1998 - modified from Mark's routine
;             28 Jun 1999 - added ortho keyword
;  A.S.Brun - 29 Jun 1999 - added fil keyword
;           - 30 Jul 1999 - add psf keyword
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names
@get_units
@colourbar

pro see_envision_shsl2,dir,q,sq,iter,recnum,depth=depth,rstar=rstar,horiz=horiz,$
                       to=to,glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,$
                       psf=psf,namepsf=namepsf,wnd=wnd,daysflag=daysflag,tv=tv,$
                       ortho=ortho,flip=flip


;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 5 then begin
     print,'see_envision_shsl2,dir,q,sq,iter,recnum,depth=depth,rstar=rstar,'+$
           'horiz=horiz,glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,'+$
           'psf=psf,namepsf=namepsf,wnd=wnd,daysflag=daysflag,tv=tv,'+$
           'ortho=ortho,flip=flip'
     return
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set default
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  see_shell_slices.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  if n_elements(q) eq 0 then begin
     print,'  see_shell_slices.pro:  parameter q must be set'
     return
  endif

  if n_elements(iter) eq 0 then begin
     print,'  see_shell_slices.pro:  parameter iter must be set'
     return
  endif

  if n_elements(recnum) eq 0 then begin
     print,'  see_shell_slices.pro:  parameter recnum must be set'
     return
  endif

  if not keyword_set(depth)    then depth    = 0
  if not keyword_set(rstar)    then rstar    = 1
  if not keyword_set(horiz)    then horiz    = 0
  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 0
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(opl)      then opl      = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(namepsf)  then namepsf  = 'SHSL_envision_'
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(daysflag) then daysflag = 1
  if not keyword_set(tv)       then tv       = 1
  if keyword_set(ortho) then begin
     if n_elements(ortho) lt 3 then begin
        if ortho eq 2 then begin
           lcent=0.0  &  bcent=35.0
        endif else begin
           lcent=0.0  &  bcent=0.0
        endelse
        ortho=[ortho,lcent,bcent]
     endif else begin
        lcent=ortho(1)  &  bcent=ortho(2)
     endelse
  endif else ortho=[0.0,0.0,0.0]
  if not keyword_set(flip)     then flip     = 0

  if glob eq 0 then begin
     dir = '/dsm/stars2/f/cemeriau/'+dir
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Graphic devices
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all
  
  !p.font     = 1
  !p.charsize = 1.7
  device,set_font='Helvetica Italic',/tt_font

;  vctr=bytarr(256) & vctg=vctr & vctb=vctr
;  close,3 & openr,3,'./ctbin/ct42.bin'
;  readu,3,vctr,vctg,vctb
;  tvlct,vctr,vctg,vctb
  
  loadct_mld,42

  nlevs = 10

  !p.multi = 0
  if psf eq 0 then begin
     set_plot,'x'
     device,decomposed=0
     window,wnd,xsize=1200,ysize=800
  endif else begin
     set_plot,'ps'
     title = get_name2(q)
     namepsf = namepsf+'_'+strcompress(title,/remove_all)+'_0'+strcompress(iter,/r)+'.eps'
     device,/encapsulated,/color,bits=8,filename=namepsf,xsize=32,ysize=32
  endelse
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  
;  Set up filename etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  textnum=strcompress(iter,/r)

  if sc eq 0 then begin
     textnum='shsl_0'+textnum
  endif else begin
     textnum='SHSL/shsl_0'+textnum
  endelse
  
  file = dir+textnum

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Read SHSL files
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  read_shsl2,q,file,recnum,sq,f=f,rad=rad,theta=theta,phi=phi,name=title,$
             notquiet=notquiet,swap=swap,time=time

  n_theta  = size(theta) & n_theta  = n_theta[1]
  n_phi    = size(phi)   & n_phi    = n_phi[1]
  n_shells = size(f)     & n_shells = n_shells[3]
  lon=phi
  lat=reverse(90-theta*!radeg)

  period=2*n_theta/n_phi

  textu = get_unit2(title)

  erase

  vin = f(*,*,depth)
  
  if period gt 1 then begin
     v=fltarr(n_theta,n_phi*period,/noz)
     for i=0,period-1 do v(*,i*n_phi:(i+1)*n_phi-1)=vin
  endif else begin
     v=vin
  endelse

  ttit=title+' @ r='+strtrim(string(rad(depth)/rstar,format='(g10.2)'),2)+' !17R!D*!N!6'
  print,title+' @ r='+strtrim(string(rad(depth)/rstar,format='(g10.2)'),2)+' R'
  
  spacing=(max(v)-min(v))/(nlevs-1.)
  levs=min(v)+(findgen(nlevs))*(spacing*(nlevs-1.))/(nlevs-1.)
  mini=min(v) & maxi=max(v)     ; modif 02/26/00 correct number but reduce color
  

;  v=transpose([[v],[v(*,0)]])
;  v=reverse(v,2)                         ;  put field in order of increasing latitudes (not theta)

  if keyword_set(flip) then v=reverse(v,1) ;  flip longitudes
  
;  determine contour levels / image scale
  nlevs=10                      ;  number of contour levels
  levs=get_contour_levels(v,nlevs,mn=mnv,mx=mxv,pct=0.04)

  icut2     = 2
  n_shells1 = n_shells

  if notquiet lt 2 then begin
     print,'Original: mnv,mxv',min(v),max(v)
     print,'Proposed: mnv,mxv',mnv,mxv
     print,'Do you want to keep them (0/1)?'
     read,ans1
     if (ans1 eq 1) then begin
        Print,'Enter min/max'
        read,mnv,mxv
     endif
  endif
  
  if ortho(0) ge 1 then begin
                     
     if horiz eq 1 then rstar = rad(depth)
     sclfact=rad(depth)/rstar
     
;     Erase, Color=cgColor('white')
     if ortho(0) eq 2 then begin
        map_set,bcent,lcent,/ortho,/noer,/nobor,/iso,chars=1.8,ymar=[6,10];,/noerase;,tit=ttit
     endif else if ortho(0) eq 1 then begin
        map_set,bcent,lcent,/mollweide,/noer,/nobor,/iso,chars=1.8,ymar=[6,10];/noerase
     endif
     clip=!p.clip               ; get pictures boundary x0,y0,x1,y1

     offset=long((1-sclfact)*[clip(2)-clip(0),clip(3)-clip(1)]/2) ; original
     winsiz=double([!d.x_size,!d.y_size])
     
     pos=(clip+[offset,-offset])/[winsiz,winsiz]

     if ortho(0) eq 2 then begin
        map_set,bcent,lcent,/ortho,/noer,/nobor,/iso,pos=pos;,/noerase
     endif else if ortho(0) eq 1 then begin
        map_set,bcent,lcent,/mollweide,/noer,/nobor,/iso,pos=pos;,/noerase
     endif
         
                                ;  remap and display image on sphere
     if (psf eq 1) then backval=abs(max(vin))*2 else backval=-abs(min(vin))*2
     remap=map_image(v(0:n_phi*period-1,*),x0,y0,xsiz,ysiz,latmin=lat(0),latmax=lat(n_theta-1),$
                     lonmin=lon(0),lonmax=lon(n_phi*period-1),missing=backval,/bilinear,/compress,scale=0.05)
     scim,remap,scale=[mnv,mxv],outim=outim,/nowin,/quiet,/interp ; original
     tv,outim,x0,y0,xsiz=xsiz,ysiz=ysiz

    
;  put in equator and redraw horizon
     oplot,findgen(361)-lcent-90.,replicate(0,361),linestyle=5,thick=3,color=0
     map_horizon,thick=2        ;3
     
                                ; now plot dotted line around full sphere
     
     pos=clip/[winsiz,winsiz]
     
     if ortho(0) eq 2 then begin
        map_set,bcent,lcent,/ortho,/noer,/nobor,/iso,pos=pos
     endif else if ortho(0) eq 1 then begin
        map_set,bcent,lcent,/mollweide,/noer,/nobor,/iso,pos=pos
     endif
     
     if horiz eq 0 then map_horizon,line=1,thick=3
     
     if psf eq 0 then xyouts,!d.x_size/2.2,!d.y_size*6/7,+ttit,/dev,charsize=2
     if psf eq 1 then begin
        if to eq 0 then begin
           to   = time/86400
           date = 0
        endif else begin
           time = time/86400
           date = time - to
        endelse
        print,'date : ',date
        jour = string(date,FORMAT='(F6.2)')
        print,jour
        xyouts,!d.x_size*4/5,!d.y_size*4/6,+strtrim(jour,2),/dev,charsize=2 
     endif

     if psf eq 0 then begin
        colourbar,[0.02+0.35,0.03,0.28+0.35,0.045],mn=mnv,mx=mxv,textu=textu
     endif
     
  endif else begin
     
     !y.margin=[4,4]
                                ;  set up coordinate system
     contour,v,lon,lat,xr=[-180,180],yr=[-90,90],$
             /xsty,/ysty,tit=ttit,ytit='latitude [deg]',xtit='longitude [deg]',$
             /nodata,ticklen=-abs(!p.ticklen),charsiz=0.8,/isotropic ; charsize=1.2
     
                                ;  overplot image
      x0=!p.clip(0)  &  y0=!p.clip(1)
      xsiz=!p.clip(2)-x0  &  ysiz=!p.clip(3)-y0
      if (psf eq 0) then remap=congrid(v,xsiz,ysiz) else remap=v
      scim,remap,scale=[mnv,mxv],outim=outim,/nowin
      tv,outim,x0,y0,xsiz=xsiz,ysiz=ysiz

      ;  redraw border
      plots,[x0,x0,x0+xsiz,x0+xsiz,x0],[y0,y0+ysiz,y0+ysiz,y0,y0],/device

      icut3=n_shells1-1-icut2
      print,icut3
      if (q le 3) then begin
         mini=mini/100. & maxi=maxi/100.
         mnv=mnv/100. & mxv=mxv/100.
      endif 

      if (psf eq 1) then begin
         colourbar2,[0.605,0.05+0.10*icut3^2.6,.62,0.25+0.10*icut3^2.6],mn=mnv,mx=mxv,textu=textu,plttype='ps'
      endif else begin
         colourbar2,[0.675,0.05+0.10*icut3^2.6,0.69,0.25+0.10*icut3^2.6],mn=mnv,mx=mxv,textu=textu
      endelse
   endelse                   

  icut2=icut2+1 



  if (psf eq 1) then begin 
     device,/close
     mv_var= 'mv '+namepsf+' '+dir+'figs/'+namepsf
     set_plot,'x'
     print,mv_var
     spawn,mv_var
  endif

  if (psf eq 2) then begin
     name=' '
     print,'enter a name for the .tiff file (.tiff will be added)'
     read,name
     tvlct,r,g,b,/get
     image_sax=tvrd()
     help,image_sax
     name1=name+'.tiff'
     write_tiff,name1,image_sax,red=r,green=g,blue=b
  endif

  if (psf eq 3) then begin
     name=' '
     print,'enter a name for the .bmp file (.bmp will be added)'
     read,name
     tvlct,r,g,b,/get
     image_sax=tvrd()
     help,image_sax
     name1=name+'.bmp'
     write_bmp,name1,image_sax,r,g,b
  endif
  
  !p.multi=0
  
end






