;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  see_ratio_spectra2.pro  -  Plot spectra from files cominf from get_spectra2
;   
;  usage : see_ratio_spectra2,file=file,icutmax=icutmax,rho=rho,mag=mag,ross=ross,$
;                   notquiet=notquiet,namepsf=namepsf,savef=savef,$
;                   psf=psf,q=q,rbcz=rbcz,fshsl=file_shsl,rstar=rstar,$
;                   swap=swap
;          where file     = output of get_spectra2
;                icutmax  = number of shells
;                rho      = density to calculate KE
;                mag      = also plot magnetic spectra
;                ross     = spectra on velocity components
;                notquiet = verbose if smaller than 2
;                namepsf  = name of output .ps file
;                savef    = save values as .idl files
;                psf      = type of output (screen or .eps)
;                q        = if greater than 1 plot spectra of q
;                rbcz     = percentage of radiative zone
;                fhsl     = path of the shsl file (to get radii of
;                shells)
;                rstar    = stellar radius
;                swap     = dependant of the endianess of files
;                licut    = list icut
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

pro see_ratio_spectra2,files,licutmax,rho=rho,mag=mag,psf=psf,notquiet=notquiet,$
             namepsf=namepsf,savef=savef,ross=ross,q=q,rbcz=rbcz,lfshsl=lfshsl,$
             lrstar=lrstar,swap=swap,glob=glob,yy=yy,nokolmo=nokolmo,$
             wnd=wnd,dep=dep,legendd=legendd

  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  if n_params() lt 2 then begin
     print,'spectra2,file,icutmax,rho=rho,mag=mag,psf=psf,'+$
           'notquiet=notquiet,namepsf=namepsf,savef=savef,'+$
           'ross=ross,q=q,rbcz=rbcz,fshsl=fshsl,rstar=rstar,'+$
           'swap=swap'
     return
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(name1)    then namepsf  = 'spectra.ps'
  if not keyword_set(rbcz)     then rbcz     = 0
  if not keyword_set(rho)      then rho      = ''
  if not keyword_set(savef)    then savef    = 0
  if not keyword_set(mag)      then mag      = 0
  if not keyword_set(ross)     then ross     = 0
  if not keyword_set(q)        then q        = 0
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(legendd)  then legendd  = 0
  if not keyword_set(yy)       then begin
     yra  = [1.d0,1.d8]
     yrb  = [1.d0,2.d9]
     yrm  = [1.d1,2.d9]
     yrm0 = [1.d2,2.d8]
  endif else begin
     yra  = yy
     yrb  = yy
     yrm  = yy
     yrm0 = yy
  endelse
  if not keyword_set(nokolmo)  then nokolmo  = 0
  if glob eq 0 then begin
     lfshsl = '/dsm/stars2/f/cemeriau/EvolZR/'+lfshsl
     dir    = '/dsm/stars2/f/cemeriau/EvolZR/'
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Graphics device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  !p.font=1
  device,set_font='Helvetica Italic',/tt_font
  
  device,decomposed=0
  r=[0,255,255,225,195,165,0,0,0,0,0,0]
  g=[0,255,0,0,0,0,0,0,0,0,255,225]
  b=[0,255,0,0,0,0,255,225,195,165,0,0]
  tvlct,r,g,b  
  dec=1
  
  if (psf eq 1) then begin
     set_plot,'ps'
     device,filename=name1,/color,/landscape
  endif

  if (psf eq 0) then  window,wnd,xsize=1600,ysize=800
  !x.style=1
  
  !p.thick=5 & !x.thick=6 & !y.thick=6 & !p.charsize=2.5
  !p.charthick=1.4
  
  if psf eq 1 then !p.charsize=1.5
  
  !p.multi = 0

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Time parameters
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  dt = 1.d0/(3600.d0*24.d0)
  P = dt * ((2.*!pi) / 2.6d-6)
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Look at the files
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  nb_files = size(files) & nb_files = nb_files[1]
  if not keyword_set(swap) then swap = dblarr(nb_files)

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Find min lmax and ndepths
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  for ifiles=0,nb_files -1 do begin

     fshsl   = lfshsl[ifiles]
     icutmax = licutmax[ifiles]
     file    = files[ifiles]
     swapf   = swap[ifiles]

     dims=fltarr(2)
     
     close,1 & openr,1,fshsl,swap_endian=swapf
     readu,1,d & N_Phi = fix(d)
     readu,1,d & N_Theta = fix(d)
     readu,1,d & N_Shells = fix(d)
     readu,1,d & N_quantities = fix(d)
     close,1 & openr,1,fshsl,swap_endian=swapf
     shell_slices = assoc(1,fltarr(N_Theta,N_Phi+1,N_Shells,N_quantities))
     rad=reform(shell_slices(8,0,0:icutmax,0,0))
     n_depths = size(rad) & n_depths = n_depths[1]
     
     close,2 & openr,2,file
     readu,2,dims
     l_max1 = long(dims(0)) & nt1 = long(dims(1))     
     close,2

     if not keyword_set(dep) then begin
        if ifiles eq 0 then begin
           dep  = n_depths-1
        endif else begin
           if n_depths-1 lt dep  then dep  = n_depths-1
        endelse
        if notquiet le 1 then print,'Dep : ',dep
     endif

     if ifiles eq 0 then begin
        lmax = l_max1
     endif else begin
        if l_max1 lt lmax then lmax = l_max1
     endelse

  endfor
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculations
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  ratio_axi    = dblarr(nb_files-1,lmax,dep+1)
  ratio_nonaxi = dblarr(nb_files-1,lmax,dep+1)
  ratio_tot    = dblarr(nb_files-1,lmax,dep+1)
  name_ratio   = strarr(nb_files-1)

  del_1 = -1
  for ifiles=0,nb_files -1 do begin    

     rstar    = lrstar[ifiles]
     fshsl    = lfshsl[ifiles]
     file     = files[ifiles]
     icutmax  = licutmax[ifiles]
     swapf    = swap[ifiles]
     icutmax1 = icutmax
     icutmax2 = icutmax

     dims=fltarr(2)
     
     close,1 & openr,1,fshsl,swap_endian=swapf
     readu,1,d & N_Phi = fix(d)
     readu,1,d & N_Theta = fix(d)
     readu,1,d & N_Shells = fix(d)
     readu,1,d & N_quantities = fix(d)
     close,1 & openr,1,fshsl,swap_endian=swapf
     shell_slices = assoc(1,fltarr(N_Theta,N_Phi+1,N_Shells,N_quantities))
     rad=reform(shell_slices(8,0,0:icutmax,0,0))
     n_depths = size(rad) & n_depths = n_depths[1]

; Adjust shells (to be coherent between models)
   
     shells = lindgen(dep+1)
     if icutmax gt dep then begin
        shells=[]
        print,rad/rstar
        del_shell = []
        print,'Enter the number of the shells you want to delete (0 being the first)'
        aux_del = 0
        while icutmax-aux_del gt dep do begin
           read,del_1
           del_shell = [del_shell,del_1]
           aux_del = aux_del + 1
        endwhile
        print,'Shells to delete : ',del_shell
        for i = 0,icutmax do begin
           if where(del_shell eq i) eq -1 then shells = [shells,i]
        endfor
     endif

; legend needs
  
     rbcz_min = min(rbcz)*100
     rbcz_max = max(rbcz)*100
     if ifiles eq 0 then begin 
        rad_depths = rad[shells]/rstar[0]
        leg_depths = []
        lin_depths = []
        col_depths = []
        prop       = []    
        for i=0,dep do begin
           prop_aux   = fix(rad_depths[i]*100)
           prop       = [prop,prop_aux]
           leg_depths = [leg_depths,strcompress(prop_aux,/r)]
           lin_depths = [lin_depths,i]
           case 1 of
              prop[i] lt rbcz_min: col_depths = [col_depths,3]
              (prop[i] lt rbcz_max) and (prop[i] ge rbcz_min): col_depths = [col_depths,5]
              prop[i] eq rbcz_max: col_depths = [col_depths,7]
              prop[i] gt rbcz_max: col_depths = [col_depths,1-psf]
           end
        endfor
     endif

; Open spectra file 
     
     close,2 & openr,2,file
     readu,2,dims
     l_max1 = long(dims(0)) & nt1 = long(dims(1))
     if (l_max1 eq 0 && nt1 eq 0) then begin
        close,2
        restore,file=file,/ver
        l_max1=long(dims(0)) 
        nt1 = long(dims(1))
        KE1=out
     endif else begin
        iter1 = fltarr(nt1) & time1 = fltarr(nt1)
        KE1 = fltarr(l_max1+1,l_max1+1,icutmax1+1)
        readu,2,iter1,time1
        readu,2,KE1
     endelse
     
     l_max2=l_max1
     
     if (mag gt 0) then begin
        lasti = STRPOS(file, '/', /REVERSE_SEARCH)
        print,'mag file :: ',strmid(file,0,lasti+1)+'mag_'+strmid(file,lasti+1)
        close,2 & openr,2,strmid(file,0,lasti+1)+'mag_'+strmid(file,lasti+1)
     endif else if (ross gt 0 ) then begin
        close,2 & openr,2,'pol_'+file
     endif
     
     magross = mag + ross
     
     if (magross gt 0) then begin
        readu,2,dims
        l_max2 = long(dims(0)) & nt2 = long(dims(1))
        iter2 = fltarr(nt2) & time2 = fltarr(nt2)
        KE2 = fltarr(l_max2+1,l_max2+1,icutmax2+1)
        readu,2,iter2,time2
        readu,2,KE2
        iter2=long(iter2)
        close,2
     endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculation on kinetic data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
     Km1 = fltarr(l_max1+1,icutmax1+1)*0.d0 & Km1nol0=Km1
     Kl1 = fltarr(l_max1+1,icutmax1+1)*0.d0 & Kl1nom0=Kl1
     
     for i=0,l_max1 do for j=0,icutmax1 do Km1(i,j)=total(KE1(0:l_max1,i,j),/double)
     for i=0,l_max1 do for j=0,icutmax1 do Km1nol0(i,j)=total(KE1(1:l_max1,i,j),/double)
     for i=0,l_max1 do for j=0,icutmax1 do Kl1(i,j)=total(KE1(i,0:l_max1,j),/double)
     for i=0,l_max1 do for j=0,icutmax1 do Kl1nom0(i,j)=total(KE1(i,1:l_max1,j),/double)
     
     E_kolmo1 = fltarr(l_max1+1) & E_k1 = E_kolmo1 & E_k1a = E_kolmo1 & E_k1b = E_k1a
     ll1 = findgen(l_max1+1)
     cte1=3e8
     for i=0,l_max1 do E_kolmo1(i)=cte1*i^(-5./3.)
     for i=0,l_max1 do E_k1(i)=cte1*i^(-2.)
     for i=0,l_max1 do E_k1a(i)=cte1*i^(-3.)
     for i=0,l_max1 do E_k1b(i)=cte1*i^(-4.)
     
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculation on magnetic or poloidal data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

     if (magross gt 0) then begin
        Km2 = fltarr(l_max2+1,icutmax2+1)*0.d0 & Km2nol0=Km2
        Kl2 = fltarr(l_max2+1,icutmax2+1)*0.d0 & Kl2nom0=Kl2
        
        for i=0,l_max2 do for j=0,icutmax2 do Km2nol0(i,j) = total(KE2(1:l_max2,i,j),/double)
        for i=0,l_max2 do for j=0,icutmax2 do Km2(i,j) = total(KE2(0:l_max2,i,j),/double)
        for i=0,l_max2 do for j=0,icutmax2 do Kl2nom0(i,j) = total(KE2(i,1:l_max2,j),/double)
        for i=0,l_max2 do for j=0,icutmax2 do Kl2(i,j) = total(KE2(i,0:l_max2,j),/double)
        
        E_kolmo2 = fltarr(l_max2+1)
        ll2 = findgen(l_max2+1) & E_k2 = E_kolmo2 & E_k2a = E_kolmo2
        cte2=3e8
        for i=0,l_max2 do E_kolmo2(i)=cte2*i^(-5./3.)
        for i=0,l_max2 do E_k2(i)=cte2*i^(-2.)
        for i=0,l_max2 do E_k2a(i)=cte2*i^(-3.)
     endif
     
     if (savef eq 1) then begin
        print,"Name of save file"
        sf=''
        read,sf
        if (magross gt 0) then begin
           save,file=sf,l_max1,l_max2,Km1,Kl1,Km1nol0,Kl1nom0,Km2,Kl2,Km2nol0,Kl2nom0,rad
        endif else begin
           save,file=sf,l_max1,Km1,Kl1,Km1nol0,Kl1nom0,rad
        endelse
     endif

     xra=[1,l_max1] & xra1=[0,l_max1]
     xrb=[1,l_max2] & xrb1=[0,l_max2]
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Transformation into energies
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

     if (not (strcmp(rho,''))) then begin
        restore,file=rho,/ver
        coef=1.d0/8.d0/!dpi
        print,'density used',dens
     endif else begin
        print,'Constant definition'
        dens=dblarr(icutmax+1)
        dens(*) = 2
        coef  = 1
     endelse
     
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculate ratio
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
     
     if ifiles ge 1 then begin
        tot_old    = tot_new
        axi_old    = axi_new
        nonaxi_old = nonaxi_new
     endif
     
     print,'Shells : ',shells
     
     if mag eq 0 then begin
        tot_new    = Kl1[0:lmax-1,shells]
        axi_new    = Kl1[0:lmax-1,shells] - Kl1nom0[0:lmax-1,shells]
        nonaxi_new = Kl1nom0[0:lmax-1,shells]
     endif else begin
        tot_new    = Kl2[0:lmax-1,shells]
        axi_new    = Kl2[0:lmax-1,shells] - Kl2nom0[0:lmax-1,shells]
        nonaxi_new = Kl2nom0[0:lmax-1,shells]
     endelse
     
     if notquiet eq 0 and psf eq 0 then begin
        !p.multi=[0,3,1]
        plot_oo,tot_new[*,0],title='Total',/xs,xr=[1,lmax-1]
        for i=1,dep do begin
           oplot,tot_new[*,i],line=i
        endfor
        plot_oo,axi_new[*,0],title='Axi',/xs,xr=[1,lmax-1]
        for i=1,dep do begin
           oplot,axi_new[*,i],line=i
        endfor
        plot_oo,nonaxi_new[*,0],title='NonAxi',/xs,xr=[1,lmax-1]
        for i=1,dep do begin
           oplot,nonaxi_new[*,i],line=i
        endfor
        stop
     endif
     
     if ifiles ge 1 then begin
        ratio_axi[ifiles-1,*,*]    = axi_new/axi_old
        ratio_nonaxi[ifiles-1,*,*] = nonaxi_new/nonaxi_old
        ratio_tot[ifiles-1,*,*]    = tot_new/tot_old
        name_ratio[ifiles-1]       = files[ifiles]+'_'+files[ifiles-1]
     endif
  endfor

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plot on kinetic data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  print,"Proportion : ",prop
  
  if (q eq 0) then begin 
     if mag eq 0 then qname = 'KE' else qname = 'ME'
     unit = '(erg/cm!U3!N)'
  endif else begin
     qname = get_name2(q)
     unit=''
  endelse
  
  if psf eq 0 then !p.multi=[0,2,1] else !p.multi = 0

  for ifiles = 0,nb_files-2 do begin

     ansmm = 1
     print,'Minimum : ',min(ratio_axi(ifiles,*,*)),'  --  Maximum : ',max(ratio_axi(ifiles,*,*))

     if (psf eq 1) then begin
        set_plot,'ps'
        namepsf = name_ratio[ifiles]+'_axi.eps'
        device,filename=namepsf,/color,/landscape
     endif 
     
     while ansmm eq 1 do begin  ; Loop for the axi plot of the ifiles ratio
        plot_oo,ratio_axi(ifiles,*,0),xtit='!5 degree l !5',ytit=qname+' axi '+unit,yr=yra,/ys,xr=xra,color=col_depths[0]
        for ii=1,dep do begin
           oplot,ratio_axi(ifiles,*,ii),color=col_depths[ii],line=ii
        endfor
        if legendd gt 0 then legend,leg_depths,linestyle=lin_depths,location=legendd,color=col_depths
        if notquiet lt 2 then begin 
           print,'Are the extremas correct ? (0/1)'
           read,ansmm
           if ansmm eq 1 then begin
              print,'Enter the new values (min first) '
              read,ymin,ymax
              yra=[ymin,ymax]
           endif
        endif else begin
           ansmm1 = 0
        endelse
     endwhile                   ; End axi plot

     if (psf eq 1) then begin
        device,/close
        mv_var= 'mv '+namepsf+' '+dir+'/figs/'+namepsf
        print,mv_var
        spawn,mv_var

        namepsf = name_ratio[ifiles]+'_nonaxi.eps' 
        device,filename=namepsf,/color,/landscape
     endif else begin
        if notquiet le 1 then stop
     endelse

     ansmm1 = 1
     while ansmm1 eq 1 do begin ; Loop for the nonaxi plot of the ifiles ratio                
        plot_oo,ratio_nonaxi(ifiles,*,0),xtit='!5 degree l !5',ytit=qname+' nonaxi '+unit,yr=yra,/ys,xr=xra,color=col_depths[0]
        for ii=1,dep do begin
           oplot,ratio_nonaxi(ifiles,*,ii),color=col_depths[ii],line=ii
        endfor
        if legendd gt 0 then legend,leg_depths,linestyle=lin_depths,location=legendd,color=col_depths
        if notquiet lt 2 then begin
           print,'Are the extremas correct ? (0/1)'
           read,ansmm1
           if ansmm1 eq 1 then begin
              print,'Enter the new values (min first) '
              read,ymin,ymax
              yra=[ymin,ymax]
           endif
        endif else begin
           ansmm1 = 0 
        endelse 
     endwhile                   ; End non axi plot
     
     if (psf eq 1) then begin
        device,/close
        mv_var= 'mv '+namepsf+' '+dir+'/figs/'+namepsf
        print,mv_var
        spawn,mv_var
        set_plot,'x'
     endif else begin
        if notquiet le 1 then stop
     endelse
  endfor

end
  




