;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  see_shsl2.pro  -  Plot shell slices
;
;       usage:  see_shell_slices,dir,q,iter,recnum,glob=glob,sc=sc
;                                notquiet=notquiet,swap=swap,opl=opl,
;                                psf=psf,namepsf=namepsf,wnd=wnd,
;                                daysflag=daysflags,tv=tv,ortho=ortho
;               where dir      = data directory 
;                     qq       = output quantity index (starting at 1)
;                     sq       = statistical quantity ([0,1,2,3] =
;                                [normal,mean,diffrot,vorticity])
;                     iter     = iteration of output file
;                     recnum   = record number
;                     icutmax  = max cut (n_shells-1)
;                     rstar    = stellar radius
;                     to       = offset time
;                     lc       = list of cut we want to plot
;                     glob     = prefix of data directory
;                     sc       = prefix of filename
;                     notquiet = verbose if smaller than 2
;                     swap     = dependant of the endianess of the file
;                     opl      = set if overplot command should be used
;                     psf      = type of output (screen or .eps)
;                     namepsf  = name of the .eps output file
;                     wnd      = number of the output screen window
;                     daysflag = set if time units are days (rather than sec)
;                     tv       = set if image rather than contour plot is desired
;                     ortho    = set to [lcent,bcent] if orthographic
;                             projection is desired, where lcent and
;                             bcent are the longitude and latitude
;                             (respectively) of the tangent point of
;                             the projection, default=[0,35]
;                     flip     =   
; 
;       notes:  -tv keyword doesn't do anything at this point
;
;  M.DeRosa -  2 Sep 1998 - modified from Mark's routine
;             28 Jun 1999 - added ortho keyword
;  A.S.Brun - 29 Jun 1999 - added fil keyword
;           - 30 Jul 1999 - add psf keyword
;           - 28 May 2004 - adapted to ASH 1.2
;  A.S.Brun - 2009 - ASH 1.4 version
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names
@get_units
@colourbar

pro see_shsl2,dir,qq,sq,iter,recnum,icutmax=icutmax,lc=lc,rstar=rstar,to=to,$
              glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,psf=psf,$
              namepsf=namepsf,wnd=wnd,daysflag=daysflag,tv=tv,$
              ortho=ortho,flip=flip
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 5 then begin  
     print,'see_shsl2,dir,qq,sq,iter,recnum,icutmax=icutmax,rstar=rstar,glob=glob,'+$
           'sc=sc,notquiet=notquiet,swap=swap,opl=opl,psf=psf,'+$
           'namepsf=namepsf,wnd=wnd,daysflag=daysflag,tv=tv,ortho=ortho,flip=flip' 
     return 
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Check parameters, set default
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  see_shsl2.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  if n_elements(qq) eq 0 then begin
     print,'  see_shsl2.pro:  parameter qq must be set'
     return
  endif

  if n_elements(iter) eq 0 then begin
     print,'  see_shsl2.pro:  parameter iter must be set'
     return
  endif

  if n_elements(sq) eq 0 then begin
     print,'  see_shsl2.pro:  parameter sq must be set'
     return
  endif

  if n_elements(recnum) eq 0 then begin
     print,'  see_shsl2.pro:  parameter recnum must be set'
     return
  endif
  
  if not keyword_set(icutmax)  then icutmax  = -1
  while icutmax lt 0 do begin
     print,'Enter a value for icutmax'
     read,icutmax
  endwhile
  if not keyword_set(lc)       then lc       = lindgen(icutmax+1)
  if not keyword_set(rstar)    then rstar    = 1
  if not keyword_set(to)       then to       = 0
  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 0
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0 
  if not keyword_set(opl)      then opl      = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(namepsf)  then namepsf  = 'SHSL'
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(daysflag) then daysflag = 1
  if not keyword_set(tv)       then tv       = 1
  if not keyword_set(flip)     then flip     = 0
  if keyword_set(ortho) then begin
     if n_elements(ortho) lt 3 then begin
        if ortho eq 2 then begin
           lcent=0.0  &  bcent=35.0 
        endif else begin
           lcent=0.0  &  bcent=0.0
        endelse
        ortho=1;[ortho,lcent,bcent]
     endif else begin
        lcent=ortho(1)  &  bcent=ortho(2)
     endelse
  endif else ortho=0;[0.0,0.0,0.0]
  if glob eq 0 then begin
     dir="/dsm/stars2/f/cemeriau/EvolZR/"+dir
  endif

  r_sun = 6.957e10
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Graphic devices
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all

  !p.font=1
  !p.charsize=1.7
  device,set_font='Helvetica Italic',/tt_font
  
  vctr=bytarr(256) & vctg=vctr & vctb=vctr
  
  close,3 & openr,3,'./ctbin/ct42new.bin'
  readu,3,vctr,vctg,vctb
  tvlct,vctr,vctg,vctb
  
  loadct_mld,42

  nlevs=10                      ;  number of contour levels

  if psf eq 0 then begin
     set_plot,'x'
     device,decomposed=0
     window,wnd,xsize=1200,ysize=800
  endif else begin
     set_plot,'ps'
     title = get_name2(qq)
     namepsf=namepsf+'_'+STRCOMPRESS(title,/REMOVE_ALL)+'_0'+strcompress(iter,/r)+".eps"
     device,/encapsulated,/color,filename=namepsf,bits=8,xsize=40,ysize=28
  endelse

  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Set up filename etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  textnum=strcompress(iter,/r)

  case sc of
     1: file = dir+'SHSL/shsl_0'+textnum
     2: file = dir+'0'+textnum
     else: file = dir +textnum
  end

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Read SHSL files
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  read_shsl2,qq,file,recnum,sq,f=f,rad=rad,theta=theta,phi=phi,name=title,$
            time=time,notquiet=notquiet,swap=swap

  n_theta = size(theta) & n_theta = n_theta[1]
  n_phi   = size(phi)   & n_phi   = n_phi[1]
  lon=phi
  lat=reverse(90-theta*!radeg) ; latitude

  period=2*n_theta/n_phi  ; here to know if we have an angular periodicity

  n_shells = icutmax+1                                                    ; ??

  tetxu = get_unit2(title)
  
  if notquiet lt 2 then begin
     print,'normalized radius'
     print,strtrim(string(rad/rstar,format='(g10.2)'))
     print,'n_shells : ',n_shells
  endif


;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Set right multi-plots adjustments
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if (n_shells gt 3) then begin 
     if (n_shells mod 3 eq 0) then begin
        print,0
        n_shells1=n_shells
        muln=n_shells/3
        !p.multi=[0,3,muln]
     endif else if (n_shells mod 3 eq 1) then begin
        print,1
        n_shells1=n_shells+2
        muln=n_shells1/3
        !p.multi=[0,3,2]  
     endif else if (n_shells mod 3 eq 2) then begin
        print,2
        n_shells1=n_shells+1
        muln=n_shells1/3
        !p.multi=[0,3,muln]
     endif
  endif else begin
     !p.multi=[0,n_shells,1]
     n_shells1=3          
  endelse
  
  if (ortho eq 0) then begin
     if (n_shells gt 3) then begin
        !p.multi=[0,4,3]
        icut4=0
     endif else begin
        !p.multi=[0,1,3]
     endelse
  endif
  
  
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Used to put the right at the right place : as to be improved
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  erase
  icut2=0  ; ?? Find better solution
  xrmin=[0.07,0.4,0.73]  ; Find better solution
  xrmax=[0.26,0.59,0.92] ; IDEM

  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Plotting loop on icut
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^  

  fillfactor=fltarr(n_shells)*0.0

  print,time,time
  if psf eq 1 then begin
     if to eq 0 then begin
        to   = time/86400
        date = 0
     endif else begin
        time = time/86400
        date = time - to
     endelse
     print,'date : ',date
     jour = string(date,FORMAT='(F6.2)')
     print,jour
     xyouts,!d.x_size*19/40,!d.y_size*8/9,+strtrim(jour,2),/dev,charsize=2 
  endif
    
  for i=0,icutmax do begin
     icut = lc[i]

     ; Get v that we will plot
     vin = f(*,*,icut)
     if period gt 1 then begin
        v=fltarr(n_theta,n_phi*period,/noz)
        for i=0,period-1 do v(*,i*n_phi:(i+1)*n_phi-1)=vin
     endif else begin
        v=vin
     endelse
     
     ; fill place where v < 0 ??
     ddd=where(v lt 0.0) 
     sd=size(ddd)
     print,'filling factor',float(sd(1))/n_elements(v)
     fillfactor(i)=float(sd(1))/n_elements(v)
     
     print,'min,max,avg : ',min(v),max(v),mean(v) 


     ; Choose title for the graph 
     if sq eq 3 then begin ; Vorticity
        ttit='!7x!17!Dr!N'+' at r='+strcompress(rad(icut),/r)
        textu='s!U-1!N'
     endif
     
     if (rstar eq r_sun) then begin
        ttit=title+' @ r='+strtrim(string(rad(icut)/rstar,format='(g10.2)'),2)+' !17R!D!9n!N!17'
     endif else begin
        ttit=title+' @ r='+strtrim(string(rad(icut)/rstar,format='(g10.2)'),2)+' !17R!D*!N!17'
     endelse
     if notquiet lt 2 then print,title+' @ r='+strtrim(string(rad(icut)/rstar,format='(g10.2)'),2)+' R'
     
     ; Spacing and levels of the graph
     spacing=(max(v)-min(v))/(nlevs-1.)
     levs=min(v)+(findgen(nlevs))*(spacing*(nlevs-1.))/(nlevs-1.)
     mini=min(v) & maxi=max(v) 

     ;  Flip longitudes
     if flip eq 1  then v=reverse(v,1) 
     
     ; Warning double definition of levs : check which one is the best
     nlevs = 50
     levs  = get_contour_levels(v,nlevs,mn=mnv,mx=mxv,pct=0.04)
     
     if notquiet lt 2 then begin
        print,'Original: mnv,mxv',min(v),max(v)
        print,'Proposed: mnv,mxv',mnv,mxv
     endif
        
     if (notquiet lt 1) then begin
        ans1=0
        print,'Do you want to keep them (0/1)?'
        read,ans1
        if (ans1 eq 1) then begin
           Print,'Enter min/max'
           read,mnv,mxv
        endif
     endif
     
     if ortho then begin
        mag1=1.
        sclfact=1.
        print,sclfact
                             
        !p.multi(0)=n_shells1-icut2  
 
        if ortho eq 2 then begin
           print,'SPHERE'
           map_set,bcent,lcent,/ortho,/noer,/nobor,/iso,chars=3,ymar=[6,10],tit=ttit
        endif else if ortho eq 1 then begin
           map_set,bcent,lcent,/mollweide,/noer,/nobor,/iso,chars=3,ymar=[6,10],tit=ttit
        endif
        clip=!p.clip                                                                    ; get pictures boundary x0,y0,x1,y1

        offset=long((1-sclfact)*[clip(2)-clip(0),clip(3)-clip(1)]/2) ; original
        winsiz=double([!d.x_size,!d.y_size])
        pos=(clip+[offset,-offset])/[winsiz,winsiz]
        
        if ortho eq 2 then begin
           map_set,bcent,lcent,/ortho,/noer,/nobor,/iso,pos=pos ;  remap and display image on sphere
        endif else if ortho eq 1 then begin
           map_set,bcent,lcent,/mollweide,/noer,/nobor,/iso,pos=pos ;  remap and display image on sphere
        endif


        if (psf eq 1) then backval=abs(max(vin))*2 else backval=-abs(min(vin))*2
;        if period eq 1 and comp eq 1 then v(n_phi/2:n_phi-1,*)= v2(n_phi/2:n_phi-1,*)
        
        remap=map_image(v(0:n_phi*period-1,*),x0,y0,xsiz,ysiz,latmin=lat(0),latmax=lat(n_theta-1),$
                        lonmin=lon(0),lonmax=lon(n_phi*period-1),missing=backval,/bilinear,/compress,scale=0.07)

        scim,remap,scale=[mnv,mxv],outim=outim,/nowin,/quiet,/interp ; original
        tv,outim,x0,y0,xsiz=xsiz,ysiz=ysiz

        
;  put in equator and redraw horizon
        oplot,findgen(361)-lcent-90.,(replicate(0,361)),linestyle=5,thick=3,color=0
        map_horizon,thick=2     ;3
;
 ;                               ; now plot dotted line around full sphere
        if ortho eq 2 then begin
           map_set,bcent,lcent,/ortho,/noer,/nobor,/iso,pos=clip/[winsiz,winsiz] 
        endif else if ortho eq 1 then begin
           map_set,bcent,lcent,/mollweide,/noer,/nobor,/iso,pos=clip/[winsiz,winsiz] 
        endif
 ;       
 ;       offset=long((1-rstar/rad(icut)*mag1)*[clip(2)-clip(0),clip(3)-clip(1)]/2)
 ;       map_horizon,lines=1,thick=2
        
        if psf eq 0 then begin
           if (n_shells1 le 3) then begin ; to get the correct position of colourbars
              colourbar,[0.02+icut2*0.35,0.05,0.28+icut2*0.35,0.065],mn=mnv,mx=mxv,textu=textu
           endif else begin
              if (icut2 le 2) then begin
                 colourbar,[0.02+icut2*0.35,0.53,0.28+icut2*0.35,0.545],mn=mnv,mx=mxv,textu=textu ; changed mini in mnv idem maxi
              endif else begin
                 icut1 = icut2 mod 3
                 colourbar,[0.02+icut1*0.35,0.03,0.28+icut1*0.35,0.045],mn=mnv,mx=mxv,textu=textu ; changed mini in mnv idem maxi
              endelse
           endelse
        endif else begin
           if (n_shells1 le 3) then begin ;  to get the correct position of colourbars
              colourbar,[xrmin(icut),0.33,xrmax(icut),0.345],mn=mnv,mx=mxv,textu=textu;,plttype='ps'
           endif else begin
              if (icut2 le 2) then begin
                 colourbar,[0.02+icut2*0.35,0.56,0.28+icut2*0.35,0.57],mn=mnv,mx=mxv,textu=textu;,plttype='ps' ; changed mini in mnv idem maxi
              endif else begin 
                 icut1 = icut2 mod 3
                 print,0.02+icut1*0.35,0.06,0.28+icut1*0.35,0.07
                 colourbar,[0.02+icut1*0.35,0.06,0.28+icut1*0.35,0.07],mn=mnv,mx=mxv,textu=textu;,plttype='ps' ; changed mini in mnv idem maxi
              endelse
           endelse
        endelse
     endif else begin
        !y.margin=[4,4]
                                ;  set up coordinate system
;         if period eq 1 and comp eq 1 then v(n_phi/2:n_phi-1)= v2(n_phi/2:n_phi-1)
        
        contour,v,lon,lat,xr=[-180,180],yr=[-90,90],$
                /xsty,/ysty,tit=ttit,ytit='latitude [deg]',xtit='longitude [deg]',$
                /nodata,ticklen=-abs(!p.ticklen),charsiz=1.5,/isotropic
        
                                ;  overplot image
        x0=!p.clip(0)  &  y0=!p.clip(1)
        xsiz=!p.clip(2)-x0  &  ysiz=!p.clip(3)-y0
        if (psf eq 0) then remap=congrid(v,xsiz,ysiz) else remap=v
        scim,remap,scale=[mnv,mxv],outim=outim,/nowin
        xsiz = xsiz*1.8 & ysiz = ysiz*1.8
        tv,outim,x0,y0,xsiz=xsiz,ysiz=ysiz
        
                                ;  redraw border
        plots,[x0,x0,x0+xsiz,x0+xsiz,x0],[y0,y0+ysiz,y0+ysiz,y0,y0],/device
        
        if (n_shells gt 3) then begin
           icut3= icut mod 2
           if ((icut ne 0) and (icut3 eq 0)) then begin
              icut4=icut4+1
           endif
        endif else begin
           icut3 = 0
           icut4 = icut
        endelse
        
        if (psf eq 1) then begin
           colourbar2,[0.40+icut3*0.5,0.73-0.34*icut4,0.42+icut3*0.5,0.93-0.34*icut4],mn=mnv,mx=mxv,textu=textu,plttype='ps'
        endif else begin
           colourbar2,[0.40+icut3*0.50,0.73-0.34*icut4,0.42+icut3*0.50,0.93-0.34*icut4],mn=mnv,mx=mxv,textu=textu
        endelse
     endelse                    ; ortho=1
     
     icut2=icut2+1              ; icut ; has to be equal to icut if not for ApJ2000, see variable nn

  endfor

  if (psf eq 1) then begin
     device,/close
     mv_var='mv '+namepsf+' '+dir+'/figs/'+namepsf
     print,mv_var
     spawn,mv_var
     set_plot,'x'
  endif

  if notquiet lt 1 then stop
  !p.multi=0
  
end

