;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  spectra2.pro  -  Plot spectra from files cominf from get_spectra2
;   
;  usage : spectra2,file=file,icutmax=icutmax,rho=rho,mag=mag,ross=ross,$
;                   notquiet=notquiet,namepsf=namepsf,savef=savef,$
;                   psf=psf,q=q,rbcz=rbcz,fshsl=file_shsl,rstar=rstar,$
;                   swap=swap
;          where file     = output of get_spectra2
;                icutmax  = number of shells
;                rho      = density to calculate KE
;                mag      = also plot magnetic spectra
;                ross     = spectra on velocity components
;                notquiet = verbose if smaller than 2
;                namepsf  = name of output .ps file
;                savef    = save values as .idl files
;                psf      = type of output (screen or .eps)
;                q        = if greater than 1 plot spectra of q
;                rbcz     = percentage of radiative zone
;                fhsl     = path of the shsl file (to get radii of
;                shells)
;                rstar    = stellar radius
;                swap     = dependant of the endianess of files
;                licut    = list icut
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

pro see_spectra2,file,icutmax,rho=rho,mag=mag,psf=psf,notquiet=notquiet,$
             namepsf=namepsf,savef=savef,ross=ross,q=q,rbcz=rbcz,fshsl=fshsl,$
             rstar=rstar,swap=swap,glob=glob,yy=yy,licut=licut,nokolmo=nokolmo,$
             wnd=wnd,nomlz=nomlz,no_m=no_m

  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  if n_params() lt 2 then begin
     print,'spectra2,file,icutmax,rho=rho,mag=mag,psf=psf,'+$
           'notquiet=notquiet,namepsf=namepsf,savef=savef,'+$
           'ross=ross,q=q,rbcz=rbcz,fshsl=fshsl,rstar=rstar,'+$
           'swap=swap'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(name1)    then namepsf  = 'spectra.ps'
  if not keyword_set(rbcz)     then rbcz     = 0
  if not keyword_set(rho)      then rho      = ''
  if not keyword_set(savef)    then savef    = 0
  if not keyword_set(mag)      then mag      = 0
  if not keyword_set(ross)     then ross     = 0
  if not keyword_set(q)        then q        = 0
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(m)        then m        = 0
  if not keyword_set(yy)       then begin
     yra  = [1.d0,1.d8]
     yrb  = [1.d0,2.d9]
     yrm  = [1.d1,2.d9]
     yrm0 = [1.d2,2.d8]
  endif else begin
     yra  = yy
     yrb  = yy
     yrm  = yy
     yrm0 = yy
  endelse
  if not keyword_set(licut)    then licut    = lindgen(icutmax+1) 
  if not keyword_set(nokolmo)  then nokolmo  = 0    ; oplot fits (sucha as kolmogorov law)
  if not keyword_set(nomlz)    then nomlz    = 0    ; kinetic energy without m=0 or l=0 (depending of what is the variable)
  if not keyword_set(no_m)     then no_m     = 0    ; kinetic energy as a function of m
  if not keyword_set(fshsl) then begin
     print,"File SHSL : "
     read,fshsl
  endif
  if glob eq 0 then fshsl='/dsm/stars2/f/cemeriau/'+fshsl

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Graphics device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  !p.font=1
  device,set_font='Helvetica Italic',/tt_font
  
  device,decomposed=0
  r=[0,255,255,225,195,165,0,0,0,0,0,0]
  g=[0,255,0,0,0,0,0,0,0,0,255,225]
  b=[0,255,0,0,0,0,255,225,195,165,0,0]
  tvlct,r,g,b  
  dec=1
  
  if (psf eq 1) then begin
     set_plot,'ps'
     device,filename=name1,/color,/landscape
  endif

  if (psf eq 0) then  window,wnd,xsize=1600,ysize=800
  !x.style=1
  
  !p.thick=5 & !x.thick=6 & !y.thick=6 & !p.charsize=2.5
  !p.charthick=1.4
  
  if psf eq 1 then !p.charsize=1.5
  
  !p.multi = 0

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Time parameters
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  dt = 1.d0/(3600.d0*24.d0)
  P = dt * ((2.*!pi) / 2.6d-6)
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; File reading : shsl to get radius (to be improved)
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  dims=fltarr(2)
  
  close,1 & openr,1,fshsl,swap_endian=swap
  readu,1,d & N_Phi = fix(d)
  readu,1,d & N_Theta = fix(d)
  readu,1,d & N_Shells = fix(d)
  readu,1,d & N_quantities = fix(d)
  close,1 & openr,1,fshsl,swap_endian=swap
  shell_slices = assoc(1,fltarr(N_Theta,N_Phi+1,N_Shells,N_quantities))
  rad=reform(shell_slices(8,0,0:icutmax,0,0))
  
  icutmax1=icutmax
  icutmax2=icutmax
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Read 'get_spectra' file
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,2 & openr,2,file
  readu,2,dims
  l_max1 = long(dims(0)) & nt1 = long(dims(1))
  if (l_max1 eq 0 && nt1 eq 0) then begin
     close,2
     restore,file=file,/ver
     l_max1=long(dims(0)) 
     nt1 = long(dims(1))
     KE1=out
  endif else begin
     iter1 = fltarr(nt1) & time1 = fltarr(nt1)
     KE1 = fltarr(l_max1+1,l_max1+1,icutmax1+1)
     readu,2,iter1,time1
     readu,2,KE1
  endelse

  l_max2=l_max1
  
  if (mag gt 0) then begin
     lasti = STRPOS(file, '/', /REVERSE_SEARCH)
     print,'mag file :: ',strmid(file,0,lasti+1)+'mag_'+strmid(file,lasti+1)
     close,2 & openr,2,strmid(file,0,lasti+1)+'mag_'+strmid(file,lasti+1)
  endif else if (ross gt 0 ) then begin
     close,2 & openr,2,'pol_'+file
  endif
  
  magross = mag + ross
  
  if (magross gt 0) then begin
     readu,2,dims
     l_max2 = long(dims(0)) & nt2 = long(dims(1))
     iter2 = fltarr(nt2) & time2 = fltarr(nt2)
     KE2 = fltarr(l_max2+1,l_max2+1,icutmax2+1)
     readu,2,iter2,time2
     readu,2,KE2
     iter2=long(iter2)
     close,2
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculation on kinetic data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  Km1 = fltarr(l_max1+1,icutmax1+1)*0.d0 & Km1nol0=Km1
  Kl1 = fltarr(l_max1+1,icutmax1+1)*0.d0 & Kl1nom0=Kl1
  
  for i=0,l_max1 do for j=0,icutmax1 do Km1(i,j)=total(KE1(0:l_max1,i,j),/double)
  for i=0,l_max1 do for j=0,icutmax1 do Km1nol0(i,j)=total(KE1(1:l_max1,i,j),/double)
  for i=0,l_max1 do for j=0,icutmax1 do Kl1(i,j)=total(KE1(i,0:l_max1,j),/double)
  for i=0,l_max1 do for j=0,icutmax1 do Kl1nom0(i,j)=total(KE1(i,1:l_max1,j),/double)

  plot_io,Km1(*,0)
  stop
  
  E_kolmo1 = fltarr(l_max1+1) & E_k1 = E_kolmo1 & E_k1a = E_kolmo1 & E_k1b = E_k1a
  ll1 = findgen(l_max1+1)
  cte1=3e8
  for i=0,l_max1 do E_kolmo1(i)=cte1*i^(-5./3.)
  for i=0,l_max1 do E_k1(i)=cte1*i^(-2.)
  for i=0,l_max1 do E_k1a(i)=cte1*i^(-3.)
  for i=0,l_max1 do E_k1b(i)=cte1*i^(-4.)
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Calculation on magnetic or poloidal data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if (magross gt 0) then begin
     Km2 = fltarr(l_max2+1,icutmax2+1)*0.d0 & Km2nol0=Km2
     Kl2 = fltarr(l_max2+1,icutmax2+1)*0.d0 & Kl2nom0=Kl2
     
     for i=0,l_max2 do for j=0,icutmax2 do Km2nol0(i,j) = total(KE2(1:l_max2,i,j),/double)
     for i=0,l_max2 do for j=0,icutmax2 do Km2(i,j) = total(KE2(0:l_max2,i,j),/double)
     for i=0,l_max2 do for j=0,icutmax2 do Kl2nom0(i,j) = total(KE2(i,1:l_max2,j),/double)
     for i=0,l_max2 do for j=0,icutmax2 do Kl2(i,j) = total(KE2(i,0:l_max2,j),/double)
     
     E_kolmo2 = fltarr(l_max2+1)
     ll2 = findgen(l_max2+1) & E_k2 = E_kolmo2 & E_k2a = E_kolmo2
     cte2=3e8
     for i=0,l_max2 do E_kolmo2(i)=cte2*i^(-5./3.)
     for i=0,l_max2 do E_k2(i)=cte2*i^(-2.)
     for i=0,l_max2 do E_k2a(i)=cte2*i^(-3.)
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Save in IDL file (allow more precise or specific spectra manipulations)
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

 if (savef eq 1) then begin
     print,"Name of save file"
     sf=''
     read,sf
     if (magross gt 0) then begin
        save,file=sf,l_max1,l_max2,Km1,Kl1,Km1nol0,Kl1nom0,Km2,Kl2,Km2nol0,Kl2nom0,rad
     endif else begin
        save,file=sf,l_max1,Km1,Kl1,Km1nol0,Kl1nom0,rad
     endelse
  endif

  xra=[1,l_max1] & xra1=[0,l_max1]
  xrb=[1,l_max2] & xrb1=[0,l_max2]
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Transformation into energies
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if (not (strcmp(rho,''))) then begin
     restore,file=rho,/ver
                                ;dens1=dens
     coef=1.d0/8.d0/!dpi
     print,'density used',dens
  endif else begin
     print,'Constant definition'
     dens=dblarr(icutmax+1)
     dens(*) = 2
     coef  = 1
  endelse
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plot on kinetic data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  if (q eq 0) then begin 
     qname = 'KE'
     unit = '(erg/cm!U3!N)'
  endif else begin
     qname = get_name2(q)
     unit=''
  endelse
  
; Global kinetic energy as function of l

  llicut = size(licut) & llicut = llicut[1]

  if psf eq 0 then begin
     if nomlz eq 1 then !p.multi=[0,3,1] else !p.multi=0
  endif

  ansmm1 = 1
  while ansmm1 eq 1 do begin    ; To upgrade scaling
     tii = 0
     while where(licut eq tii) eq -1 do tii = tii+1 ; first cut
     plot_oo,0.5*dens(tii)*Kl1(*,tii),xtit='!5 degree l !5',ytit=qname+unit,yr=yra,/ys,xr=xra
     if (llicut ge 2) then begin
        for ii=tii+1,icutmax1 do begin
           if where(licut eq ii) gt -1 then begin
              print,rad(ii),rbcz*rstar
              if rad(ii) lt rbcz*rstar then begin
                 oplot,0.5*dens(ii)*Kl1(*,ii),color=3,line=ii
              endif else begin
                 oplot,0.5*dens(ii)*Kl1(*,ii),line=ii
              endelse
           endif
        endfor
     endif

     if nokolmo eq 1 then begin
        oplot,ll1(10:l_max1),E_kolmo1(10:l_max1),thick=1,color=6
        xyouts,l_max1/3.,1.1*E_kolmo1(l_max1/3.),'k!U-5/3!N',charsize=3,color=6
        oplot,ll1(10:l_max1),E_k1(10:l_max1),thick=1,color=6
        xyouts,l_max1/3.,1.1*E_k1(l_max1/3.),'k!U-2!N',charsize=3,color=6
        oplot,ll1(10:l_max1),E_k1a(10:l_max1),thick=1,color=6
        xyouts,l_max1/3.,1.1*E_k1a(l_max1/3.),'k!U-3!N',charsize=3,color=6
     endif
        
                               ; Separation between m=0 and m=/=0
     if (nomlz eq 1) then begin
                                ; No m=0 plots
        tii = 0
        while where(licut eq tii) eq -1 do tii = tii+1
        plot_oo,0.5*dens(tii)*Kl1nom0(*,tii),yr=yra,ys=1,xr=xra,xtit='!5 degree l !5',ytit=qname+'-'+qname+'(m=/=0) '+unit
        for ii=tii+1,icutmax1 do begin
           if where(licut eq ii) gt -1 then begin
              if rad(ii) lt rbcz*rstar then begin
                 oplot,0.5*dens(ii)*Kl1nom0(*,ii),line=ii,color=3
              endif else begin
                 oplot,0.5*dens(ii)*Kl1nom0(*,ii),line=ii              
              endelse
           endif
        endfor
                                ; m=0 plots
        tii = 0
        while where(licut eq tii) eq -1 do tii = tii+1
        plot_oo,0.5*dens(tii)*(Kl1(*,tii)-Kl1nom0(*,tii)),yr=yra,ys=1,xr=xra,xtit='!5 degree l !5',ytit=qname+'-'+qname+'(m=0) '+unit
        for ii=tii+1,icutmax1 do begin
           if where(licut eq ii) gt -1 then begin
              if rad(ii) lt rbcz*rstar then begin
                 oplot,0.5*dens(ii)*(Kl1(*,ii)-Kl1nom0(*,ii)),line=ii,color=3
              endif else begin
                 oplot,0.5*dens(ii)*(Kl1(*,ii)-Kl1nom0(*,ii)),line=ii              
                 endelse
           endif
        endfor
     endif
     
     if psf eq 0 then stop

     if notquiet lt 1 and psf eq 0 then begin
        print,'Are kinetic extrema correct ? (0/1)'
        read,ansmm1
        if ansmm1 eq 1 then begin
           print,'Enter new min-max values'
           read,ymmin,ymmax
           yra=[ymmin,ymmax]
        endif
     endif else begin
        ansmm1 = 0
     endelse
  endwhile
  
  
  if no_m eq 1 then begin
                                ; Global kinetic energy as function of m

     ansmm1 = 1
     while ansmm1 eq 1 do begin ; To upgrade scaling
        tii = 0
        while where(licut eq tii) eq -1 do tii = tii+1 ; first cut
        plot_oo,0.5*dens(tii)*Km1(*,tii),xtit='!5 azimu. wavenb. m',ytit=qname+unit,yr=yra,/ys,xr=xra
        if (llicut ge 2) then begin
           for ii=tii+1,icutmax1 do begin
              if where(licut eq ii) gt -1 then begin
                 print,rad(ii),rbcz*rstar
                 if rad(ii) lt rbcz*rstar then begin
                    oplot,0.5*dens(ii)*Km1(*,ii),color=3,line=ii
                 endif else begin
                 oplot,0.5*dens(ii)*Km1(*,ii),line=ii
              endelse
              endif
           endfor
        endif
                                ; Separation between m=0 and m=/=0
        if (nomlz eq 1) then begin
                                ; No m=0 plots
           tii = 0
           while where(licut eq tii) eq -1 do tii = tii+1
           plot_oo,0.5*dens(tii)*Km1nol0(*,tii),yr=yra,ys=1,xr=xra,xtit='!5 azimu. wavenb. m',ytit=qname+'-'+qname+'(l=/=0) '+unit
           for ii=tii+1,icutmax1 do begin
              if where(licut eq ii) gt -1 then begin
                 if rad(ii) lt rbcz*rstar then begin
                    oplot,0.5*dens(ii)*Km1nol0(*,ii),line=ii,color=3
                 endif else begin
                    oplot,0.5*dens(ii)*Km1nol0(*,ii),line=ii              
                 endelse
              endif
           endfor
                                ; m=0 plots
           tii = 0
           while where(licut eq tii) eq -1 do tii = tii+1
           plot_oo,0.5*dens(tii)*(Km1(*,tii)-Km1nol0(*,tii)),yr=yra,ys=1,xr=xra,xtit='!5 azimu. wavenb. m',ytit=qname+'-'+qname+'(l=0) '+unit
           for ii=tii+1,icutmax1 do begin
              if where(licut eq ii) gt -1 then begin
                 if rad(ii) lt rbcz*rstar then begin
                    oplot,0.5*dens(ii)*(Km1(*,ii)-Km1nol0(*,ii)),line=ii,color=3
                 endif else begin
                    oplot,0.5*dens(ii)*(Km1(*,ii)-Km1nol0(*,ii)),line=ii              
                 endelse
              endif
           endfor
        endif

        if psf eq 0 then stop

        if notquiet lt 1 and psf eq 0 then begin
           print,'Are kinetic extrema correct ? (0/1)'
           read,ansmm1
           if ansmm1 eq 1 then begin
              print,'Enter new min-max values'
              read,ymmin,ymmax
              yra=[ymmin,ymmax]
           endif
        endif else begin
           ansmm1 = 0
        endelse
     endwhile
  endif
     
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Plot on magnetic data
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  xx=.3 & yy=.05 
  
  if (mag gt 0) and (q eq 0) then begin

     if (notquiet lt 2) then begin
        print,'type .c to draw the magnetic spectrum'
        stop
     endif

     qname = 'ME'
     unit = '(erg/cm!U3!N)'
                                ; Global magnetic energy as function
                                ; of l 
     ansmm1 = 1
     while ansmm1 eq 1 do begin ; To upgrade scaling
        tii = 0
        while where(licut eq tii) eq -1 do tii = tii+1 ; first cut
        plot_oo,0.5*dens(tii)*Kl2(*,tii),xtit='!5 degree l !5',ytit=qname+unit,yr=yra,/ys,xr=xra
        if (llicut ge 2) then begin
           for ii=tii+1,icutmax1 do begin
              if where(licut eq ii) gt -1 then begin
                 print,rad(ii),rbcz*rstar
                 if rad(ii) lt rbcz*rstar then begin
                    oplot,0.5*dens(ii)*Kl2(*,ii),color=3,line=ii
                 endif else begin
                    oplot,0.5*dens(ii)*Kl2(*,ii),line=ii
                 endelse
              endif
           endfor
        endif
        
                                ; Separation between m=0 and m=/=0
        if (nomlz eq 1) then begin
                                ; No m=0 plots
           tii = 0
           while where(licut eq tii) eq -1 do tii = tii+1
           plot_oo,0.5*dens(tii)*Kl2nom0(*,tii),yr=yra,ys=1,xr=xra,xtit='!5 degree l !5',ytit=qname+'-'+qname+'(m=/=0) '+unit
           for ii=tii+1,icutmax1 do begin
              if where(licut eq ii) gt -1 then begin
                 if rad(ii) lt rbcz*rstar then begin
                    oplot,0.5*dens(ii)*Kl2nom0(*,ii),line=ii,color=3
                 endif else begin
                    oplot,0.5*dens(ii)*Kl2nom0(*,ii),line=ii              
                 endelse
              endif
           endfor
                                ; m=0 plots
           tii = 0
           while where(licut eq tii) eq -1 do tii = tii+1
           plot_oo,0.5*dens(tii)*(Kl2(*,tii)-Kl2nom0(*,tii)),yr=yra,ys=1,xr=xra,xtit='!5 degree l !5',ytit=qname+'-'+qname+'(m=0) '+unit
           for ii=tii+1,icutmax1 do begin
              if where(licut eq ii) gt -1 then begin
                 if rad(ii) lt rbcz*rstar then begin
                    oplot,0.5*dens(ii)*(Kl2(*,ii)-Kl2nom0(*,ii)),line=ii,color=3
                 endif else begin
                    oplot,0.5*dens(ii)*(Kl2(*,ii)-Kl2nom0(*,ii)),line=ii              
                 endelse
              endif
           endfor
        endif
     
        if psf eq 0 then stop
        
        if notquiet lt 1 and psf eq 0 then begin
           print,'Are magnetic extrema correct ? (0/1)'
           read,ansmm1
           if ansmm1 eq 1 then begin
              print,'Enter new min-max values'
              read,ymmin,ymmax
              yra=[ymmin,ymmax]
           endif
        endif else begin
           ansmm1 = 0
        endelse
     endwhile
  
  
     if no_m eq 1 then begin
                                ; Global magnetic energy as function of m
        ansmm = 1
        while ansmm1 eq 1 do begin ; To upgrade scaling
           tii = 0
           while where(licut eq tii) eq -1 do tii = tii+1 ; first cut
           plot_oo,0.5*dens(tii)*Km2(*,tii),xtit='!5 azimu. wavenb. m',ytit=qname+unit,yr=yra,/ys,xr=xra
           if (llicut ge 2) then begin
              for ii=tii+1,icutmax1 do begin
                 if where(licut eq ii) gt -1 then begin
                    print,rad(ii),rbcz*rstar
                    if rad(ii) lt rbcz*rstar then begin
                       oplot,0.5*dens(ii)*Km2(*,ii),color=3,line=ii
                    endif else begin
                       oplot,0.5*dens(ii)*Km2(*,ii),line=ii
                    endelse
                 endif
              endfor
           endif
                                ; Separation between m=0 and m=/=0
           if (nomlz eq 0) then begin
                                ; No m=0 plots
              tii = 0
              while where(licut eq tii) eq -1 do tii = tii+1
              plot_oo,0.5*dens(tii)*Km2nol0(*,tii),yr=yra,ys=1,xr=xra,xtit='!5 azimu. wavenb. m',ytit=qname+'-'+qname+'(l=/=0) '+unit
              for ii=tii+1,icutmax1 do begin
                 if where(licut eq ii) gt -1 then begin
                    if rad(ii) lt rbcz*rstar then begin
                       oplot,0.5*dens(ii)*Km2nol0(*,ii),line=ii,color=3
                    endif else begin
                       oplot,0.5*dens(ii)*Km2nol0(*,ii),line=ii              
                    endelse
                 endif
              endfor
                                ; m=0 plots
              tii = 0
              while where(licut eq tii) eq -1 do tii = tii+1
              plot_oo,0.5*dens(tii)*(Km2(*,tii)-Km2nol0(*,tii)),yr=yra,ys=1,xr=xra,xtit='!5 azimu. wavenb. m',ytit=qname+'-'+qname+'(l=0) '+unit
              for ii=tii+1,icutmax1 do begin
                 if where(licut eq ii) gt -1 then begin
                    if rad(ii) lt rbcz*rstar then begin
                       oplot,0.5*dens(ii)*(Km2(*,ii)-Km2nol0(*,ii)),line=ii,color=3
                    endif else begin
                       oplot,0.5*dens(ii)*(Km2(*,ii)-Km2nol0(*,ii)),line=ii              
                    endelse
                 endif
              endfor
           endif
           
           if psf eq 0 then stop
           
           if notquiet lt 1 and psf eq 0 then begin
              print,'Are magnetic extrema correct ? (0/1)'
              read,ansmm1
              if ansmm1 eq 1 then begin
                 print,'Enter new min-max values'
                 read,ymmin,ymmax
                 yra=[ymmin,ymmax]
              endif
           endif else begin
              ansmm1 = 0
           endelse
        endwhile
     endif
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Mid depth plot (not yet improved)
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if (psf eq 0) then begin  
     if (mag eq 0) and (notquiet lt 2) then begin
        print,'type .c to draw KE at mid depth'
        stop
     endif else begin
        if (mag eq 1) and (notquiet lt 2) then begin
           print,'type .c to draw KE & ME at mid depth'
           stop
        endif
     endelse
  endif
  
  if (psf eq 0 ) then begin
     window,2,xsize=1200,ysize=600
     !p.multi = 0
  endif

  xrc = [1,max(l_max1,l_max2)]
  if yra[0] lt yrb[0] then yic = yra[0] else  yic = yrb[0]
  if yra[1] gt yrb[1] then yac = yra[1] else  yac = yrb[1]
  yrc = [yic,yac]
  
  for midi=0,icutmax do begin
     print,'radius plotted r_mid=',rad(midi)
     print,'xrc',xrc,'yrc',yrc
     plot_oo,0.5*dens(midi)*Kl1(*,midi),xtit='!5 degree l',$   
             ytit='!5 KE - ME (erg/cm!U3!N)',yr=yrc,ys=1,xr=xrc,title=rad(midi)/rstar*100
     oplot,0.5*dens(midi)*KE1(*,0,midi),line=2
     if ( mag gt 0 ) then begin
        cc = 2
        if rad(midi) lt rbcz then cc = 6 
        oplot,coef*Kl2(*,midi),color=cc
        oplot,coef*KE2(*,0,midi),color=cc,line=2
        legend,['KE(l)','KE(l,m)','ME(l)','ME(l,m)'],linestyle=[0,2,0,2],color=[1-psf,1-psf,cc,cc],/top,/right,thick=[5,5,5,5]
     endif else begin
        legend,['KE(l)','KE(l,m=0)'],linestyle=[0,2],color=[1-psf,1-psf],/top,/right,thick=[5,5]
        if notquiet lt 2 then stop
     endelse
     if notquiet lt 2 then stop
  endfor
  
  if (mag gt 0) then begin   
     if (psf eq 0) then window,4,xsize=1200,ysize=600
     for midi=0,icutmax do begin
        plot_oo,coef*KE1(*,0,midi),xtit='!5 degree l',$   
                ytit='!5 ME & KE (m=0) (erg/cm!U3!N)',yr=yrm0,ys=1,xr=xrc,title=rad(midi)/rstar*100
        oplot,0.5*dens(midi)*KE2(*,0,midi),color=2
        legend,['KE','ME'],color=[1-psf,2],linestyle=[0,0],/top,/right,thick=[5,5]
        if notquiet lt 2 then stop
     endfor
  endif

  if psf eq 1 then begin
     device,/close
     set_plot,'x'
     !p.multi=0
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Diff of ME - KE and Etot spectrum
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  if (mag gt 0) then begin
     if notquiet lt 2 then begin
        print,'type .c to draw the diff of ME - Ke and Etot spectrum'
        stop
     endif
     set_plot,'ps'
     device,file='idl3.eps',/encapsulated
     
     diffE=fltarr(l_max1+1,6)*0.0 & Etot=diffE
     for i=0,5 do begin
        diffE(*,i)=coef*Kl2(*,i)-0.5*dens(i)*Kl1(*,i)
        Etot(*,i)=coef*Kl2(*,i)+0.5*dens(i)*Kl1(*,i)
     endfor
     
     plot,ll2,diffE(*,4),xtit='!5 degre l',ytit='E_R = ME - KE',line=1
     oplot,ll2,diffE(*,5),line=2
     oplot,ll2,diffE(*,2),line=0
     legend,['r=0.05 R','r=0.1 R','r=0.16 R'],linestyle=[1,2,0],/bottom,/right,charsize=1.2
     plot_oo,ll2,abs(diffE(*,4)),xtit='!5 degre l',ytit='|E_R| = |ME - KE|',yr=[1e4,1e9],/ys,xr=[1,l_max1],/xs,line=1
     oplot,ll2,abs(diffE(*,5)),line=2
     oplot,ll2,abs(diffE(*,2)),line=0
     plot,ll2,Etot(*,4),xtit='!5 degre l',ytit='Etot = ME + KE',line=1
     oplot,ll2,Etot(*,5),line=2
     oplot,ll2,Etot(*,2),line=0
     plot_oo,ll2,Etot(*,4),xtit='!5 degre l',ytit='Etot = ME + KE',xr=[1,l_max1],/xs,line=1
     oplot,ll2,Etot(*,5),line=2
     oplot,ll2,Etot(*,2),line=0
     plot,ll2,diffE(*,4)/ll2/Etot(*,4)^2,xtit='!5 degre l',ytitle='E_R / l Etot^2',line=1
     oplot,ll2,diffE(*,5)/ll2/Etot(*,5)^2,line=2
     oplot,ll2,diffE(*,2)/ll2/Etot(*,2)^2,line=0
     plot_oo,ll2,abs(diffE(*,4))/ll2/Etot(*,4)^2,xtit='!5 degre l',ytitle='|E_R| / l Etot^2',yr=[1e-11,1e-6],/ys,xr=[1,l_max1],/xs,line=1
     oplot,ll2,abs(diffE(*,5))/ll2/Etot(*,5)^2,line=2
     oplot,ll2,abs(diffE(*,2))/ll2/Etot(*,2)^2,line=0
     
;-----------------------
     device,/close
     set_plot,'x'
     !p.multi=0
  endif

end
  




