;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;
;  weights_legendre.pro - This function returns the Legendre integration
;                         weights given an array of collocation points x.
;
;  usage:  weights = weights_legendre(x)
;       where weights = Legendre integration weights
;             x = array of collocation points, i.e. the zeroes of the Legendre
;                 function (of the first kind) of order nx (where nx =
;                 number of elements in the array x)
;
;  M.DeRosa - 13 Oct 2000 - cannibalized from spherical_transform.pro
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

function weights_legendre,x

;  preliminaries
n_theta=n_elements(x)
weights=dblarr(n_theta)
costheta=double(x)
sintheta=sqrt(1-costheta^2)

   one = double(1) & two = double(2)
   Pi = 3.1415926535897932384626433832795028841972d+0

   ;------------------------------------------
   ; First compute the integration weights   
   ; run through the recurrence relations to get the
   ; derivative of the Legendre Polynomial of degree N_Theta.
   ; P is the Legendre Polynomial and D is its derivative
   Pm1 = 1.d0
   Dm1 = 0.d0
   P = x
   D = 1.d0
   for n=2,N_theta do begin       
       rn = one/double(n)
       Pm2 = Pm1
       Pm1 = P
       Dm2 = Dm1
       Dm1 = D
       P = (two-rn)*x*Pm1 - (one-rn)*Pm2
       D = Dm2 + (two*n-one)*Pm1
      endfor
   weights = two/((1-x*x)*D*D)

   ; get the normalization straight for the ffts
   weights = weights * (2.d0*Pi)
   return,weights

end


