;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;   driver.pro  -  Integrator of IDL routines
;       usage:     driver,input_file
;     
;  A.S.Brun, Constance and J. Varela - 25/03/2015
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@choice 

pro driver,driver_input

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Input main (Check the sub programs for more information of the internal variables)
;
;  The directory structure must be the next to avoid problems:
;          main directory                          = dir
;           folder for Scalar subprogram           = dir/Scalar (ASH Scalar output)
;           folder for flux_bal subprogram         = dir/SHAV   (ASH Shell_Avgs output)
;           folder for see_az_avgs subprogram      = dir/AZAV   (ASH AZ_Avgs output)
;           folder for see_shell_slices subprogram = dir/SHSL   (ASH Shell_Slices output)
;           folder for see_eq_slices subprogram    = dir/EQSL   (ASH Equatorial_Slices output)
;           folder for psf ouput                   = dir/figs
;                      
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Read input file if existing 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  choice1 = '1' 
  res    = dictionary()

  if (n_params() eq 0) then begin ; no input file

     print,'No input file'
     print,'==> Analysis parameters will be asked'

; The first parameters we need are to know the data directory and if
; the data are HD or MHD

     res  = dictionary()
     GV   = dictionary()

     ans1 = ''
     print,'Enter case directory'
     read,ans1
     GV['dir'] = ans1

     ans1      = 0.0
     print,'HD or MHD analysis ? (0/1)'
     read,ans1
     GV['hydro'] = ans1

  endif else begin ; there is an input file
     if n_params() eq 1 then begin

        if isa(driver_input, /number) eq 0 then begin
           parser,driver_input,res
       endif else begin
           print,'Format input error : input file name has to be a string'
           return
        endelse

     endif else begin

        print,'Input error : too many parameters --> only need input file name'
        return

     endelse
  endelse

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Print choices
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  while (choice1 ne '') do begin
     
     print,' '
     print,'******************************'
     print,' Analysis choice '
     print,'******************************'
     print,' '
     print,'* 1  : Scalar'
     print,'* 2  : Shell Averages' 
     print,'* 3  : Equatorial slices'
     print,'* 4  : Shell slices'
     print,'* 5  : Azimuthal averages'
     print,' '
     print,'* 6  : Flux Balance'
     print,'* 7  : Spectra'
     print,'* 8  : Butterfly diagram latitudinal'
     print,'* 9  : Butterfly diagram radial'
     print,'* 10 : Angular Momentum' 
     print,'* 11 : Magnetic field production'
     print,' '
     print,'* 12 : alpha-omega effect'
     print,' '
     print,'* 0  : change case'
     print,' '
     print,'Which analysis ? : '
     read,choice1
;     if isa(choice1,/number) eq 0 then choice1=''
     if choice1 ne '' then begin
        choice,choice1,res
     endif 
  endwhile
  print,'Bye, bye !!'
end 
