;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  see_shell_slices.pro  -  Reads in shell_slice and plots
;
;       usage:  see_shell_slices,q,iter,recnum,dir,ndigits=ndigits,t_o=t_o,
;                 /daysflag,/opl,/tv,/ortho
;               where q = output quantity index (starting at 1)
;                     iter = iteration of output file
;                     recnum = record number
;                     dir = data directory
;                     ndigits = number of digits in filename (default=6)
;                     t_o = time offset (default=0.0)
;                     daysflag = set if time units are days (rather than sec)
;                     opl = set if overplot command should be used
;                     tv = set if image rather than contour plot is desired
;                     ortho = set to [lcent,bcent] if orthographic
;                             projection is desired, where lcent and
;                             bcent are the longitude and latitude
;                             (respectively) of the tangent point of
;                             the projection, default=[0,35]
;		      fill = set if color
;                     psf = 0 => window output =1 => postscript file 
;
;       notes:  -tv keyword doesn't do anything at this point
;
;  M.DeRosa -  2 Sep 1998 - modified from Mark's routine
;             28 Jun 1999 - added ortho keyword
;  A.S.Brun - 29 Jun 1999 - added fil keyword
;           - 30 Jul 1999 - add psf keyword
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names
@get_units

pro filter_shsl_dip,q,iter,recnum,dir,ndigits=ndigits,t_o=t_o,$
  daysflag=daysflag,flip=flip,opl=opl,tv=tv,ortho=ortho,fil=fil,psf=psf,swap=swap,sc=sc

psf = 0 
  vctr=bytarr(256) & vctg=vctr & vctb=vctr

  close,3 & openr,3,'./ctbin/ct42new.bin'
  readu,3,vctr,vctg,vctb
  tvlct,vctr,vctg,vctb
  
;  usage message
  if n_params() lt 4 then begin
     print,'  filter_shsl,q,iter,recnum,dir,ndigits=ndigits,t_o=t_o,'+$
           '/daysflag,/opl,/tv,ortho=[lcent,bcent],fil=fil,psf=psf'
     return
  endif

;  check parameters, set defaults
  if n_elements(q) eq 0 then begin
     print,'  see_shell_slices.pro:  parameter q must be set'
     return
  endif
  if n_elements(iter) eq 0 then begin
     print,'  see_shell_slices.pro:  parameter iter must be set'
     return
  endif
  if n_elements(recnum) eq 0 then begin
     print,'  see_shell_slices.pro:  parameter recnum must be set'
     return
  endif
  if n_elements(dir) eq 0 then begin
     print,'  see_shell_slices.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'
  if n_elements(ndigits) eq 0 then ndigits=7 else ndigits=fix(ndigits)
  if n_elements(t_o) eq 0 then t_o=0.0 else t_o=float(t_o)
  if keyword_set(daysflag) then daysflag=1b else daysflag=0b
  if keyword_set(opl) then opl=1b else opl=0b
  if keyword_set(tv) then tv=1b else tv=0b
  if keyword_set(ortho) then begin
     if n_elements(ortho) lt 2 then begin
        lcent=0.0  &  bcent=35.0
     endif else begin
        lcent=ortho(0)  &  bcent=ortho(1)
     endelse
     ortho=1b
  endif else ortho=0b
  if keyword_set(fil) then fil=1
  if keyword_set(psf) then psf=1
  if not keyword_set(sc) then sc=1
  
  if (psf eq 1) then begin
     name1=' '
     set_plot,'ps'
     print,'enter a name for the .ps file (.ps will be added)'
     read,name1
     device,/landscape,/color,bits=8,filename=name1+'.ps'
  endif
  
  daysflag=1

;  set up filename
  textnum=strcompress(iter,/r)
;while (strlen(textnum) lt ndigits) do textnum='shsl_0'+textnum
  if sc eq 1 then begin
     file=dir +'shsl_0'+textnum
  endif
  
;  associate data file
  
  read_shsl2,q,file,recnum,sq=sq,swap=swap,$  
             f=f,iteration=iteration,time=time,deltat=deltat,name=name,$
             rad=rad,theta=theta,phi=phi
  
  n_phi    = size(phi)   & n_phi    = n_phi(1)
  n_theta  = size(theta) & n_theta  = n_theta(1)
  n_shells = size(rad)   & n_shells = n_shells(1)
  
  period=2*n_theta/n_phi
  
  print,'Resolution NtxNphi:',n_theta,n_phi
  print,'Angular periodicity:',period
  
;  read in theta,phi indices, quantity codes
  shell_radius=rad

  costheta = cos(theta)
  sintheta = sin(theta)
  
  title = get_name2(q)
  lon=phi(0:N_phi-1)
  lat=reverse(90-acos(costheta(*))*!radeg) ; latitude
  
  textu = get_unit2(title)
  
  r_sun=6.9599e10
  rstar=9.0*r_sun
  print,'normalized radius'
  print,strtrim(string(shell_radius/rstar,format='(g10.2)'))

;  read in shell slice data and plot
  
  if (n_shells gt 3) then begin ; 01/27/00 really easy setting!!!
     !p.multi=[0,3,2]
     n_shells1=n_shells         ;+2;+1 ;3  has to be equal to n_shells if not for ApJ2000
  endif else begin
     !p.multi=[0,n_shells,1]
     n_shells1=3                ; n_shells ; has to be equal to n_shells if not for ApJ2000
  endelse
  
  if (ortho eq 0) then begin
     if (n_shells gt 3) then begin
        !p.multi=[0,2,3] 
        icut4=0
     endif else begin
        !p.multi=[0,1,3]
     endelse
  endif
  
  erase
  
  if daysflag then time=time/(3600.*24d0)
  

  dv1=fltarr(N_theta,N_phi) & dv2=dv1
  vort_r=0
  icut2=0
  
  nn=1
  
  deb=0                         ; 1;0
  sub=1                         ; 5 ;1;3 ; originally sub=1
  totshell=n_shells-sub
  
  !p.multi=[0,2,2]
  
  for icut=deb,totshell,nn do begin
     vin=reform(f(*,1:n_phi,icut))
     if period gt 1 then begin
        v=fltarr(n_theta,n_phi*period,/noz)
        for i=0,period-1 do v(*,i*n_phi:(i+1)*n_phi-1)=vin
     endif else begin
        v=vin
     endelse
     
     if (rstar eq r_sun) then begin
        ttit=title+' @ r='+strtrim(string(shell_radius(icut)/rstar,format='(g10.2)'),2)+' !17R!D!9n!N!17'
     endif else begin
        ttit=title+' @ r='+strtrim(string(shell_radius(icut)/rstar,format='(g10.2)'),2)+' !17R!D*!N!17'
     endelse
     
     print,title+' @ r='+strtrim(string(shell_radius(icut)/rstar,format='(g10.2)'),2)+' R'

     
     spacing=(max(v)-min(v))/(nlevs-1.)
     
     levs=min(v)+(findgen(nlevs))*(spacing*(nlevs-1.))/(nlevs-1.)
     
     mini=min(v) & maxi=max(v)  ; modif 02/26/00 correct number but reduce color
     
     v=transpose(v)
     
     v=reverse(v,2)                           ;  put field in order of increasing latitudes (not theta)
     if keyword_set(flip) then v=reverse(v,1) ;  flip longitudes
     
;  determine contour levels / image scale
     nlevs=10                   ;  number of contour levels
;  levs=get_contour_levels(v,nlevs,mn=mnv,mx=mxv)
     levs=get_contour_levels(v,nlevs,mn=mnv,mx=mxv,pct=0.04)
     print,'Original: mnv,mxv',min(v),max(v)
     print,'Proposed: mnv,mxv',mnv,mxv
     print,'Do you want to keep them (0/1)?'
     read,ans1
     if (ans1 eq 1) then begin
        Print,'Enter min/max'
        read,mnv,mxv
     endif
     
     if ortho then begin
        mag1=1.                 ;  2.
        sclfact=1.              ; mag1*shell_radius(icut)/rstar
        print,sclfact
        
                                ; be careful between n_shells and n_shells1
        !p.multi(0)=n_shells1-icut2                                      ;  map_set,/advance does not work properly
        map_set,bcent,lcent,/ortho,/noer,/nobor,/iso,chars=1.8,ymar=[6,10] ;,tit=ttit,/adv
        clip=!p.clip                                                       ; get pictures boundary x0,y0,x1,y1
        
        offset=long((1-sclfact)*[clip(2)-clip(0),clip(3)-clip(1)]/2) ; original
        winsiz=double([!d.x_size,!d.y_size])
        
        pos=(clip+[offset,-offset])/[winsiz,winsiz]

        map_set,bcent,lcent,/ortho,/noer,/nobor,/iso,$
                pos=pos         ;(clip+[offset,-offset])/[winsiz,winsiz]
        
                                ;  remap and display image on sphere
        if (psf eq 1) then backval=abs(max(vin))*2 else backval=-abs(min(vin))*2
        
        remap=map_image(v(0:n_phi*period-1,*),x0,y0,xsiz,ysiz,latmin=lat(0),latmax=lat(n_theta-1),$
        lonmin=lon(0),lonmax=lon(n_phi*period-1),missing=backval,/bilinear,/compress,scale=0.05)
        
        scim,remap,scale=[mnv,mxv],outim=outim,/nowin,/quiet,/interp ; original
        tv,outim,x0,y0,xsiz=xsiz,ysiz=ysiz
        
;  put in equator and redraw horizon
        oplot,findgen(361)-lcent-90.,replicate(0,361),linestyle=5,thick=3,color=0
        map_horizon,thick=2     ;3
        
                                ; now plot dotted line around full sphere
;;;    map_set,bcent,lcent,/ortho,/noer,/nobor,/iso,pos=clip/[winsiz,winsiz] ; original
        
        offset=long((1-rstar/shell_radius(icut)*mag1)*[clip(2)-clip(0),clip(3)-clip(1)]/2)
;;;    map_horizon,lines=1,thick=2
        
        if psf eq 0 then begin
           if (n_shells1 le 3) then begin ; to get the correct position of colourbars
              colourbar,[0.02+icut2*0.35,0.03,0.28+icut2*0.35,0.045],mn=mnv,mx=mxv,textu=textu
           endif else begin
              if (icut le 2) then begin
                 colourbar,[0.02+icut*0.35,0.53,0.28+icut*0.35,0.545],mn=mnv,mx=mxv,textu=textu ; changed mini in mnv idem maxi
              endif else begin
                 icut1 = icut mod 3
                 colourbar,[0.02+icut1*0.35,0.03,0.28+icut1*0.35,0.045],mn=mnv,mx=mxv,textu=textu ; changed mini in mnv idem maxi
              endelse
           endelse
        endif else begin
           if (n_shells1 le 3) then begin ;  to get the correct position of colourbars
              colourbar,[0.02+icut2*0.35,0.03,0.28+icut2*0.35,0.045],mn=mnv,mx=mxv,textu=textu,plttype='ps'
           endif else begin
              if (icut le 2) then begin
                 colourbar,[0.02+icut*0.35,0.51,0.28+icut*0.35,0.52],mn=mnv,mx=mxv,textu=textu,plttype='ps' ; changed mini in mnv idem maxi
              endif else begin 
                 icut1 = icut mod 3
                 colourbar,[0.02+icut1*0.35,0.01,0.28+icut1*0.35,0.02],mn=mnv,mx=mxv,textu=textu,plttype='ps' ; changed mini in mnv idem maxi
              endelse
           endelse
        endelse
        
     endif else begin
        if (psf eq 0) then wset,0
        !y.margin=[4,4]
                                ;  set up coordinate system
        contour,v,lon,lat,xr=[-180,180],yr=[-90,90],$
                /xsty,/ysty,tit=ttit,ytit='!17 latitude !3[!17deg!3]',xtit='!17 longitude !3[!17deg!3]!17',$
                /nodata,ticklen=-abs(!p.ticklen),charsiz=1.5,/isotropic
        
                                ;  overplot image
        x0=!p.clip(0)  &  y0=!p.clip(1)
        xsiz=!p.clip(2)-x0  &  ysiz=!p.clip(3)-y0
        if (psf eq 0) then remap=congrid(v,xsiz,ysiz) else remap=v
        scim,remap,scale=[mnv,mxv],outim=outim,/nowin
        tv,outim,x0,y0,xsiz=xsiz,ysiz=ysiz
        
                                ;  redraw border
        plots,[x0,x0,x0+xsiz,x0+xsiz,x0],[y0,y0+ysiz,y0+ysiz,y0,y0],/device
        
        help,v
        
                                ; spherical transform of v
        vhat=spherical_transform_new2(v, costheta) ; uses Marc routines
        
        help,vhat
        lmx=size(vhat)
        lmx=lmx(1)
        print,'l_max:',lmx
        
        checktrans = 0
        if (checktrans eq 1) then begin    
                                ; inverse spherical transform of v
           vp= inv_spherical_transform_new2(vhat, costheta) ; uses Marc routines
           
           levs=get_contour_levels(vp,nlevs,mn=mnv,mx=mxv,pct=0.04)
           print,'Original: mnv,mxv',min(v),max(v)
           print,'Proposed: mnv,mxv',mnv,mxv
           print,'Do you want to keep them (0/1)?'
           read,ans1
           if (ans1 eq 1) then begin
              Print,'Enter min/max'
              read,mnv,mxv
           endif     
           
           !y.margin=[4,4]
                                ;  set up coordinate system
           contour,vp,lon,lat,xr=[-180,180],yr=[-90,90],$
                   /xsty,/ysty,tit=ttit,ytit='!17 latitude !3[!17deg!3]',xtit='!17 longitude !3[!17deg!3]!17',$
                   /nodata,ticklen=-abs(!p.ticklen),charsiz=1.5,/isotropic
           
                                ;  overplot image
           x0=!p.clip(0)  &  y0=!p.clip(1)
           xsiz=!p.clip(2)-x0  &  ysiz=!p.clip(3)-y0
           if (psf eq 0) then remap=congrid(vp,xsiz,ysiz) else remap=vp
           scim,remap,scale=[mnv,mxv],outim=outim,/nowin
           tv,outim,x0,y0,xsiz=xsiz,ysiz=ysiz
           
                                ;  redraw border
           plots,[x0,x0,x0+xsiz,x0+xsiz,x0],[y0,y0+ysiz,y0+ysiz,y0,y0],/device
        endif                   ; checktrans
        
        
        
                                ; inverse spherical transform of v dipole l=1 m=0,1   ; vhat(l,m)
        print,'Now l=1'
        mm1=1 & print,'lmax1',mm1
        vhat_dip=vhat
        vhat_dip(2:*,2:*)=0.0d0
        vhat_dip(0,0)=0.0d0 & vhat_dip(2:*,0)=0.0d0 & vhat_dip(2:*,1)=0.0d0
                                ;  vhat_dip(1,1)=0.0d0 ; to get only l=1,m=0  comment line below
                                ;  vhat_dip(1,0)=0.0d0 ; to get only l=1,m=1  comment line above
;stop
                                ; vp2= inv_spherical_transform_new2(vhat, costheta, mrange=[0,mm1], lmax=mm1)   ; uses Marc routines
        vp2= inv_spherical_transform_new2(vhat_dip, costheta,lmax=1)
        vhat2=spherical_transform_new2(vp2, costheta)
        
        levs=get_contour_levels(vp2,nlevs,mn=mnv,mx=mxv,pct=0.04)
        print,'Original: mnv,mxv',min(vp2),max(vp2)
        print,'Proposed: mnv,mxv',mnv,mxv
        print,'Do you want to keep them (0/1)?'
        read,ans1
        if (ans1 eq 1) then begin
           Print,'Enter min/max'
           read,mnv,mxv
        endif     
        
        !y.margin=[4,4]
                                ;  set up coordinate system
        contour,vp2,lon,lat,xr=[-180,180],yr=[-90,90],$
                /xsty,/ysty,tit=ttit,ytit='!17 latitude !3[!17deg!3]',xtit='!17 longitude !3[!17deg!3]!17',$
                /nodata,ticklen=-abs(!p.ticklen),charsiz=1.5,/isotropic
        
                                ;  overplot image
        x0=!p.clip(0)  &  y0=!p.clip(1)
        xsiz=!p.clip(2)-x0  &  ysiz=!p.clip(3)-y0
        if (psf eq 0) then remap=congrid(vp2,xsiz,ysiz) else remap=vp2
        scim,remap,scale=[mnv,mxv],outim=outim,/nowin
        tv,outim,x0,y0,xsiz=xsiz,ysiz=ysiz
        
                                ;  redraw border
        plots,[x0,x0,x0+xsiz,x0+xsiz,x0],[y0,y0+ysiz,y0+ysiz,y0,y0],/device
        
                                ; inverse spherical transform of v , l=2, m=0,1,2
        print,'Now l=2'
        vhat_quad=vhat
        vhat_quad(3:*,3:*)=0.0d0
        vhat_quad(0:1,0:1)=0.0d0 & vhat_quad(3:*,0)=0.0d0 & vhat_quad(3:*,1)=0.0d0 & vhat_quad(3:*,2)=0.0d0
;      vhat_quad(2,1:2)=0.0d0 ; to get only l=2,m=0  comment both lines below
;      vhat_quad(2,0)=0.0d0  & vhat_quad(2,2)=0.0d0 ; to get only l=2,m=1  comment line above & below
;      vhat_quad(2,0:1)=0.0d0 ; to get only l=2,m=2  comment both lines above
        
        vp3= inv_spherical_transform_new2(vhat_quad, costheta,lmax=2) ; uses Marc routines
        print,'done v_quad'
                                ;     vp3= inv_spherical_transform_new2(vhat, costheta, mrange=[1,2], lmax=2)   ; uses Marc routines
        vhat3=spherical_transform_new2(vp3, costheta)
        
        levs=get_contour_levels(vp3,nlevs,mn=mnv,mx=mxv,pct=0.04)
        print,'Original: mnv,mxv',min(vp3),max(vp3)
        print,'Proposed: mnv,mxv',mnv,mxv
        print,'Do you want to keep them (0/1)?'
        read,ans1
        if (ans1 eq 1) then begin
           Print,'Enter min/max'
           read,mnv,mxv
        endif     
        
        !y.margin=[4,4]
                                ;  set up coordinate system
        contour,vp3,lon,lat,xr=[-180,180],yr=[-90,90],$
                /xsty,/ysty,tit=ttit,ytit='!17 latitude !3[!17deg!3]',xtit='!17 longitude !3[!17deg!3]!17',$
                /nodata,ticklen=-abs(!p.ticklen),charsiz=1.5,/isotropic
        
                                ;  overplot image
        x0=!p.clip(0)  &  y0=!p.clip(1)
        xsiz=!p.clip(2)-x0  &  ysiz=!p.clip(3)-y0
        if (psf eq 0) then remap=congrid(vp3,xsiz,ysiz) else remap=vp3
        scim,remap,scale=[mnv,mxv],outim=outim,/nowin
        tv,outim,x0,y0,xsiz=xsiz,ysiz=ysiz

                                ;  redraw border
        plots,[x0,x0,x0+xsiz,x0+xsiz,x0],[y0,y0+ysiz,y0+ysiz,y0,y0],/device
        
        print,'.c to get the other modes, but inv_transform can take some time....'
        stop
        
                                ; inverse spherical transform of v [high m's]
        vp4= inv_spherical_transform_new2(vhat, costheta, mrange=[3,lmx-1]) ; uses Marc routines
        vhat4=spherical_transform_new2(vp4, costheta)
        
        levs=get_contour_levels(vp4,nlevs,mn=mnv,mx=mxv,pct=0.04)
        print,'Original: mnv,mxv',min(vp4),max(vp4)
        print,'Proposed: mnv,mxv',mnv,mxv
        print,'Do you want to keep them (0/1)?'
        read,ans1
        if (ans1 eq 1) then begin
           Print,'Enter min/max'
           read,mnv,mxv
        endif     
        
        !y.margin=[4,4]
      ;  set up coordinate system
        contour,vp4,lon,lat,xr=[-180,180],yr=[-90,90],$
                /xsty,/ysty,tit=ttit,ytit='!17 latitude !3[!17deg!3]',xtit='!17 longitude !3[!17deg!3]!17',$
                /nodata,ticklen=-abs(!p.ticklen),charsiz=1.5,/isotropic
        
                                ;  overplot image
        x0=!p.clip(0)  &  y0=!p.clip(1)
        xsiz=!p.clip(2)-x0  &  ysiz=!p.clip(3)-y0
        if (psf eq 0) then remap=congrid(vp4,xsiz,ysiz) else remap=vp4
        scim,remap,scale=[mnv,mxv],outim=outim,/nowin
        tv,outim,x0,y0,xsiz=xsiz,ysiz=ysiz
        
                                ;  redraw border
        plots,[x0,x0,x0+xsiz,x0+xsiz,x0],[y0,y0+ysiz,y0+ysiz,y0,y0],/device
        
                                ; original spectra and filtered ones
        if (psf eq 0) then window,2
        
        KE=abs(vhat)^2
        Km = dblarr(lmx) & Kl=Km
        for i=0,lmx-1 do Km(i)=total(KE(0:lmx-1,i),/double)
        for i=0,lmx-1 do Kl(i)=total(KE(i,0:lmx-1),/double)
        
        plot_oo,Kl,title='Original Spectra',xr=[1,lmx],xs=1,yr=[1e-12,2e-7],ys=1
        oplot,Km,line=2
        legend,['l spectrum','m spectrum'],linestyle=[0,1],color=[0,0],/bottom,/left
        
        KE=abs(vhat2)^2
        for i=0,lmx-1 do Km(i)=total(KE(0:lmx-1,i),/double)
        for i=0,lmx-1 do Kl(i)=total(KE(i,0:lmx-1),/double)
        
        plot_oo,Kl,title='Filtered Spectra (low m''s)',xr=[1,lmx],xs=1,yr=[3e-10,2e-7],ys=1
        oplot,Km,line=2
        
        KE=abs(vhat3)^2
        for i=0,lmx-1 do Km(i)=total(KE(0:lmx-1,i),/double)
        for i=0,lmx-1 do Kl(i)=total(KE(i,0:lmx-1),/double)
        
        plot_oo,Kl,title='Filtered Spectra (mid m''s)',xr=[1,lmx],xs=1,yr=[1e-12,2e-9],ys=1
        oplot,Km,line=2
        
        KE=abs(vhat4)^2
        for i=0,lmx-1 do Km(i)=total(KE(0:lmx-1,i),/double)
        for i=0,lmx-1 do Kl(i)=total(KE(i,0:lmx-1),/double)
        
        plot_oo,Kl,title='Filtered Spectra (high m''s)',xr=[1,lmx],xs=1,yr=[1e-14,1e-11],ys=1
        oplot,Km,line=2
        
        if (psf eq 1) then begin 
           device,/close
           set_plot,'x'
        endif
        
        stop
        
        if (n_shells gt 3) then begin
           icut3= icut mod 2
           if ((icut ne 0) and (icut3 eq 0)) then begin
              icut4=icut4+1
           endif
        endif else begin
           icut3 = 0
           icut4 = icut
        endelse

        if (psf eq 1) then begin
           colourbar2,[0.40+icut3*0.5,0.73-0.34*icut4,0.42+icut3*0.5,0.93-0.34*icut4],mn=mnv,mx=mxv,textu=textu,plttype='ps'
;;     colourbar2,[0.675,0.055+0.34*icut3,.69,0.245+0.34*icut3],mn=mini,mx=maxi,textu=textu,plttype='ps'
        endif else begin
           colourbar2,[0.40+icut3*0.50,0.73-0.34*icut4,0.42+icut3*0.50,0.93-0.34*icut4],mn=mnv,mx=mxv,textu=textu
;;     colourbar2,[0.675,0.07+0.34*icut3,0.69,0.26+0.34*icut3],mn=mini,mx=maxi,textu=textu
        endelse
     endelse                    ; ortho=1
     
     icut2=icut2+1              ; icut ; has to be equal to icut if not for ApJ2000, see variable nn
  endfor
  
  if (psf eq 1) then begin 
     device,/close
     set_plot,'x'
  endif
  
;  cleanup
  free_lun,unit
  !p.multi=0

end









