;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; To read
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

pro image_polar,a,r,costheta,spacing=spacing,amap=amap,title=title,$
                interface=interface,flip = flip,vmin=vmin,noborder=noborder,$
                levels=levels,c_labels=c_labels,c_thick=c_thick,mini=mini,$
                maxi=maxi,blackline=blackline,rbcz=rbcz

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Input settings
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  device,decomposed=0

  if keyword_set(flip) then begin
     sz = size(a) & N_theta = sz(1)
     b = a     
     for i=0,N_theta-1 do a(i,*) = b(N_theta-1-i,*)
  endif
  
  theta = !pi*.5 - acos(costheta)
  rmax = max(r) & rmin = min(r)
  
  if not keyword_set(spacing) then spacing = .01*rmax
  if not keyword_set(title) then title = ' '
  if not keyword_set(rbcz) then rbc=0 else rbc=rbcz 
  if keyword_set(vmin) then begin
     amin = vmin
  endif else begin
     amin = min(a)
  endelse

  ;; modif 09/10/01 , find out that in image_contour mini and maxi
  ; are not taken into account. Thus I decided to modify that: new keywords mini & maxi.
  amap = polar_surface(transpose(a),r,theta,/grid,missing=amin, $
                       bound=[0,-rmax,rmax,rmax],spacing=spacing*[0.1,0.1])
  
  sz=size(amap) & nx=sz(1) & ny=sz(2)
  x=amap & y=x
  for i=0,ny-1 do x(*,i) = rmax*findgen(nx)/(nx-1)
  for i=0,nx-1 do y(i,*) = 2.*rmax*findgen(ny)/(ny-1) - rmax
  rad = sqrt(x^2+y^2)
  ind=where(rad lt rmin)
  amap(ind) = amin 
  
  if keyword_set(c_labels) then begin
     image_contour,amap,xx=findgen(nx),yy=findgen(ny),title=title,$
                   levels=levels,/noaxis,c_labels=c_labels,c_thick=c_thick,$
                   mini=mini,maxi=maxi,blackline=blackline,aspect=1
  endif else begin
     image_contour,amap,xx=findgen(nx),yy=findgen(ny),title=title,$
                   levels=min(amap),/noaxis,mini=mini,maxi=maxi,aspect=1
;     if not keyword_set(noborder) then contour,amap,/overplot,nlevels=10
  endelse 
  
  if not keyword_set(noborder) then begin
     x=findgen(nx) & y=sqrt((nx-1)^2-x^2)
     oplot,x,(nx-1)+y,thick=2 & oplot,x,(nx-1)-y,thick=2
     
; plot the small ticks every 15 degree
     plots,(nx-1)*[1,1.025],[nx-1,nx-1],thick=2
     theta_tick=[15,30,45,60,75,90]*2*!pi/360.
     for ii=0,5 do begin
        plots,(nx-1)*[1,1.025]*cos(theta_tick(ii)),(nx-1)+(nx-1)*[1,1.025]*sin(theta_tick(ii)),thick=2
        plots,(nx-1)*[1,1.025]*cos(theta_tick(ii)),(nx-1)+(nx-1)*[1,1.025]*sin(-1*theta_tick(ii)),thick=2
     endfor     
     
     x0=x & x0(*)=0 
     oplot,x0,y*1.01,thick=2 & oplot,x0,y+(nx-1),thick=2
     y0=x & y0(*)=nx-1 & oplot,x,y0,linestyle=2,thick=2  ;,color=2
     xyouts,2,(nx-1)+2,'!17 EQ',charthick=2,charsize=1.2 ;,color=2
     cte1=rmin*(nx-1)/rmax & theta1=!pi*0.5 - theta(0)
     oplot,[cte1,nx-1]*sin(theta1),(nx-1)+[cte1,nx-1]*cos(theta1),thick=2 ;color=2
     oplot,[cte1,nx-1]*sin(theta1),(nx-1)-[cte1,nx-1]*cos(theta1),thick=2 ;color=2
     x=x*cte1/100. & y=sqrt(cte1^2-x^2)
     
     x=rebin(x,3*nx) & y=rebin(y,3*nx)
     theta2=cte1*sin(theta1) 
     
;    little loop to find the closest index for x to be equal to theta2 06/08/00
     inda=where(fix(x) eq fix(theta2))
     
;     print,"INDA :: ",inda; & help,inda
     sza=size(inda) & print,sza(1)
     
     if (inda(0) gt 0) then begin 
        indb=inda(0) 
     endif else begin
        print,'check indices in image_polar.pro'
        indb=0
        sza(1)=1
     endelse
     diff=abs(x(indb)-theta2)
     for i=0,sza(1)-1 do begin
        diff1=abs(x(inda(i))-theta2)
        if (diff1 le diff) then begin
           diff=diff1 & indb=inda(i)
        endif
     endfor
     
     oplot,x(indb:3*nx-1),(nx-1)+y(indb:3*nx-1),thick=2 ;,color=2  ; indices originaux 23 va avec 9 & 118
     oplot,x(indb:3*nx-1),(nx-1)-y(indb:3*nx-1),thick=2 ;,color=2
     
     
     rbc=rbc*(nx-1)
     if (rbc ne 0) then begin
        x=findgen(nx) & indmm=fix(rbc*sin(theta2*!pi/180.0))
        oplot,x(indmm:nx-1),(nx-1)+sqrt(rbc^2-x(indmm:nx-1)^2),line=2,thick=2
        oplot,x(indmm:nx-1),(nx-1)-sqrt(rbc^2-x(indmm:nx-1)^2),line=2,thick=2
     endif     
     if keyword_set(interface) then begin
        xx=interface*findgen(50)/49.
        oplot,xx,sqrt(interface^2-xx^2),line=2,thick=2
        oplot,xx,-sqrt(interface^2-xx^2),line=2,thick=2
     endif
     
  endif   
  return
end








