;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  invariants.pro  -  Plot azimuthal averages
;
;       usage:  invariants,dir,q,sq,iter,recnum,rbcz=rbcz,rstar=rstar,to=to,
;               idmx=idmx,glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,
;               psf=psf,namepsf=namepsf,wnd=wnd,legendd=legendd,tv=tv
; 
;               where dir      = data directory
;                     q        = output quantity index (starting at 1)
;                     sq       = 
;                     iter     = iteration of output file
;                     recnum   = record number
;                     rbcz     = percentage of the radiative zone
;                     idmx     = amplitude of theta
;                     glob     = prefix of data directory    
;                     sc       = prefix of filenames 
;                     notquiet = verbose if smaller than 2
;                     swap     = change endianess of the file 
;                     psf      = output screen or psf    
;                     namepsf  = name of the .eps output file           
;                     wnd      = number of the window for screen
;                     output  
;                     tv       = set if image rather than contour plot
;                     is desired
;                     flip     = reverse latitudes
;                     build    = 0 if want invariants 1 for plotting soluces
; 
;  M.DeRosa - 27 Aug 1998 - modified from Mark's routine
;  A.S. Brun - many modif - adapted to ASH 1.2
;  A.S. Brun - 2009 - ASH 1.4 version
;  C.Emeriau-Viard - June 2016 - Version 2.0 
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_units
@get_names
@colourbar
@magnetic_components

pro invariants,dir,iter,recnum,rbcz=rbcz,rmin=rmin,idmx=idmx,glob=glob,$
               sc=sc,notquiet=notquiet,swap=swap,psf=psf,namepsf=namepsf,$
               wnd=wnd,flip=flip,build=build,rstar=rstar

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 3 then begin
     print,' invariants,dir,iter,recnum,rbcz=rbcz,rmin=rmin,idmx=idmx,'+$
           'glob=glob,sc=sc,notquiet=notquiet,swap=swap,psf=psf,namepsf=namepsf,'+$
           'wnd=wnd,flip=flip,build=build'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Input settings
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  invariants.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

 if n_elements(iter) eq 0 then begin
     print,'  invariants.pro:  parameter iter must be set'
     return
  endif
  if n_elements(recnum) eq 0 then begin
     print,'  invariants.pro:  parameter recnum must be set'
     return
  endif

  if not keyword_set(rbcz)        then rbcz        = 1
  if not keyword_set(rmin)        then rmin        = 0 
  if not keyword_set(idmx)        then idmx        = 0
  if not keyword_set(glob)        then glob        = 0
  if not keyword_set(sc)          then sc          = 0
  if not keyword_set(notquiet)    then notquiet    = 0
  if not keyword_set(swap)        then swap        = 0
  if not keyword_set(psf)         then psf         = 0
  if not keyword_set(namepsf)     then namepsf     = 'Theory'
  if not keyword_set(wnd)         then wnd         = 0
  if not keyword_set(flip)        then flip        = 0
  if not keyword_set(build)       then build       = 0
 
  tv = 1 
  
  if glob eq 0 then begin
     dir  = '/dsm/stars2/f/cemeriau/EvolZR/'+dir
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
; Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all
  
  r=[0b,255b,130b,255b,255b,0b  ,0b  ,0b  ,255b,255b]
  g=[0b,255b,130b,0b  ,0b  ,0b  ,255b,255b,255b,170b]
  b=[0b,255b,130b,0b  ,255b,255b,255b,0b  ,0b  ,0b  ]
  tvlct,r,g,b

;  loadct_mld,41
  device,set_font='Helvetica',/tt_font

  if (psf eq 0) then begin
     set_plot,'x'
     window,wnd,xs=700,ys=900
     device,decomposed=0
  endif else begin
     set_plot,'ps'
     title=get_name2(q) & if notquiet lt 1 then print,title
     namepsf=namepsf+'_'+STRCOMPRESS(title,/REMOVE_ALL)+'_0'+strcompress(iter,/r)+".eps"
     device,/landscape,/color,bits=8,filename=namepsf;,xsize=8,ysize=8
  endelse

  !p.multi=[0,2,1]

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Set up filename
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  textnum=strcompress(iter,/r)
  case sc of 
     0: file = dir+'/AZAV/azav_0'+textnum 
     1: file = dir+'/AZAV/azav_0'+textnum+'_special'
     else: file = dir +textnum
  end

  sq=1
  read_azav2,76,file,recnum,f=h_azav,notquiet=notquiet,swap=swap,rad=rad,theta=theta
  read_azav2,22,file,recnum,f=hc_azav,notquiet=notquiet,swap=swap
  read_azav2,40,file,recnum,f=L_azav,notquiet=notquiet,swap=swap
  read_azav2,67,file,recnum,f=E_azav,notquiet=notquiet,swap=swap

  case sc of 
     0: file = dir+'/SHAV/shav_0'+textnum 
     1: file = dir+'shav_0'+textnum
     else: file = dir +textnum
  end
  
  read_shav2,76,file,recnum,f=h_shav,notquiet=notquiet,swap=swap
  read_shav2,22,file,recnum,f=hc_shav,notquiet=notquiet,swap=swap
  read_shav2,67,file,recnum,f=E_shav,notquiet=notquiet,swap=swap
  
  case sc of 
     0: file = dir+'/Scalar/scalar_0'+textnum 
     1: file = dir+'scalar_0'+textnum
     else: file = dir +textnum
  end

  read_scalar2,7,file,recnum,f=hc_scalar,notquiet=notquiet,swap=swap     
  read_scalar2,2,file,recnum,f=L_scalar,notquiet=notquiet,swap=swap

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Integrate data to get invariants :: Par besoin de MPSI dans le cas axi
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  n_r      = size(rad)   & n_r      = n_r[1] 
  
; Delimited radiative zone
  irad_max = n_r-1 - fix(rmin*n_r)
  irad_min = n_r-1 - fix(rbcz*n_r)
  
  if irad_min le 0 then  irad_min=0
  
  if notquiet le 1 then print,'Limits of the ZR : ',irad_min,irad_max
  
  n_rr = irad_max-irad_min+1
  
  ht_aux  = dblarr(n_rr)
  htc_aux = dblarr(n_rr)
  L_aux  = dblarr(n_rr)
  
  for i=irad_min,irad_max do begin
     ir = i-irad_min
     ht_aux(ir)    = int_tabulated(theta,h_azav(*,i) *sin(theta))
     htc_aux(ir)   = int_tabulated(theta,hc_azav(*,i)*sin(theta))
     L_aux(ir)    = int_tabulated(theta,L_azav(*,i) *sin(theta))
  endfor
  ht_aux = reverse(ht_aux)
  htc_aux = reverse(htc_aux)
  l_aux = reverse(l_aux)

  Rt = rstar*rbcz
  Rb = rstar*rmin  

  V = 1.0/3*(rt^3-rb^3)
  
  print,rb,rt,v

  E    = 8*!pi*int_tabulated(theta,E_azav(*,irad_min)*sin(theta))  
  Ea   = 8*!pi*E_shav(irad_min)
  

  radius = reverse(rad[irad_min:irad_max])


  h_aux  = reverse(h_shav[irad_min:irad_max])       
  hc_aux = reverse(hc_shav[irad_min:irad_max])       

  plot,radius,h_aux
  oplot,radius,ht_aux*2,color=3
  stop
  plot,radius,hc_aux
  oplot,radius,htc_aux*2,color=3


  h    = int_tabulated(radius,h_aux*radius^2)
  hc   = int_tabulated(radius,hc_aux*radius^2)
  L    = int_tabulated(radius,L_aux*radius^2)

  print,'Magnetic helicity : ',h/2
  print,'Cross-helicity : ',hc,hc_scalar*V
  print,'Angular momentum : ',L,l_scalar*V
  print,'Amplitude',E,Ea*2
  return

end








