;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  read_scalar_zone2.pro  -  Calculate data used in
;                                         scalar but not implemented
;                                         in shav
;
;       usage: read_scalar_zone2,qq,file,recnum,sq,f=f,rad=rad,name=name,
;                       notquiet=notquiet,swap=swap
;               where qq        = output quantity index
;                     file      = filename
;                     recnum    = record number
;                     sq        = statistical quantity ([0,1,2,3,4,5]=[mean,variance
;                               skewness,kurtosis,min,max]), default=0
;                     rbcz      = positive for CZ and negative for RZ
;                     f         = output quantity (array in that routine)
;                     rad       = output radius
;                     iteration = iteration
;                     time      = output time
;                     deltat    = time step
;                     name      = quantity name
;                     notquiet  = verbose if smaller then 2
;                     swap      = dependant of the endianess of the file
;
;  M.DeRosa - 4 Sep 1998 - modified from Mark's routine
;  A.S. Brun - 2009 - ASH 1.4 version
;  C.Emeriau-Viard - 10 May 2016 - Version 2.0 (adapted from see_shell_avgs14)
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@radial_integration

pro read_scalar_zone2,qq,file,recnum,sq=sq,rbcz=rbcz,f=f,rad=rad,iteration=iteration,$
                      time=time,deltat=deltat,name=name,notquiet=notquiet,$
                      swap=swap

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_params() lt 3 then begin
     print,'read_scalar_zone2,qq,file,recnum,sq,rbcz,f=f,rad=rad,'+$
           'name=name,notquiet=notquiet,swap=swap'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(qq) eq 0 then begin
     print,'  read_scalar_zone2.pro:  parameter q must be set'
     return
  endif
  if n_elements(file) eq 0 then begin
     print,'  read_scalar_zone2.pro:  parameter file must be set'
     return
  endif
  if n_elements(recnum) eq 0 then begin
     print,'  read_scalar_zone2.pro:  parameter recnum must be set'
     return
  endif
  if n_elements(sq) eq 0 then begin
     print,'  read_scalar_zone2.pro:  parameter sq must be set'
  endif
  if n_elements(rbcz) eq 0 then begin
     print,'  read_scalar_zone2.pro:  parameter rbcz must be set'
  endif
  if not keyword_set(notquiet) then notquiet = 0
  if not keyword_set(swap)     then swap     = 0

  ll     = strlen(file)
  lastss = STRPOS(file, '/', /REVERSE_SEARCH)
  file   = STRMID(file,0,lastss-6)+'SHAV/shav'+STRMID(file,lastss+7,ll-lastss-7)

  name = get_scalar_name2(qq)
  case qq of
     0: begin
         read_shav2,10,file,recnum,sq=0,f=f1,rad=rad,time=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
         read_shav2,67,file,recnum,sq=0,f=f2,rad=rad,time=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
         f = f1 + f2
      end
     1 : read_shav2,10,file,recnum,sq=0,f=f,rad=rad,time=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     2 : begin
        ll = strlen(file)
        lastss = STRPOS(file, '/', /REVERSE_SEARCH)
        file2 = STRMID(file,0,lastss-4)+'AZAV/azav'+STRMID(file,lastss+5,ll-lastss-5)
        
        read_azav2,9,file2,recnum,f=f1,rad=rad,theta=theta,time=time,name=name,notquiet=notquiet,swap=swap
        
        name = 'Angular momentum'
        
        nt = size(theta) & nt = nt[1] & nr = size(rad) & nr = nr[1]
        tt = dblarr(nt,nr) & rr = dblarr(nt,nr)
        
        for i=0,nt-1 do rr[i,*]=rad
        for j=0,nr-1 do tt[*,j]=theta
        
        fint = rr^3*sin(tt)^2*f1

        f = dblarr(nr)
        for i=0,nr-1 do f[i] = int_tabulated(theta,fint[*,i])
     end
     3 : read_shav2,20,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     6 : read_shav2,24,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     7 : read_shav2,22,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     8 : read_shav2,23,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     9 : read_shav2,43,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     10: read_shav2,44,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     12: read_shav2,45,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     15: read_shav2,29,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     16: begin
        read_azav2,28,file2,recnum,f=rho,rad=rad,theta=theta,time=time,name=name,notquiet=notquiet,swap=swap
        read_azav2,28,file2,recnum,f=temp,rad=rad,theta=theta,time=time,name=name,notquiet=notquiet,swap=swap
        cv = 1 ;; TO BE CHANGED 
        fint = rho*cv*temp
        nr = size(rad)   & nr = nr(1)
        nt = size(theta) & nt = nt(1)
        for it=0,nt-1 do begin
           fint(it,*) = fint(it,*)*rad^2
        endfor
        for ir=0,nr-1 do begin
           fint(*,ir) = fint(*,ir)*sin(theta)
           f(ir) = int_tabulated(theta,fint(*,ir))
        endfor
        f = f/2 ; normalize by 'int sin(theta)'
     end
     61: read_shav2,67,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     62: read_shav2,76,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     63: begin
        read_shav2,97,file,recnum,sq=0,f=f1,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
        read_shav2,99,file,recnum,sq=0,f=f2,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
        f = f1 + f2
        name = 'Poloidal ME'
     end
     64: begin
        read_shav2,98,file,recnum,sq=0,f=f1,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
        read_shav2,96,file,recnum,sq=0,f=f2,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
        f = f1 + f2
        name = 'Toroidal ME'
     end
     65: read_shav2,91,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     66: read_shav2,92,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     67: read_shav2,93,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     68: read_shav2,77,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     70: read_shav2,78,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     71: read_shav2,80,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     74: read_shav2,95,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     75: read_shav2,94,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     76: read_shav2,92,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     77: read_shav2,91,file,recnum,sq=0,f=f,rad=rad,t=time,name=name,notquiet=notquiet,swap=swap,deltat=deltat
     else: begin
        f=0
        name = ''
     end
  endcase

  i_end     = size(f) & i_end=i_end[1]-1
  rr = abs(rbcz)
  int_value = radial_integration(rad[0:i_end-1],f[0:i_end-1],rbcz=rr,test=2) 
  if rbcz ge 0 then f = int_value[0] else f = int_value[1]

end








