;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;   see_eqsl.pro  -  Plot equatorial slices
;
;       usage:  see_eqsl,dir,qq,sq,iter,recnum,rbcz=rbcz,to=to,glob=glob,
;                        sc=sc,notquiet=notquiet,swap=swap,psf=psf,  
;                        namepsf=namepsf,wnd=wnd,legendd=legendd,tv=tv,
;                        xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax
;               where dir      = data directory
;                     qq       = quantity index 
;                     sq       = statistical quantity ([0,1,2,3]=
;                                [normal,vrms,mean,log])
;                     iter     = iteration
;                     recnum   = record per file
;                     rstar    = stellar radius
;                     rbcz     = percentage of the radiative zone
;                     to       = starting time
;                     glob     = prefix of data directory  
;                     sc       = prefix of filenames 
;                     notquiet = verbose if smaller than 2 
;                     swap     = dependant of the endianess of files
;                     opl      = plot comparison between two models   
;                     psf      = type of output (screen or .eps) 
;                     namepsf  = name of the .eps output file 
;                     wnd      = window number
;                     legendd  = legend is set if 0 and is hidden either
;                     tv       = set if image rather than contour plot is desired
;                     vmin     = min   
;                     vmax     = max   
;
;  A.S.Brun and J. Varela - 17/03/2015 - user friendly version
;  C.Emeriau-Viard - 19 May 2016 - Version 2.0
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names
@colourbar

pro see_eqsl2,dir,qq,sq,iter,recnum,rbcz=rbcz,to=to,$
              dir2=dir2,qq2=qq2,sq2=sq2,iter2=iter2,recnum2=recnum2,$
              glob=glob,sc=sc,swap=swap,notquiet=notquiet,psf=psf,namepsf=namepsf,$
              wnd=wnd,legendd=legendd,tv=tv,xmin=xmin,xmax=xmax,ymin=ymin,$
              ymax=ymax,interface=interface
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   

  if n_params() lt 5 then begin
     print,' see_eqsl2,dir,qq,iter,sq,recnum,rbcz=rbcz,to=to,'+$
           'dir2=dir2,qq2=qq2,sq2=sq2,iter2=iter2,recnum2=recnum2,'+$
           'glob=glob,sc=sc,swap=swap,notquiet=notquiet,psf=psf,namepsf=namepsf,'+$
           'wnd=wnd,legendd=legendd,tv=tv,xmin=xmin,xmax=xmax,ymin=ymin,'+$
           'ymax=ymax,interface=interface'
     return
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   
; Check parameters, set default values
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   

  close,/all

  if n_elements(dir) eq 0 then begin
     print,'  see_eqsl2.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'
  if keyword_set(dir2) then begin
     if strmid(dir2,strlen(dir2)-1,1) ne '/' then dir2=dir2+'/'
  endif

  if n_elements(qq) eq 0 then begin
     print,'  see_eqsl2.pro:  parameter q must be set'
     return
  endif
  
  if n_elements(sq) eq 0 then begin
     print,'  see_eqsl2.pro:  parameter sq must be set'
     return
  endif
  
  if n_elements(iter) eq 0 then begin
     print,'  see_eqsl2.pro:  parameter iter must be set'
     return
  endif
  
  if n_elements(recnum) eq 0 then begin
     print,'  see_eqsl2.pro:  parameter recnum must be set'
     return
  endif
  
  if keyword_set(dir2) or keyword_set(qq2) or keyword_set(sq2) or $
     keyword_set(iter2) or keyword_set(recnum2) then comp = 1 $
  else comp = 0


  if not keyword_set(dir2)      then dir2      = dir
  if not keyword_set(qq2)       then qq2       = qq
  if not keyword_set(sq2)       then sq2       = sq
  if not keyword_set(iter2)     then iter2     = iter
  if not keyword_set(recnum2)   then recnum2   = recnum
  if not keyword_set(rbcz)      then rbcz      = 0
  if not keyword_set(to)        then to        = 0
  if not keyword_set(glob)      then glob      = 0
  if not keyword_set(sc)        then sc        = 1
  if not keyword_set(notquiet)  then notquiet  = 0
  if not keyword_set(swap)      then swap      = 0
  if not keyword_set(opl)       then opl       = 0
  if not keyword_set(psf)       then psf       = 0
  if not keyword_set(namepsf)   then namepsf   = "EQSL"
  if not keyword_set(wnd)       then wnd       = 0
  if not keyword_set(legendd)   then legendd   = 0
  if not keyword_set(tv)        then tv        = 1  
  if not keyword_set(interface) then interface = 1
  
  
  if (glob eq 0) then begin
     dir  ="/dsm/stars2/f/cemeriau/EvolZR/"+dir
     if comp eq 1 then dir2 ="/dsm/stars2/f/cemeriau/EvolZR/"+dir2
  endif
  
  if comp eq 1 then begin
     aux_s = size(rbcz) & aux_s1 = aux_s(0) & aux_s2 = aux_s(1) 
     case 1 of
        aux_s1 eq 0: begin
           rbcz1 = rbcz
           rbcz2 = rbcz
        end
        aux_s1 eq 1: begin
           if aux_s2 eq 1 then begin
              rbcz1 = rbcz(0)
              rbcz2 = rbcz(0)
           endif else begin
              rbcz1 = rbcz(0)  
              rbcz2 = rbcz(1)  
           endelse
        end
     end

     aux_s = size(swap) & aux_s1 = aux_s(0) & aux_s2 = aux_s(1) 
     case 1 of
        aux_s1 eq 0: begin
           swap1 = swap
           swap2 = swap
        end
        aux_s1 eq 1: begin
           if aux_s2 eq 1 then begin
              swap1 = swap(0)
              swap2 = swap(0)
           endif else begin
              swap1 = swap(0)  
              swap2 = swap(1)  
           endelse
        end
     end
     swap = swap1
  endif     

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
; Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
  
  loadct_mld,41
  device,set_font='Helvetica',/tt_font
  
  if psf eq 0 then begin
     set_plot,'x'
     window,wnd,xsize=1000,ysize=1000
     device,decomposed=0
  endif else begin
     set_plot,'ps'
     title = get_name2(qq) & if notquiet eq 2 then print,title
     namepsf=namepsf+'_'+STRCOMPRESS(title,/REMOVE_ALL)+'_mean-'+strcompress(fix(sq),/r)+'_0'+strcompress(iter,/r)
     if comp eq 1 then namepsf = namepsf+'_0'+strcompress(iter2,/r)
     namepsf = namepsf+'.eps'
     device,/encapsulated,/color,bits=8,filename=namepsf,xsize=16,ysize=16 
  endelse
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
;  Set up filename etc. 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
  
  textnum=strcompress(iter,/r) 
  case sc of 
     1: file  = dir+'EQSL/eqsl_0'+textnum
     2: file  = dir+'0'+textnum
     else: file  = dir +textnum
  endcase
  
  if comp eq 1 then begin
     textnum2 = strcompress(iter2,/r)
     case sc of 
        1: file2  = dir2+'EQSL/eqsl_0'+textnum2
        2: file2  = dir2+'0'+textnum2
        else: file2  = dir2 +textnum2
     endcase
  endif

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Associate data file
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  read_eqsl2,qq,file,recnum,sq=sq,f=vres1,t=t,rad=radius,nlats=nlats,name=name,notquiet=notquiet,swap=swap,nphi=nphi
  if comp eq 1 then read_eqsl2,qq2,file2,recnum2,sq=sq2,f=vres2,t=t2,rad=radius2,nlats=nlats2,name=name2,notquiet=notquiet,swap=swap2,nphi=nphi2

  if to eq 0 then begin
     to   = t 
     date = 0
  endif else begin
     date = t - to
  endelse

  !p.multi = [0,nlats,1]

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Plots : Contours and min, max
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  n_r  = size(radius)  & n_r  = n_r[1]
  if comp eq 1 then begin
     n_r2 = size(radius2) 
     n_r2 = n_r2[1]
  endif

  for il = 0, nlats - 1 do begin ; loop over latitudes (often 1)

     v1  = vres1(*,*,il)
     
     if comp eq 1 then begin
        v2  = vres2(*,*,il)
        
        v11 = v1(*,0:Nphi/2-1)
        v22 = v2(*,Nphi/2:Nphi-1)
     endif

     nlevs=10
     levs=get_contour_levels(v1,nlevs,mn=mnv,mx=mxv,pct=0.04)
     
     print,'Original: mnv,mxv',min(v1),max(v1)
     print,'Proposed: mnv,mxv',mnv,mxv
     if keyword_set(vmin) and keyword_set(vmax) then begin
        mnv = vmin
        mxv = vmax
        print,'Choosen : mnv,mxv',mnv,mxv
     endif else begin
        if not keyword_set(vmin) and not keyword_set(vmax) then begin
           if notquiet eq 2 then begin
              print,'Do you want tok keep them (0/1)?'
              read,ans1
              if (ans1 eq 1) then begin
                 Print,'Enter min/max'
                 read,mnv,mxv
              endif
           endif
        endif else begin
           print,'One of the min-max values is missing'
        endelse
     endelse
     
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Plots : settings
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
     
     if interface eq 1 then begin ; plot features as border or ticks
        if keyword_set(tv) then begin ; plot color and not only contours
           date = date/86400
           if date < 0 then date = 0
           print,'DATE :::::::::',date,strcompress(date,/r)
           if comp eq 1 then image_eq_comp,v11,v22,radius,interface=interface,mini=mnv,maxi=mxv,rbcz=rbcz,title=strcompress(date,/r)$
           else image_eq,v1,radius,interface=interface,mini=mnv,maxi=mxv,rbcz=rbcz,psf=psf
        endif else begin
           contour_lat,v1,radius,interface=interface,$
                       tit=title+': theta = '+strtrim(lat_angle(il),2)
        endelse
     endif else begin
        if keyword_set(tv) then begin
           if comp eq 1 then image_eq_comp,v11,v22,radius,mini=mnv,maxi=mxv,rbcz=rbcz $
           else image_eq,v1,radius,mini=mnv,maxi=mxv,rbcz=rbcz,psf=psf
        endif else begin
           contour_lat,v1,radius,tit=title+': theta = '+strtrim(lat_angle(il),2)
        endelse
     endelse
  endfor
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;   Plots : output
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
  
  if (psf eq 1) then begin
     device,/close
     mv_var= 'mv '+namepsf+' '+dir+'/figs/'+namepsf
     print,mv_var
     spawn,mv_var
     set_plot,'x'
  endif
  
  !p.multi = 0
  
  if notquiet gt 0 then begin
     print,name
     stop
  endif

end





