;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  see_shav.pro  -  Plot shell averages
;
;       usage: see_shav,dir,qq,sq,iter,recnum,rbcz=rbcz,glob=glob,sc=sc,
;              notquiet=notquiet,swap=swap,opl=opl,psf=psf,namepsf=namepsf,
;              wnd=wnd,xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax
;                 
;               where dir      = data directory
;                     qq       = output quantity index
;                     sq       = statistical quantity([0,1,2,3,4,5]=[mean,
;                              variance,skewness,kurtosis,min,max]),
;                              default=0 
;                     iter     = iteration of output file
;                     recnum   = record number
;                     rstar    = star radius
;                     rbcz     = percentage of the radiative zone
;                     glob     = prefix of data directory
;                     sc       = prefix of filenames
;                     notquiet = verbose if smaller than 2
;                     swap     = change endianess of the file 
;                     opl      = set if overplot command should be used
;                     psf      = output screen or psf
;                     namepsf  = name of the .eps output file
;                     wnd      = number of the window for screen output 
;                     xmin     = min
;                     xmax     = max
;                     ymin     = min
;                     ymax     = max
; 
;
;  M.DeRosa - 4 Sep 1998 - modified from Mark's routine
;  A.S. Brun - 2009 - ASH 1.4 version
;  C.Emeriau-Viard - 10 May 2016 - Version 2.0
;
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@get_names

pro see_shav2,dir,qq,file,rec,nfiles,start,skip,sq=sq,rstar=rstar,rbcz=rbcz,glob=glob,sc=sc,$
              notquiet=notquiet,swap=swap,opl=opl,psf=psf,namepsf=namepsf,$
              wnd=wnd,xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax,log=log,$
              build=build

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Usage message
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(build) eq 0 then begin
     build = 0
     print,'Do you want to create or read a IDL saving file ?'
     print,'0: No'
     print,'1: Create'
     print,'2: Read'
     read,build
  endif

  case build of 
     0: begin
        if n_params() lt 4 then begin
           print,'  see_shav2,dir,qq,sq=sq,iter,recnum,rstar=rstar,rbcz=rbcz,'+$
                 'glob=glob,sc=sc,notquiet=notquiet,swap=swap,opl=opl,psf=psf,'+$
                 'namepsf=namepsf,wnd=wnd,xmin=xmin,xmax=xmax,'+$
                 'ymin=ymin,ymax=ymax'
           return
        endif
     end
     1: begin
        if n_params() lt 7 then begin
           print,'see_shav2,dir,q,savingIDL,recper,nfiles,start,skip,sq=sq,rstar=rstar,'+$
                 'rbcz=rbcz,notquiet=notquietopl=opl,psf=psf,namepsf=namepsf,wnd=wnd,'+$
                 'xmin=xmin,xmax=xmax,ymin=ymin,ymax=ymax'
           return
        endif
     end
     2: begin
        if n_params() lt 3 then begin
           print,'see_shav2,dir,q,savingIDL,rstar=rstar,rbcz=rbcz,notquiet=notquiet'+$
                 'opl=opl,psf=psf,namepsf=namepsf,wnd=wnd,xmin=xmin,xmax=xmax'+$
                 'ymin=ymin,ymax=ymax'
           return
        endif
     end
  end

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Check parameters, set defaults
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  if n_elements(dir) eq 0 then begin
     print,'  see_shav2.pro:  parameter dir must be set'
     return
  endif
  if strmid(dir,strlen(dir)-1,1) ne '/' then dir=dir+'/'

  if n_elements(qq) eq 0 then begin
     print,'  see_shav2.pro:  parameter q must be set'     
     return
  endif

  case build of
     0: begin
        if n_elements(file) eq 0 then begin
           print,'  see_shav2.pro:  parameter iter must be set'
           return
        endif
        
        if n_elements(rec) eq 0 then begin
           print,'  see_shav2.pro:  parameter recnum must be set'
           return
        endif
        iter   = file
        recnum = rec
     end
     1: begin
        if n_elements(file) eq 0 then begin
           print,'  see_shav2.pro:  parameter savingIDL must be set'
           return
        endif
        if n_elements(rec) eq 0 then begin
           print,'  see_shav2.pro:  parameter recper must be set'
           return
        endif
        if n_elements(nfiles) eq 0 then begin
           print,'  see_shav2.pro:  parameter nfiles must be set'
           return
        endif
        if n_elements(start) eq 0 then begin
           print,'  see_shav2.pro:  parameter start must be set'
           return
        endif
        if n_elements(skip) eq 0 then begin
           print,'  see_shav2.pro:  parameter skip must be set'
           return
        endif
        savingIDL = file
        recper    = rec
     end
     2:begin
        if n_elements(file) eq 0 then begin
           print,'  see_shav2.pro:  parameter savingIDL must be set'
           return
        endif
        savingIDL = file
     end
  end

  if not keyword_set(sq)       then sq       = 0
  if not keyword_set(rbcz)     then rbcz     = 0
  if not keyword_set(glob)     then glob     = 0
  if not keyword_set(sc)       then sc       = 0
  if not keyword_set(swap)     then swap     = 0
  if not keyword_set(opl)      then opl      = 0
  if not keyword_set(psf)      then psf      = 0
  if not keyword_set(namepsf)  then namepsf  = 'SHAV'
  if not keyword_set(wnd)      then wnd      = 0
  if not keyword_set(xmin)     then xmin     = -1000
  if not keyword_set(xmax)     then xmax     = -1000
  if not keyword_set(ymin)     then ymin     = -1000
  if not keyword_set(ymax)     then ymax     = -1000
  if not keyword_set(log)      then log      = 0

  if glob eq 0 then begin
     dir="/dsm/stars2/f/cemeriau/EvolZR/"+dir
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Graphic device
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  close,/all

  r=[0b,255b,130b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b]
  g=[0b,255b,130b,0b  ,75b ,0b  ,75b ,0b  ,75b ,255b,255b,255b,255b,255b,255b,170b,195b]
  b=[0b,255b,130b,0b  ,75b ,255b,255b,255b,255b,255b,255b,0b  ,75b ,0b  ,75b ,0b  ,75b ]
  tvlct,r,g,b
  
  device,set_font='Helvetica',/tt_font

  !p.font         = 1
  !x.style        = 1
  !x.thick        = 1
  !y.thick        = 1
  !p.thick        = 1
  !p.charthick    = 1.8
  !x.charsize     = 1.2 
  !y.charsize     = 1.2
  !p.charsize     = 1.5
  !x.tickinterval = 0.1
  !p.multi        = 0
  th              = 3

  if (psf eq 0) then begin 
     set_plot,'x'
     device,decomposed=0
     if opl le 1 then window,wnd,xsize=800,ysize=500
  endif else begin
     set_plot,'ps'
     title = get_name2(qq)
     if notquiet gt 0 then print,title
     if build eq 0 then begin
        namepsf=namepsf+'_'+strcompress(title,/REMOVE_ALL)+'_0'+strcompress(iter,/r)+".eps"     
     endif else begin
        namepsf = savingIDL+'.eps'
     endelse
     device,/encapsulated,/landscape,/color,bits=8,filename=namepsf
  endelse

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Set up filename, etc.
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  case build of 
     0: begin
        textnum=strcompress(iter,/r)
        
        case sc of
           0: file = dir+'SHAV/shav_0'+textnum
           1: file = dir+'/shav_0'+textnum
           else: file = dir+textnum
        end
     end
     1: begin
        case sc of 
           0: savingIDL = dir+'SHAV/'+savingIDL
           1: savingIDL = dir+savingIDL
        end
     end
     else: begin
        case sc of 
           0: savingIDL = dir+'SHAV/'+savingIDL
           1: savingIDL = dir+savingIDL
        end
     end
  end

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
;  Associate data file
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

  case build of 
     0: begin
        read_shav2,qq,file,recnum,sq=sq,f=yy,rad=rad,name=name,notquiet=notquiet,$
                   swap=swap
     end
     1: begin
        get_mean2,dir,qq,recper,nfiles,start,skip,'SHAV',sq=sq,glob=1,sc=sc,$
                  notquiet=notquiet,swap=swap,savingIDL=savingIDL
        restore,filename=savingIDL
        rad = radius
     end
     2: begin
        restore,filename=savingIDL
        rad = radius
     end
  end

  if not keyword_set(rstar)    then rstar    = rad[0]
  
  nr    = size(rad) & nr = nr(1)
  irad  = fix(nr*(1-rbcz)) 
  print,irad
  yy_cz = yy[0:irad-1]  & rad_cz = rad[0:irad-1]
  if rbcz gt 0 then begin
     yy_rz = yy[irad:nr-1] & rad_rz = rad[irad:nr-1]
  endif
  
  print,'Mean over CZ : ',int_tabulated(reverse(rad_cz),reverse(yy_cz))/(rad(0)-rad(irad-1))
  if rbcz gt 0 then print,'Mean over RZ : ',int_tabulated(reverse(rad_rz),reverse(yy_rz))/(rad(irad)-rad(nr-1))
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^   
;  Plots : min, max and title
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
  
  c = opl
  if opl le 1 then begin
     c = 1-psf
     xtitle = '!17 Radius'
     ytitle = name
     
     nr = size(rad)
     nr = nr[1]
     
     yra=min(yy) & yrb=max(yy)
     if xmin eq -1000 then xmin = rad[nr-1]/rstar
     if xmax eq -1000 then xmax = rad[0]/rstar 
     if ymin eq -1000 then ymin = yra
     if ymax eq -1000 then ymax = yrb
     
     if notquiet gt 0 then begin
        answ1 = 0
        print,'min-max proposed',ymin,ymax
        print,'do you want to retain then (0/1)?'
        read,answ1
        if (answ1 ne 0) then begin
           print,'Please enter new values:'
           read,ymin,ymax
        endif
     endif
  endif
  
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
; Plots 
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  print,yy(20),rad(20)/rstar
  stop

  if opl gt 1 then oplot,rad/rstar,yy,thick=th,color=c else $
     
     if log eq 0 then plot,rad/rstar,yy,/xs,/ys,xr=[xmin,xmax],yr=[ymin,ymax],xtitle=xtitle,$
     ytitle=ytitle,title=ytitle,thick=th,color=c else $
        plot_io,rad/rstar,yy,/xs,/ys,xr=[xmin,xmax],yr=[ymin,ymax],xtitle=xtitle,$ 
     ytitle=ytitle,title=ytitle,thick=th,color=c
  

  if rbcz gt 0 and opl eq 0 then vline,rbcz,l=2,c=4

;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 
; Plots : output
;^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^ 

  if (psf eq 1) then begin
     device,/close
     mv_var= 'mv '+namepsf+' '+dir+'/figs/'+namepsf
     if notquiet gt 0 then print,mv_var
     spawn,mv_var
  endif

  if notquiet gt 0 then begin
     stop
  endif

end
